#!/bin/bash
#
# $Id: xorg-x11.spec,v 1.197 2004/09/03 18:56:30 mharris Exp $
#
# These are the architectures that this spec file contains patches for and
# builds cleanly on currently.  As new platforms are supported, they'll
# be added to the list.  Please file bug reqports in bugzilla.redhat.com to
# have architecture specific patches and modifications added to this file
ExclusiveArch: %{ix86} x86_64 alpha ia64 s390 s390x ppc ppc64 sparc sparc64

# xorg-x11 build requires about 1Gb of disk space, however other disk space
# users may be running simultaneously, so we set requirements to 4Gb.  This
# value is increased by 1Gb each time a build fails due to out of disk space.
BuildConflicts: rhbuildsys(DiskFree) < 4000M

%define cvs_build               0
%define cvs_date                0000_00_00

Name: xorg-x11
Version: 6.8.2
Release: 31
#Release: 1.FC3.31

%define build_mharris_mode	0

# Set to 1 to build xorg-x11 for the distribution version of the system you
# are building it on.  Default is to autodetect the build maintainer's distro
# version and build for that.
%define build_autodetect_mode	%{build_mharris_mode}

%if ! %{build_autodetect_mode}
# Set *one* of the following build targets to 1 as appropriate
# Fedora Core development builds a.k.a. "rawhide"
%define build_fc4		1
%define build_rhel4		0
%define build_fc3		0
%define build_fc2		0
%define build_mharris		0
%else
%define build_fc4		0
%define build_rhel4		0
%define build_fc3		0
%define build_fc2		0
%define build_mharris		1
%endif

ExclusiveOS: linux

# NOTE: with_alternate_projectroot is something I (mharris) have wanted to
# implement for a billion years, but never got a trapezoidal tuit.  For some
# reason I just got one, and think it can be implemented over time, so I'm
# going to start with the basics and see where it goes.  ;o)
#
# *** WARNING ***:  Currently, THIS DOES NOT WORK, so DO NOT USE IT.  I will
# update this message over time to indicate current status, if it changes.
%define with_alternate_projectroot	0

%if %{with_alternate_projectroot}
%define _projectroot		/usr/local/%{name}-%{version}
%else
%define _projectroot		/usr/X11R6
%endif

# These defines must precede any usage of them, or bad things will happen.
%define _x11dir			%{_projectroot}
%define _x11bindir		%{_x11dir}/bin
%define _x11datadir		%{_x11dir}/lib
%define _x11includedir		%{_x11dir}/include
%define _x11localedir		%{_x11datadir}/X11/locale
%define _x11libdir		%{_x11dir}/%{_lib}
%define _x11mandir		%{_x11dir}/man
%define _x11fontdir		%{_x11datadir}/X11/fonts

%define with_archexec		1

%define with_icons_in_datadir	1
%if %{with_icons_in_datadir}
%define _x11icondir		%{_datadir}/icons
%else
%define _x11icondir		%{_x11datadir}/X11/icons
%endif

# Makes 'make World' build significantly faster
%define with_fastbuild		1
# parallel_build speeds up building on SMP systems, but is broken in
# xorg-x11 6.7.0, 6.8.0, 6.8.1
%define parallel_build		0
%define verbose_build		1
# Builds X with debug symbol info.  This results in *FRECKIN* *HUGE* packages.
# Enable this if you want to debug the modular X server.  As of gdb 5.1.1, this
# requires patches to gdb to be completely useful.  I MEAN HUGE, ie 2-3 times
# the size!  Don't complain - you've been warned!  gdb for X is
# available for download from ftp://people.redhat.com/mharris/gdb-xfree86
%define debug_build         0
# If enabled, this makes the libraries contain debug info.  In the future I
# would like to either have xorg-x11 debuginfoized or build both sets of libs.
%define with_debuglibs		0
# Pass -save-temps to gcc for debugging purposes
%define with_savetemps		0
%define Glide3version           20010520

%ifarch %{ix86} alpha
%define Glide3Require           1
%else
%define Glide3Require           0
%endif

# Now that rpm mostly handles multilib so to speak, give or take, sortof, we
# don't need to package the libs data stuff in a separate subpackage anymore.
%define with_libs_data		0

%define with_new_savage_driver	0

# s390 doesn't have video hardware.  xorg-x11 support for PPC64 is very very
# new and experimental.  We ship libs only as PPC64 has we ship the PPC 32bit
# X server.  When PPC64 is supported much better in xorg-x11, and we actually
# support 64bit xorg-x11 installations on PPC64 we might enable the X server.
%ifarch s390 s390x ppc64
%define with_Xserver		0
%else
%define with_Xserver		1
%endif

# Enable DRI on supported architectures, but only on Fedora Core 2/3
# variants, ie: only enable PPC DRI on Fedora Core.
%define with_DRI		0
%ifarch %{ix86} x86_64 ia64 alpha
%define with_DRI		1
%endif
%ifarch ppc
%define with_DRI		%([ '%{build_rhel4}' -eq '1' ] && echo 0 || echo 1)
%endif

# libGL version:
# We specify the libGL version here for multiple reasons.  Firstly, so that
# we can add a versioned virtual provide in the subpackage that libGL gets
# included in, so that 3rd party apps needing to Require libGL can require
# libGL in an implementation neutral manner.  We want to ensure that the
# virtual provide version ALWAYS matches the shipping libGL version however,
# and by making an rpm macro, we can easily ensure that the virtual provide
# always matches the version of the file included in the file lists.  If
# a libGL update occurs during development, rpm will fail to package libGL
# due to the version number being bumped, and when the spec file is examined
# to determine the problem, the macro here just needs to be adjusted, and then
# both the virtual provide and the included libGL .so version will be
# guaranteed to always match.
%define libGL_version	1.2
# Same thing for libGLU as for libGL above
%define libGLU_version	1.3

# Set enable_sdk to 1 to enable the SDK when an Xserver is built, or 0 to disable
%define enable_sdk		1
%if %{with_Xserver}
%define with_sdk                %{enable_sdk}
%else
%define with_sdk                0
%endif

%ifarch s390 s390x
%define with_docs		0
%else
%define with_docs		1
%endif

# xf86cfg only works on x86, and alpha, so we ifarch, however xf86cfg is now
# disabled, as we've moved to our own GTK+ config tool redhat-config-xfree86,
# which has been renamed to system-config-display in Fedora Core 2
%ifarch %{ix86} alpha
%define with_xf86cfg            0
%define with_xf86config		0
%else
%define with_xf86cfg            0
%define with_xf86config		0
%endif

%define with_xcalc		1
%define with_xedit		0
%define with_xman		0
%define with_xmh		0

%define with_rstart		0
%define with_xprint		0

# Build fontconfig and package it instead of using external fontconfig
%define with_fontconfig		0
# Eventually we want to build fonts in a separate subpackage, so this option
# toggles font building and subpackage inclusion
%define with_fonts		%{build_fc2}

%define with_whiteglass		0
%define with_redglass		0
%define with_handhelds		0

%define with_libxrx		0
# FIXME: Never ship xterm as part of xorg-x11.  This option will be removed
#        entirely in the future as we always will ship xterm separately.
%define with_xterm		0
%define with_sis_dri		0

%define with_dll_modules	0


%define with_bail_on_undef_syms			0

# The following, are post build checks performed in %%check section
# Test for dead symlinks after build and install sections are done?
%define with_dead_symlink_test			1
# Use ldd -r to test for undef syms.  Xorg isn't clean enough for this to be
# enabled except for developmental testing purposes.
%define with_undef_sym_test			0
# with_fortify_source is used to manually enable gcc's fortify source support
# available in newer gcc releases.  It causes "-D_FORTIFY_SOURCE=2" to be
# added to the gcc CFLAGS when building.  Currently, our RHEL4 and FC3 gcc
# have support for this but rpm does not enable it globally by default, so
# this macro causes it to be enabled on those builds.  FC4 has it enabled
# by default in the stock rpm configuration, so it doesn't need to be enabled
# here.  NOTE:  bcopy(), bzero(), vfprintf() are redefined in the X sources,
# causing FORTIFY_SOURCE to be useless for those functions.  Additionally the
# libc_wrapper causes the benefits of using fortify source to be lost for
# those functions wrapped by the wrapper.  Xorg needs some enhancements to
# fully benefit from FORTIFY_SOURCE.
%define with_fortify_source	0
#%( [ '%{build_fc3}' -eq '1' -o '%{build_rhel4}' -eq '1' ] && echo 1 || echo 0 )

# We don't ship the wacom driver as part of the xorg-x11 package, but
# ship the driver from linuxwacom.sourceforge.org.
%define with_wacom_driver       0

# Command macros
%define __mkfontdir	umask 133;%{_x11bindir}/mkfontdir
%define __mkfontscale	umask 133;%{_x11bindir}/mkfontscale
# Use this macro to call fc-cache throughout the specfile.
%define __fccache	umask 133;which fc-cache &> /dev/null && fc-cache

# Disable rpm from stripping xorg-x11's modules, or they explode
#if %{debug_build}
%define __spec_install_post /usr/lib/rpm/redhat/brp-compress
%define debug_package %{nil}
#endif

%define rhbsys  %([ -r /etc/beehive-root ] && echo 1 || echo 0)


######################################################################
######################################################################

Summary: The basic fonts, programs and docs for an X workstation.
License: MIT/X11, and others
Group: User Interface/X
URL: http://xorg.freedesktop.org
BuildRoot: %{_tmppath}/%{name}-%{version}-root

BuildRequires: flex >= 2.5.4a
# Perl is used both by xorg-x11 during build (bdftruncate.pl) and the specfile
BuildRequires: perl
BuildRequires: bison, zlib-devel, ncurses-devel, utempter, expat-devel
BuildRequires: pam-devel, libpng-devel
# sh-utils needed for 'whoami' in spec file
BuildRequires: sh-utils
# Needed for correct man page compression, since we override the default
# -- Bill Nottingham <notting@redhat.com>
BuildRequires: redhat-rpm-config

%if %{with_fontconfig}
# FIXME: Apparently fontconfig requires ed or ex to build.  We don't want to
# build fontconfig however, so this can go away when we can get rid of
# fontconfig weirdness
BuildRequires: ed
%endif
# Requires rpm 4.0.4 or higher to build or else modules will get stripped
BuildRequires: rpm >= 4.0.4
# xorg-x11-6.8.2 comes with freetype 2.1.9, which is the minimum version of
# freetype required to build it.  Also, -fno-strict-aliasing must be passed
# to the compiler when building freetype to avoid an aliasing bug in freetype.
BuildRequires: freetype-devel >= 2.1.9
# If using GL_TLS patch, a newer glibc is required
#%if %{with_GL_TLS}
#BuildRequires: glibc >= 2.3.2-66
#Requires: glibc >= 2.3.2-66
#%endif

%if ! %{with_fontconfig}
BuildRequires: fontconfig-devel >= 2.1
%endif

Prereq: /bin/ln, %{_sbindir}/chkfontpath, %{_x11bindir}/mkfontdir

Requires: %{name}-xfs = %{version}-%{release}, %{name}-libs = %{version}-%{release}
# Don't make the base-fonts dependancy ver-rel as that is a bit problematic.
# We no longer use "xorg-x11-base-fonts" dep, but instead "base-fonts" virtual
# dep, so that fonts-xorg can provide the dependancy for us, or something else
# in the future.
Requires: base-fonts, utempter
# xinitrc is required as per bug #81424 in Red Hat bugzilla
Requires: xinitrc
Requires: %{_sysconfdir}/pam.d/system-auth
# FIXME: xrdb needs /lib/cpp at runtime (should be changed to use /usr/bin/cpp)
Requires: %{_bindir}/cpp, %{_x11bindir}/xauth
# kernel-drm requirement is so DRI works properly.  The kernel RPM package
# should have a "Provides: kernel-drm = 4.2.0".  Future kernels that provide
# new kernel-drm, should list all supported DRM interfaces with multiple
# Provides: lines.  The 4.2.0 DRM is backward compatible with XFree86 4.1.0
# also.                                                 <mharris@redhat.com>
%if %{with_DRI}
Requires: kernel-drm = 4.3.0
%endif

# Obsolete all old XFree86 3.3.x packages, and other legacy packages
Obsoletes: XFree86-ATI, XFree86-Alliance, XFree86-ChipsTechnologies
Obsoletes: XFree86-Cirrus, XFree86-Cyrix, XFree86-i740, XFree86-i810, XFree86-mga
Obsoletes: XFree86-NeoMagic, XFree86-NVidia, XFree86-Rage128, XFree86-Rendition
Obsoletes: XFree86-SiS, XFree86-3dfx, XFree86-Trident, XFree86-Tseng
Obsoletes: tdfx_dri, X11R6-contrib, XFree86-V4L, XFree86-Setup
Obsoletes: XFree86-3DLabs, XFree86-8514, XFree86-AGX, XFree86-FBDev
Obsoletes: XFree86-Mach32, XFree86-Mach64, XFree86-Mach8, XFree86-Mono
Obsoletes: XFree86-P9000, XFree86-S3, XFree86-S3V, XFree86-SVGA
Obsoletes: XFree86-VGA16, XFree86-W32, XFree86-compat-modules, XFree86-compat-libs
# This one was only on Alpha
Obsoletes: XFree86-TGA
# XFree86-{xtrap-clients,cursors} are integrated into other subpackages now
Obsoletes: XFree86-xtrap-clients, XFree86-cursors
%if ! %{with_xf86cfg}
Obsoletes: XFree86-xf86cfg
%endif

Obsoletes: XFree86

Conflicts: XFree86-sdk < 4.2.99.3-20030115.0

# What archive format to use for main tarball.  ".gz" is preferred because it
# uncompresses twice as fast, which knocks off about 10% of the build time on
# faster machines.  Disk space is cheap.
%define zipext	tar.gz

%if %{cvs_build}
Source:   http://xorg.freedesktop.org/X11R6.8.2/%{name}-%{version}-%{cvs_date}.%{zipext}
%else
# Main source tarball for official releases created using the following:
# cvs -d :pserver:anoncvs@cvs.freedesktop.org:/cvs/xorg export -r XORG-6_8_1 xc
# tar zcf xorg-x11-%{version}.tar.gz
Source:   %{name}-%{version}.%{zipext}
%endif

Source1:  host.def
Source3:  xserver.pamd
Source4:  xdm.pamd
Source5:  xfs.init
Source6:  xfs.config
Source7:  xdm.init
%if %{with_archexec}
Source10: archexec
%endif
#Source14: http://www.probo.com/timr/savage-1.1.27t.tgz
Source23: mkxauth
Source24: mkxauth.1x
Source25: CHANGELOG-rpm

# X.org stable branch patch, created using:
# FIXME: These instructions need to be updated to X.org relevance.
# cvs rdiff -u -r xo-6_8_0 -r xo-6_8-branch xc > xorg-x11-6.8.0-xo-6_8-branch-$(/bin/date +"%Y-%m-%d").patch
#Patch0:   XFree86-4.3.0-xf-4_3-branch-2003-11-03.patch

Patch9:   XFree86-4.3.0-makefile-fastbuild.patch

# Patches: 800-829 - xkb keyboard symbol files
# 6000-6049 xkb related patches

##### DRIVER PATCHES #################################################
# Patches 1000-1024: apm driver patches
# Patches 1050-1099: ark driver patches
# Patches 1100-1149: ati driver patches

# Patches 1150-1199: ATI Rage 128
# Patches 1200-1299: radeon driver patches 
Patch1213: XFree86-4.3.0-radeon-ia64-preint10.patch
Patch1214: XFree86-4.3.0-radeon-disable-VideoRAM-option.patch
Patch1215: xorg-x11-6.8.1-ati-radeon-disable-dri.patch

# Patches 1300-1319: chips driver patches 
Patch1300: XFree86-4.2.99.901-chips-default-to-noaccel-on-69000.patch
# For bugzilla https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=82438
Patch1301: XFree86-4.2.99.901-chips-default-to-swcursor-on-65550.patch

# Patches 1320-1339: cirrus driver patches 
# Patches 1340-1359: cyrix driver patches
# Patches 1360-1379: fbdev driver patches
# Patches 1380-1399: glint driver patches
# Patches 1400-1419: i128 driver patches
# Patches 1420-1439: i740 driver patches
# Patches 1600-1624: Intel i810 / i830 patches
# Patches 1625-1649: mga driver patches
# Patches 1650-1674: neomagic driver patches
# Patches 1675-1699: nv driver patches
# Patches 1700-1719: rendition driver patches
# Patches 1720-1739: s3 driver patches
# Patches 1740-1759: s3virge driver patches
# Patches 1760-1779: savage driver patches
# Patches 1780-1799: siliconmotion driver patches
# Patches 1800-1824: sis driver patches
# Patches 1825-1849: tdfx driver patches
# Patches 1850-1859: tga driver patches
# Patches 1860-1879: trident driver patches
# Patches 1880-1899: tseng driver patches
# Patches 1900-1919: v4l driver patches
# Patches 1920-1939: vesa driver patches
# Patches 1940-1959: vga driver patches
# Patches 1960-1979: via driver patches
# Patches 1980-1999: vmware driver patches

### Non-video driver patches #########################################
# Patches 2000-2019: xc/nls/{locale.dir,locale.alias,compose.dir} patches
# Manpage fixup  Mike A. Harris <mharris@redhat.com>
# load agpgart for DRM
Patch2022: XFree86-4.1.0-agpgart-load.patch

Patch9007: XFree86-4.2.99.2-netmouse.patch

Patch9013: xorg-Imake-make-icondir-configurable.patch
# These two can be merged into one later.
Patch9015: XFree86-4.2.99.4-IncludeSharedObjectInNormalLib.patch
Patch9016: XFree86-4.3.0-libfontenc-IncludeSharedObjectInNormalLib.patch

# Minor version fixup from debian for manpage strings
Patch9028: XFree86-4.2.99.901-028_fbdev_depth24_support.patch
# Recommendation of Keith Packard
Patch9031: XFree86-4.2.99.901-dont-install-Xcms.txt.patch

Patch9111: XFree86-4.3.0-disable-building-apps-we-do-not-ship.patch

Patch9120: XFree86-4.3.0-ia64-new-elfloader-relocations.patch

Patch9163: XFree86-4.3.0-XRes-IncludeSharedObjectInNormalLib.patch
Patch9181: XFree86-4.3.0-keyboard-disable-ioport-access-v3.patch
Patch9184: xorg-x11-6.8.0-Xserver-increase-max-pci-devices.patch
Patch9187: xorg-x11.6.8.1.903-AMD64-override-default-driverlist.patch

# ia64 section
Patch9204: XFree86-4.3.0-ia64-pci-infinite-loop.patch
Patch9208: XFree86-4.3.0-ia64-drm-locking.patch

# New X.org patches from after Fedora Core integration

# This patch is submitted upstream in the following URLs:
# https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=119032
# http://pdx.freedesktop.org/cgi-bin/bugzilla/show_bug.cgi?id=368 (marked as
# rel-blocker, not committed as of Apr 5, 2004)
# http://bugs.xfree86.org/show_bug.cgi?id=991
Patch9306: xorg-x11-6.7.0-fix-BuildXFree86ConfigTools.patch
Patch9307: xorg-x11-6.7.0-xterm-make-optional.patch
Patch9309: xorg-x11-6.7.0-libxf86config-monitor-freq-fix.patch
Patch9310: xorg-x11-6.8.0-Imake-add-BuildFontDevelUtils-macro.patch

Patch9312: xorg-x11-6.8.0-libXdmcp-build-with-PIC.patch

Patch9317: xorg-x11-6.8.1-init-origins-fix.patch
Patch9319: xorg-x11-6.8.1-nls-indic-locales.patch
Patch9321: xorg-x11-6.8.1.902-ia64-hp-zx2-support-bug-119364.patch
Patch9323: xorg-x11-6.8.1.902-lnxLib-tmpl-sharedlibreq-fixes.patch

Patch9324: xorg-x11-6.8.1-composite-gravity.patch
Patch9326: xorg-x11-6.8.2-ati-radeon-disable-broken-renderaccel-by-default.patch
Patch9327: xorg-x11-6.8.2-ati-radeon-gcc4-fix.patch
Patch9328: xorg-x11-6.8.2-fix-font-crash.patch
# Nominated as fdo2546-2005
Patch9329: xorg-x11-6.8.2-xnest-shape-fix.patch
Patch9330: xorg-x11-6.8.2-config-StaticNeedsPicForShared.patch
Patch9331: xorg-x11-6.8.2-XScreenSaverQueryInfo-crash-fix.patch
Patch9333: XFree86-4.1.0-xpm-security-fix-CAN-2005-0605.patch
Patch9334: xorg-x11-6.8.2-xorg.conf.man-dont-refer-to-nonexisting-example.patch

# This patch reverts the dynamic clocks handling in the radeon driver
# to the behavior we had pre-6.8.2.  It's not the right patch going
# forward, but until the dynamic clocks code is fixed properly, let's
# stick to something that works.
Patch9335: xorg-x11-6.8.1-ati-radeon-dynamic-clocks-fix-2.patch
Patch9336: xorg-x11-6.8.2-ati-ragexl-ia64-avoidcpiofix.patch
Patch9337: xorg-x11-6.8.2-use-linux-native-pciscan-by-default.patch

# EXPERIMENTAL PATCHES intended strictly for fedora-devel (FC4 currently).
# Once a patch is determined to be safe to apply to other releases, it can
# be moved to the normal section above in sequence.
# These are currently build_fc4 only:

# BenH said he'd nominate this and other Radeon + PPC patches for 6.8.3
Patch9500: xorg-x11-6.8.3-deassert-ddc-lines.patch
Patch9501: xorg-x11-6.8.2-laptop-modes.patch
Patch9502: xorg-x11-6.8.2-xft-releasefile-crash.patch


# PATCHES NOMINATED FOR 6.8.3
# Of the patches only enabled for fedora-devel, some of them are
# nominated for 6.8.3.  The patch filenames typically end in
# fdoXXXX-YYYY where XXXX is the bugs.freedesktop.org bug number and
# YYYY is the attachement number the patch was taken from.

Patch9700: xorg-x11-6.8.3-alpha-srel32-fix-fdo1765-2174.patch
Patch9701: xorg-x11-6.8.3-canonicalize-builderaddr-1-fdo2884-2293.patch
Patch9702: xorg-x11-6.8.2-cursor-flicker.patch
Patch9705: xorg-x11-6.8.3-iso8859-compose-files-fdo2592-2156.patch
Patch9706: xorg-x11-6.8.3-lbxproxy-fdo2678-2051.patch
Patch9707: xorg-x11-6.8.3-nv-hw-fdo2533-1896.patch
Patch9708: xorg-x11-6.8.3-nv-patch-fdo2380-1752.patch
Patch9709: xorg-x11-6.8.3-radeon-cursor-sync-fdo2844-2230.patch
Patch9710: xorg-x11-6.8.3-radeon-render-byteswap-fdo2164-1863.patch
Patch9711: xorg-x11-6.8.3-radeon-set-fb-location-fdo2698-2079.patch
Patch9712: xorg-x11-6.8.3-saver-c-fdo2194-1613.patch
Patch9713: xorg-x11-6.8.3-uname-fdo2123-1587.patch
Patch9714: xorg-x11-6.8.3-void-fdo2467-1828.patch
Patch9716: xorg-x11-6.8.3-xnest-fdo2599-1964.patch
Patch9717: xorg-x11-6.8.3-xorgcfg-typo-fdo2896-2311.patch
Patch9718: xorg-x11-6.8.3-xset-fdo2258-2166.patch
Patch9719: xorg-x11-6.8.1-battle-libc-wrapper.patch
Patch9720: xorg-x11-6.8.2-gcc4-fix.patch

# END OF 6.8.3 CANDIDATES
# END OF DEVEL PATCHES

######################################################################
# Red Hat customizations, not intended for submission upstream
Patch10000: xorg-x11-6.8.0-redhat-custom-startup.patch
Patch10001: XFree86-4.2.99.2-redhat-custom-modelines.patch

# Disable the ugly checkerboard pattern that X starts up with.  We're in the
# year 2002 now, and this pattern just has to go.  No really.  <mharris>
Patch10002: xorg-redhat-die-ugly-pattern-die-die-die.patch
#XFree86-4.2.99.901-parallelmake-this-time-its-personal.patch
Patch10005: XFree86-4.3.0-redhat-bug-report-address-update.patch

# John Dennis's libGL fixes for exec-shield
# FIXME: This needs to be ported to Mesa head, and submitted by John for
#        discussion/integration in upstream Mesa CVS.
Patch10012: xorg-x11-6.8.0-redhat-libGL-exec-shield-fixes.patch
Patch10015: XFree86-4.3.0-redhat-nv-riva-videomem-autodetection-debugging.patch
# Red Hat Xft enhancements 9009/9010 are dependant on 9008
Patch10020: XFree86-4.3.0-redhat-fontconfig-2.1-slighthint.patch
Patch10022: xorg-redhat-embeddedbitmap.patch
Patch10023: XFree86-4.3.0-redhat-exec-shield-GNU-stack.patch

# Patches in the 20000+ section are Red Hat specific patches that are 
# not intended to be sent upstream in their current state, or are Red Hat
# specific things not intended to be sent upstream at all.  Some are temporary
# workarounds unsuitable for upstream submission, some others are works in
# progress.

# FIXME: This patch makes sessreg work with highuid Linux systems.  It was
# originally submitted to XFree86 a long time ago, but was rejected as being
# non-portable.  This works good enough for us for the time being, until
# proper highuid support is implemented throughout the X.Org source tree.
Patch20002: XFree86-4.2.0-sessreg-highuid.patch
# Disable DRI on 16Mb cards in high res (Mike A. Harris <mharris@redhat.com>)
Patch20004: XFree86-4.2.0-tdfx-disable-dri-on-16Mb-cards-in-hires.patch
# Force mkfontdir to make fonts.dir and encodings.dir, etc. mode 0644 Mike A. Harris <mharris@redhat.com>
# FIXME: This should be updated, and resubmitted upstream to X.Org for 6.9.0
# or X11R7
Patch20005: XFree86-4.2.99.2-mkfontdir-perms.patch
Patch20007: XFree86-4.3.0-redhat-xcursorgen-do-not-build-included-cursors.patch
# Changes xfs.init to start at level 8 instead of level 90 during OS startup,
# to ensure xfs is started prior to the X server and gdm
Patch20008: xfs.init-fc4-startearly.patch
# EXPERIMENTAL patches (disabled except for development)

######################################################################
%description
X.org X11 is an open source implementation of the X Window System.  It
provides the basic low level functionality which full fledged
graphical user interfaces (GUIs) such as GNOME and KDE are designed
upon.
######################################################################
%package devel
Summary: X Window System application development package
Group: Development/Libraries
Requires: %{name}-libs = %{version}-%{release}
# Experimental Requires libGL{,U}.  Once confirmed safe, we can deconditionalize
%if %{build_fc4}
Requires: libGL >= 1, libGLU >= 1
%endif
Obsoletes: xpm-devel, Mesa-devel
Obsoletes: Xft-devel
Provides: xpm-devel, Mesa-devel
%if %{build_mharris}
Provides: Xft-devel
%endif
# Conditionalized the Conflicts Xft-devel line as it seems to prevent upgrades
# from working from XFree86 4.2.x to 4.3.0 on RHL 8.0 systems as the package both
# provides and obsoletes itself already.  The conflicts seems to make it conflict
# with itself too.
%if ! %{build_mharris}
Conflicts: Xft-devel
%endif
%if %{with_archexec}
# archexed moved from "xorg-x11" to "xorg-x11-devel" in the 6.8.0-1 rpm for
# bug #132121
Conflicts: %{name} < 6.8.0
%endif
%if ! %{with_fontconfig}
Requires: fontconfig-devel >= 2.1
%endif
Requires: pkgconfig
Obsoletes: XFree86-devel
Provides: XFree86-devel = 4.4.0
# Virtual provides for libGL and libGLU
# Provide for libGL major version
Provides: libGL-devel = 1
# Provide libGL specific version
Provides: libGL-devel = %{libGL_version}
# Provide for libGLU major version
Provides: libGLU-devel = 1
# Provide libGLU specific version
Provides: libGLU-devel = %{libGLU_version}

%description devel
This development package includes the libraries, header files and
documentation needed for developing applications for the X window system.
######################################################################
%package deprecated-libs-devel
Summary: Deprecated X Window System developmental libraries
Group: Development/Libraries
Requires: %{name}-deprecated-libs = %{version}-%{release}
Requires: %{name}-devel = %{version}-%{release}
# libXp used to be in the 'libs' subpackage, but we moved it in 6.7.99.901
Conflicts: xorg-x11-libs <= 6.7.99.901
Provides: libXp-devel = 6.2

%description deprecated-libs-devel
This package contains shared library runtimes which have been deprecated,
but are provided still for compatibilty with existing applications that link
to them.  Software projects which use these libraries, should port their
code to current alternatives.
######################################################################
%package font-utils
Summary: Font utilities required for installing fonts
Group: User Interface/X
# mkfontdir, ttmkfdir and other util were moved here so this conflict is needed
Conflicts: XFree86 < 4.2.0-5.2,
# ucs2any moved from xorg-x11-tools to xorg-x11-font-utils in 6.7.99.903-3
Conflicts: xorg-x11-base-fonts <= 6.7.99.903-3
# The fonts/util subdir moved from xorg-x11-base-fonts to xorg-x11-font-utils
# in 6.7.99.903-3
Conflicts: xorg-x11-base-fonts <= 6.7.99.903-3
Obsoletes: XFree86-font-utils
Provides: XFree86-font-utils = 4.4.0
Provides: font-utils

%description font-utils
Includes mkfontdir, and other font related utilities which are required when
installing font packages.
######################################################################
%package xfs
Summary: A font server for the X Window System.
Group: System Environment/Daemons
Prereq: fileutils sed shadow-utils initscripts
# chkconfig is needed for %post %postun
Prereq: /sbin/chkconfig, %{_x11bindir}/mkfontdir, %{_bindir}/ttmkfdir
Requires: %{name}-libs = %{version}-%{release}
# xfs rpm scripts that use /sbin/service
Requires(preun): /sbin/service
Requires(postun): /sbin/service
Obsoletes: XFree86-xfs
Provides: xfs

%description xfs
This package contains the X Window System xfs font server and related
utilities, which is used to serve legacy core fonts to a local or remote
X server.
######################################################################
%package twm
Summary: A simple window manager
Group: User Interface/X
%if ! %{with_xterm}
Requires: xterm
%endif
Provides: windowmanager
# The twm.1 manpage was moved from the XFree86 package to the twm package
# to fix bug #70025 on July 29 2002 - Mike A. Harris
Conflicts: XFree86 <= 4.2.0-57.1
Obsoletes: XFree86-twm
Provides: twm

%description twm
A simple and lightweight window manager
######################################################################
%package xdm
Summary: X Display Manager
Requires: %{name} = %{version}, /etc/pam.d/system-auth
# xinitrc requirement on 3.13 for user login shell enhancement to Xsession
Requires: xinitrc >= 3.13
Group: User Interface/X
Obsoletes: XFree86-xdm
Provides: xdm

%description xdm
X Display Manager.
######################################################################
%package libs
Summary: Shared libraries needed by the X Window System
Group: System Environment/Libraries
# Now that Xft2 is part of XFree86 4.3.0, we obsolete the old standalone one
Obsoletes: Xft
Requires: freetype >= 2.1.8
Obsoletes: xpm
Provides: xpm
%if %{build_mharris}
Provides: Xft
%endif
# Conditionalized the Conflicts Xft-devel line as it seems to prevent upgrades
# from working from XFree86 4.2.x to 4.3.0 on RHL 8.0 systems as the package both
# provides and obsoletes itself already.  The conflicts seems to make it conflict
# with itself too.
%if ! %{build_mharris}
Conflicts: Xft
%endif
%if %{with_libs_data}
Requires: %{name}-libs-data = %{version}-%{release}
%else
Obsoletes: xorg-x11-libs-data < %{version}-%{release}
Obsoletes: XFree86-libs-data
# Files moved from these packages to XFree86-libs-data, and now to
# xorg-x11-libs-data, so we conflict them
Conflicts: XFree86 <= 4.2.99.2-0.20021105.0, XFree86-libs <= 4.2.99.2-0.20021105.0
%endif
#Requires(post): /sbin/ldconfig grep textutils
#Requires(postun): /sbin/ldconfig grep textutils
#Requires(verify): /sbin/ldconfig grep textutils
Prereq: /sbin/ldconfig grep textutils
Obsoletes: XFree86-libs
# FIXME: Currently the same libs are present, but that's soon to change
Provides: XFree86-libs = 4.4.0

%description libs
This package contains the shared libraries required for running X
applications.
######################################################################
%package deprecated-libs
Summary: Deprecated X Window System shared libraries 
Group: System Environment/Libraries

%description deprecated-libs
This package contains shared library runtimes which have been deprecated,
but are provided still for compatibilty with existing applications that link
to them.  Software projects which use these libraries, should port their
code to current alternatives.
######################################################################
%if %{with_libs_data}
%package libs-data
Summary: Architecture independent data required by X Window System libraries
Group: System Environment/Libraries
Obsoletes: XFree86-libs-data
# Files moved from these packages to XFree86-libs-data, and now to
# xorg-x11-libs-data, so we conflict them
Conflicts: XFree86 <= 4.2.99.2-0.20021105.0, XFree86-libs <= 4.2.99.2-0.20021105.0

%description libs-data
Architecture independent data files required by the X11 runtime libraries,
including locale and compose database files, XErrorsDB, rgb.txt, etc.
%endif
######################################################################
# Font subpackages
%if %{with_fonts}
%package base-fonts
Summary: Base fonts required by the X Window System
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
# Required so upgrades work, since base fonts moved here from main pkg
Conflicts: XFree86 <= 4.2.0-3.1
# The fonts.* files from truetype and syriac moved from those pkgs to base
Conflicts: XFree86-truetype-fonts < 4.2.99.901-20030209.2
Conflicts: XFree86-syriac-fonts < 4.2.99.901-20030209.2
Obsoletes: XFree86-base-fonts
# Added to force removal of XFree86-ISO8859-2-Type1-fonts and 
# fonts-ISO8859-2-Type1 on upgrades, as this was renamed to the latter in
# RHL 7.2 and then removed entirely around RHL 8.0.  These fonts were removed
# because they are very broken, among other reasons, so we do not support them
# at all.  By forcing their removal, we can have better guarantees that people
# do not experience problems with these broken fonts when upgrading their OS.
# Adding it back now to fix (#129523)
Obsoletes: XFree86-ISO8859-2-Type1-fonts, fonts-ISO8859-2-Type1
Provides: base-fonts

%description base-fonts
This package provides the base fonts that are required by the X Window System.
######################################################################
%package truetype-fonts
Summary: TrueType fonts provided by the X Window System
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir, %{_bindir}/ttmkfdir
Obsoletes: XFree86-truetype-fonts

%description truetype-fonts
A collection of truetype fonts which are part of the core X Window System
distribution.
######################################################################
%package syriac-fonts
Summary: Syriac TrueType fonts by Beth Mardutho
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir, %{_bindir}/ttmkfdir
Obsoletes: XFree86-syriac-fonts

%description syriac-fonts
A collection of Syriac truetype fonts from Beth Mardutho, which are part
of the core X Window System distribution.
######################################################################
%package 75dpi-fonts
Summary: A set of 75dpi resolution fonts for the X Window System.
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
Obsoletes: XFree86-75dpi-fonts

%description 75dpi-fonts
A set of 75 dpi fonts used by the X window system.
######################################################################
%package 100dpi-fonts
Summary: A set of 100dpi resolution fonts for the X Window System.
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
Obsoletes: XFree86-100dpi-fonts

%description 100dpi-fonts
A set of 100 dpi fonts used by the X window system.
######################################################################
%package ISO8859-2-75dpi-fonts
Summary: A set of 75dpi Central European language fonts for X.
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
Obsoletes: XFree86-ISO8859-2-75dpi-fonts

%description ISO8859-2-75dpi-fonts
Contains a set of 75dpi fonts for Central European languages.
######################################################################
%package ISO8859-2-100dpi-fonts
Summary: A set of 100dpi Central European language fonts for X.
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
Obsoletes: XFree86-ISO8859-2-100dpi-fonts

%description ISO8859-2-100dpi-fonts
Contains a set of 100dpi fonts for Central European languages.
######################################################################
%package ISO8859-9-75dpi-fonts
Summary: ISO8859-9-75dpi-fonts
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
Obsoletes: XFree86-ISO8859-9-75dpi-fonts

%description ISO8859-9-75dpi-fonts
Contains a set of 75dpi fonts for the Turkish language.
######################################################################
%package ISO8859-9-100dpi-fonts
Summary: ISO8859-9-100dpi-fonts
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
Obsoletes: XFree86-ISO8859-9-100dpi-fonts

%description ISO8859-9-100dpi-fonts
Contains a set of 100dpi fonts for the Turkish language.
######################################################################
%package ISO8859-14-75dpi-fonts
Summary: ISO8859-14-75dpi-fonts
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
Obsoletes: XFree86-ISO8859-14-75dpi-fonts

%description ISO8859-14-75dpi-fonts
Contains a set of 75dpi fonts in the ISO8859-14 encoding which
provide Welsh support.
######################################################################
%package ISO8859-14-100dpi-fonts
Summary: ISO8859-14-100dpi-fonts
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
Obsoletes: XFree86-ISO8859-14-100dpi-fonts

%description ISO8859-14-100dpi-fonts
Contains a set of 100dpi fonts in the ISO8859-14 encoding which
provide Welsh support.
######################################################################
%package ISO8859-15-75dpi-fonts
Summary: ISO8859-15-75dpi-fonts
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
Obsoletes: XFree86-ISO8859-15-75dpi-fonts

%description ISO8859-15-75dpi-fonts
Contains a set of 75dpi fonts in the ISO8859-15 encoding which
provide Euro support.
######################################################################
%package ISO8859-15-100dpi-fonts
Summary: ISO8859-15-100dpi-fonts
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
Obsoletes: XFree86-ISO8859-15-100dpi-fonts

%description ISO8859-15-100dpi-fonts
Contains a set of 100dpi fonts in the ISO8859-15 encoding which
provide Euro support.
######################################################################
%package cyrillic-fonts
Summary: Cyrillic fonts for X.
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
Obsoletes: XFree86-cyrillic-fonts

%description cyrillic-fonts
Contains a set of Cyrillic fonts.
%endif
# End of font subpackages ############################################
######################################################################
%if %{with_docs}
%package doc
Summary: Documentation on various X11 programming interfaces.
Group: Documentation
Obsoletes: XFree86-doc

%description doc
This package contains various documentation in PostScript format on
the various X APIs, libraries, and other interfaces.  If you need
low level X documentation, you will find it here.  Topics include
the X protocol, the ICCCM window manager standard, ICE session management,
the font server API, etc.
%endif
######################################################################
%package Xdmx
Summary: Distributed Multihead X Server and utilities
Group: User Interface/X
Requires: %{name} = %{version}-%{release}
Provides: Xdmx

%description Xdmx
Xdmx is proxy X server that provides multi-head support for multiple displays
attached to different machines (each of which is running a typical X server).
When Xinerama is used with Xdmx, the multiple displays on multiple machines
are presented to the user as a single unified screen.  A simple application
for Xdmx would be to provide multi-head support using two desktop machines,
each of which has a single display device attached to it.  A complex
application for Xdmx would be to unify a 4 by 4 grid of 1280x1024 displays
(each attached to one of 16 computers) into a unified 5120x4096 display.
######################################################################
%package Xnest
Summary: A nested server.
Group: User Interface/X
Requires: %{name} = %{version}-%{release}
Obsoletes: XFree86-Xnest
Provides: Xnest

%description Xnest
Xnest is an X server, which has been implemented as an ordinary
X application.  It runs in a window just like other X applications,
but it is an X server itself in which you can run other software.  It
is a very useful tool for developers who wish to test their
applications without running them on their real X server.
######################################################################
%package tools
Summary: Various X Window System tools
Group: User Interface/X
Obsoletes: X11R6-contrib
Requires: %{name}
Obsoletes: XFree86-tools

%description tools
Various tools for X, including listres, xcalc, and xload among others.

This package contains all applications that used to be in X11R6-contrib
in older releases.
######################################################################
%package xauth
Summary: X authority file utility
Group: User Interface/X
Conflicts: XFree86 < 4.2.0-50.11
Obsoletes: mkxauth
Provides: mkxauth
Obsoletes: XFree86-xauth
Provides: xauth

%description xauth
The xauth program is used to edit and display the authorization information
used in connecting to the X server.
######################################################################
%package Mesa-libGL
Summary: A 3D graphics library which uses an OpenGL-like API
Group: System Environment/Libraries
# FIXME: These should be versioned to the Mesa version
Obsoletes: Mesa
Provides: Mesa
%if %{build_fc4}
Provides: libGL = 1
%endif
Obsoletes: XFree86-Mesa-libGL
# Conflict is due to this package being split out from XFree86-libs a long time ago
Conflicts: XFree86-libs < 4.2.0-50.5

%description Mesa-libGL
The Mesa 3D graphics library is a powerful and generic toolset for
creating hardware assisted computer graphics. To the extent that Mesa
utilizes the OpenGL command syntax or state machine, it is being used
with authorization from Silicon Graphics, Inc. However, the author
(Brian Paul) makes no claim that Mesa is in any way a compatible
replacement for OpenGL or associated with Silicon Graphics, Inc. Those
who want a licensed implementation of OpenGL should contact a licensed
vendor. Mesa is very similar to OpenGL and you might find Mesa to be a
valid alternative to OpenGL.
######################################################################
%package Mesa-libGLU
Summary: Commonly used GL utility library
Group: System Environment/Libraries
Obsoletes: XFree86-Mesa-libGLU
%if %{build_fc4}
Provides: libGLU = 1
%endif
# Conflict is due to this package being split out from XFree86-libs a long time ago
Conflicts: XFree86-libs < 4.2.0-50.5

%description Mesa-libGLU
libGLU is a utility library used by a lot of OpenGL applications
######################################################################
%if %{with_xf86cfg}
%package xf86cfg
Summary: X server configuration program
Group: User Interface/X
Obsoletes: XFree86-XF86Setup
Requires: %{name} = %{version}-%{release}
# Removed dep on Xconfigurator and changed to the actual Cards file instead
Requires: %{_x11datadir}/X11/Cards
# /usr/X11R6/include/X11/pixmaps/* moved from XFree86-devel to XFree86-xf86cfg
# in 4.3.0-3.8 so we need a Conflicts, however we don't build or ship it anyway
Conflicts: XFree86-devel < 4.3.0-3.8
Obsoletes: XFree86-xf86cfg

%description xf86cfg
X server configuration tool
%endif
######################################################################
%package Xvfb
Summary: A X Windows System virtual framebuffer X server.
Group: User Interface/X
Requires: %{name} = %{version}-%{release}
Obsoletes: XFree86-Xvfb
Provides: Xvfb

%description Xvfb
Xvfb (X Virtual Frame Buffer) is an X server that is able to run on
machines with no display hardware and no physical input devices.
Xvfb simulates a dumb framebuffer using virtual memory.  Xvfb does
not open any devices, but behaves otherwise as an X display.  Xvfb
is normally used for testing servers.
######################################################################
%if %{with_sdk}
%package sdk
Summary: SDK for X server driver module development
Group: User Interface/X
#Prereq: no idea what prereqs we need yet.
Obsoletes: XFree86-sdk
#Provides: XFree86-sdk = 4.4.0

%description sdk
The SDK package provides the developmental files which are necessary for
developing X server driver modules, and for compiling driver modules
outside of the standard X11 source code tree.  Developers writing video
drivers, input drivers, or other X modules should install this package.
%endif
##########  PREP  ###################################################
%prep
%setup -q -c

##########  PATCH  ##################################################
chmod 444 xc/config/cf/xfree86.cf
# xc/config/cf/xfree86.cf.OBSOLETE-USE-xorg.cf-INSTEAD
#%patch0 -p0 -b .xf-4_3-branch

%if %{with_new_savage_driver}
{
   echo "Updating SAVAGE driver with %{SOURCE14}"
   pushd xc/programs/Xserver/hw/xfree86/drivers
   mv savage savage-4.3.0
   tar zxvf %{SOURCE14}
   popd
}
%endif

%if %{with_fastbuild}
%patch9 -p0 -b .makefile-fastbuild
%endif

%patch1213 -p0 -b .radeon-ia64-preint10
%patch1214 -p0 -b .radeon-disable-VideoRAM-option

%if %{build_rhel4}
%patch1215 -p0 -b .ati-radeon-disable-dri
%endif

# FIXME: Chips & technologies -  Disable these two for now, to see if the
# problems are resolved that these two worked around.
# mharris - Jul 15, 2004
#%patch1300 -p0 -b .chips-default-to-noaccel-on-69000
#%patch1301 -p0 -b .chips-default-to-swcursor-on-65550

######################################################################
%patch2022 -p1 -b .agpgart-load

# FIXME: patch doesn't apply to xorg-x11.  It may be that it is not needed
# anymore due to being fixed in an alternate way, or it may still be needed,
# and needs a minor tweak to apply. We disable it for now until we find
# someone with a netmouse affected by this problem.
#%patch9007 -p0 -b .netmouse
%patch9013 -p0 -b .make-icondir-configurable

# These two can be merged into one later.
%patch9015 -p0 -b .IncludeSharedObjectInNormalLib
%patch9016 -p0 -b .libfontenc-IncludeSharedObjectInNormalLib

# Fixes from Daniel Stone's Debian debs
# FIXME: This needs to be investigated for xorg-x11 packaging and fixed/updated
#%patch9028 -p0 -b .028_fbdev_depth24_support
%patch9031 -p0 -b .dont-install-Xcms.txt
# Don't build these apps if all of them are disabled
%if ! %{with_xedit}%{with_xman}%{with_xmh}
# FIXME: This needs to be investigated for xorg-x11 packaging and fixed/updated
#%patch9111 -p0 -b .disable-building-apps-we-do-not-ship
%endif
# FIXME: This needs to be investigated for xorg-x11 packaging and fixed/updated
#%patch9120 -p0 -b .ia64-new-elfloader-relocations

%patch9163 -p0 -b .XRes-IncludeSharedObjectInNormalLib
# FIXME: This needs to be investigated for xorg-x11 packaging and fixed/updated
#%patch9181 -p0 -b .keyboard-disable-ioport-access-v3
%patch9184 -p0 -b .Xserver-increase-max-pci-devices
%patch9187 -p0 -b .AMD64-override-default-driverlist

%patch9204 -p0 -b .ia64-pci-infinite-loop
# FIXME: This needs to be investigated for xorg-x11 packaging and fixed/updated
#%patch9208 -p0 -b .ia64-drm-locking

%patch9306 -p0 -b .fix-BuildXFree86ConfigTools
# FIXME: No longer applies to 6.8.0 cvs development.  Not important patch,
# so no major urge to port it forward.
#%patch9307 -p0 -b .xterm-make-optional
%patch9309 -p0 -b .libxf86config-monitor-freq-fix
%patch9310 -p0 -b .Imake-add-BuildFontDevelUtils-macro
%patch9312 -p0 -b .libXdmcp-build-with-PIC
%patch9317 -p0 -b .init-origins-fix
%patch9319 -p0 -b .nls-indic-locales
%patch9321 -p0 -b .ia64-hp-zx2-support-bug-119364
%patch9323 -p0 -b .lnxLib-tmpl-sharedlibreq-fixes
%patch9324 -p0 -b .composite-gravity.patch
%patch9326 -p0 -b .ati-radeon-disable-broken-renderaccel-by-default
%patch9327 -p0 -b .ati-radeon-gcc4-fix
%patch9328 -p0 -b .fix-font-crash.patch
%patch9329 -p0 -b .xnest-shape-fix.patch
%patch9330 -p0 -b .config-StaticNeedsPicForShared
%patch9331 -p0 -b .XScreenSaverQueryInfo-crash-fix
%patch9333 -p0 -b .xpm-security-fix-CAN-2005-0605
%patch9334 -p0 -b .xorg.conf.man-dont-refer-to-nonexisting-example

%patch9335 -p0 -b .ati-radeon-dynamic-clocks-fix-2
%patch9336 -p0 -b .xorg-x11-6.8.2-ati-ragexl-ia64-avoidcpiofix.patch
%patch9337 -p0 -b .use-linux-native-pciscan-by-default

# EXPERIMENTAL PATCHES intended strictly for fedora-devel (FC4 currently)
%if %{build_fc4}

%patch9500 -p0 -b .deassert-ddc-lines
%patch9501 -p0 -b .laptop-modes.patch
%patch9502 -p0 -b .xorg-x11-6.8.2-xft-releasefile-crash

# Patches nominated for 6.8.3 in upstream bugzilla
%patch9700 -p0 -b .alpha-srel32-fix-fdo1765-2174
%patch9701 -p0 -b .canonicalize-builderaddr-1-fdo2884-2293
%patch9702 -p0 -b .cursor-flicker
%patch9705 -p0 -b .iso8859-compose-files-fdo2592-2156
%patch9706 -p0 -b .lbxproxy-fdo2678-2051
%patch9707 -p0 -b .nv-hw-fdo2533-1896
%patch9708 -p0 -b .nv-patch-fdo2380-1752
%patch9709 -p0 -b .radeon-cursor-sync-fdo2844-2230
%patch9710 -p0 -b .radeon-render-byteswap-fdo2164-1863
%patch9711 -p0 -b .radeon-set-fb-location-fdo2698-2079
%patch9712 -p0 -b .saver-c-fdo2194-1613
%patch9713 -p0 -b .uname-fdo2123-1587
%patch9714 -p0 -b .void-fdo2467-1828
%patch9716 -p0 -b .xnest-fdo2599-1964
%patch9717 -p0 -b .xorgcfg-typo-fdo2896-2311
%patch9718 -p0 -b .xset-fdo2258-2166
%patch9719 -p0 -b .battle-libc-wrapper
%patch9720 -p0 -b .gcc4-fix
%endif

########################################################################
# Red Hat custom patches
%patch10000 -p0 -b .redhat-custom-startup
%if %{build_rhel4}
%patch10001 -p0 -b .redhat-custom-modelines
%endif
# By default, we remove the default X server grey stipple pattern.
%patch10002 -p0 -b .redhat-die-ugly-pattern-die-die-die
# FIXME: This needs to be investigated for xorg-x11 packaging and fixed/updated
#%patch10005 -p0 -b .redhat-bug-report-address-update

# FIXME: These need to be updated for Xorg-x11 at some point
#%patch10007 -p0 -b .redhat-version-change-notification

# FIXME: This patch needs to be ported to *MESA* CVS, and included there
#        *FIRST*, before being submitted to X.Org at all.
#%patch10012 -p0 -b .redhat-libGL-exec-shield-fixes
%patch10015 -p0 -b .redhat-nv-riva-videomem-autodetection-debugging

#%patch10020 -p0 -b .redhat-fontconfig-2.1-slighthint
%patch10022 -p0 -b .redhat-embeddedbitmap
# FIXME: This needs to be investigated for xorg-x11 packaging and fixed/updated
#%patch10023 -p0 -b .redhat-exec-shield-GNU-stack

%patch20002 -p0 -b .sessreg-highuid
# FIXME: This may not be needed any more.  We can leave it disabled and get
#        some tdfx users to hammer on it.  If no problems arise, we'll leave
#        it disabled.
#%patch20004 -p0 -b .tdfx-disable-dri-on-16Mb-cards-in-hires
# FIXME: This needs to be investigated for xorg-x11 packaging and fixed/updated
#        Also, mkfontscale, and possibly other utilities should be examined as well.
#%patch20005 -p0 -b .mkfontdir-perms
# Do not build the xcursor cursors as we do not ship them anyway
%if %([ '%{with_whiteglass}' -eq '0' -a '%{with_redglass}' -eq '0' -a '%{with_handhelds}' -eq '0' ] && echo 1 || echo 0)
%patch20007 -p0 -b .redhat-xcursorgen-do-not-build-included-cursors
%endif


######################################################################
#####  CREATE host-$arch.def  ##############################################
pwd
%if %{build_mharris}
%define rhstr Build Maintainer custom build (%(whoami)@%(hostname -f))
%endif
%if %{build_fc2}
%define rhstr Fedora Core 2
%endif
%if %{build_fc3}
%define rhstr Fedora Core 3
%endif
%if %{build_fc4}
%define rhstr Fedora Core 4 Developmental build
%endif
%if %{build_rhel4}
%define rhstr Red Hat Enterprise Linux v.4
%endif

%if %{rhbsys}
%define vendorstring %{rhstr}
%else
%define vendorstring Unsupported Custom Build by %(whoami)
%endif

# FIXME: Hack to remove -g from RPM_OPT_FLAGS until XFree86 can be built
# with new rpm/gdb -debuginfo goodness
export RPM_OPT_FLAGS=${RPM_OPT_FLAGS//-g/}
%if %{with_fortify_source}
export RPM_OPT_FLAGS="${RPM_OPT_FLAGS} -D_FORTIFY_SOURCE=2"
%endif

# Copy our static architecture independant host.def into place
cp %{SOURCE1} xc/config/cf/
echo -e "\n\nGenerating architecture specifc host-%{_arch}.def file.\n\n"

cat > xc/config/cf/host-%{_arch}.def << EOF
#define XFree86CustomVersion "%vendorstring: %{version}-%{release}"
/* Experimental custom messages */
#define XFree86RedHatCustom	YES

#define BuilderString "Build Host: %(hostname -f)\n"
#define LinuxDistribution	LinuxRedHat
    
#define BuildDebug		%{debug_build}
/* #define XFree86Devel		%{debug_build} */

%if %{with_debuglibs}
#define DebuggableLibraries	YES
%endif

#define BootstrapCFlags         $RPM_OPT_FLAGS -pipe

/* Add -Wa,--noexecstack to AsCmd, in order to force all assembler files to
 * use GNU stacks.  This was accomplished in an alternative way in our XFree86
 * packaging via XFree86-4.3.0-redhat-exec-shield-GNU-stack.patch, which
 * patched every assembler file to add a .note.GNU-stack section, which is
 * considered a superior solution, but our patch was non-portable to non-GNU
 * systems.  This is a cleaner hack for now.
 *      -- Mike A. Harris <mharris@redhat.com>
 */
#define AsCmd                   CcCmd -c -x assembler -Wa,--noexecstack

/* FIXME: Remove -fno-strength-reduce and GccAliasingArgs after confirming
 * upstream that they are not needed for anything on Linux
 */
%if %{with_savetemps}
#define DefaultGcc2i386Opt      $RPM_OPT_FLAGS GccAliasingArgs -save-temps
#define DefaultGcc2x86_64Opt    $RPM_OPT_FLAGS GccAliasingArgs -save-temps
#define DefaultGcc2AxpOpt       $RPM_OPT_FLAGS GccAliasingArgs -save-temps -Wa,-m21164a
#define DefaultGcc2PpcOpt       $RPM_OPT_FLAGS GccAliasingArgs -save-temps
#define DefaultGcc2Ppc64Opt     $RPM_OPT_FLAGS GccAliasingArgs -save-temps
%else
#define DefaultGcc2i386Opt      $RPM_OPT_FLAGS GccAliasingArgs -pipe
#define DefaultGcc2x86_64Opt    $RPM_OPT_FLAGS GccAliasingArgs -pipe
#define DefaultGcc2AxpOpt       $RPM_OPT_FLAGS GccAliasingArgs -pipe -Wa,-m21164a
#define DefaultGcc2PpcOpt       $RPM_OPT_FLAGS GccAliasingArgs -pipe
#define DefaultGcc2Ppc64Opt     $RPM_OPT_FLAGS GccAliasingArgs -pipe
%endif

#define MakeDllModules		%{with_dll_modules}

%if %{parallel_build}
#define ParallelMakeFlags	-j%(getconf _NPROCESSORS_ONLN)
/* This one seems to not work properly on GLU gosh darned it, possibly a
 * conflict with HJL's patch */
/* #define HasParallelMake	YES */
%endif

%if %{with_alternate_projectroot}
/* FIXME: Building rpms with ProjectRoot set is highly experimental right now
 *        and probably does not work at all as long as you see this warning
 *        still here.  It is a feature intended mostly for myself, but also
 *        for other developers doing development.  It is not, and never will
 *        be intended for use by end users, and wont ever be supported for
 *        parallel installation by end users.  Use entirely at own risk, and
 *        expect that your OS may be totally screwed up if you install rpms
 *        built for an alternate ProjectRoot.  Having said that, if anyone
 *        does try it out, feel free to send patches to the spec file, etc.
 *        that fix things.  ;o)  -  mharris (Jan 26, 2005)
#define ProjectRoot			%{_projectroot}
#define NothingOutsideProjectRoot 	YES
/* EtcX11Directory might be set automatically by Imake now, I should test if
 * this needs to be set manually still or not - mharris
 */
#define EtcX11Directory			ProjectRoot/etc
%endif

%if ! %{with_Xserver}
#define XorgServer			NO
%endif
#define BuildServer			YES
#define XVirtualFramebufferServer	YES
#define XnestServer			YES

/* Make xtrans fail gracefully by default, for bug #129622 and others */
#define XtransFailSoft		YES

/* We want includes in %{_includedir}/GL, so we move them there later on
 * because the LinkGLToUsrInclude option makes the GL subdirectory a symlink,
 * which is bad for RPM packaging as other packages may place files there,
 * plus there's the whole rpm replacing a symlink with a dir, etc. thing.
 */
#define LinkGLToUsrInclude	NO

/* The OpenGL ABI on Linux standard states libGL and libGLU must be present in
 * /usr/lib either directly, or as symlinks.  The supplied Imake config option
 * LinkGLToUsrLib makes absolute symlinks rather than relative ones, so it is
 * not suitable for us to use.
 */
#define LinkGLToUsrLib		NO
/* LinkGLToUsrInclude makes an absolute symlink to the _x11includedir, which
 * essentially makes %{_libdir}/GL a symlink, which is messy, and may conflict
 * with other package's files that may be installed in the GL include dir for
 * whatever reason.  We disable this option for now, and handle things
 * ourselves with a bit of scripting in the spec file.
 */
#define LinkGLToUsrInclude	NO
#define BuildGLwLibrary		YES
#define ForceNormalLib		YES

/* Disable joystick support because it is totally broken */
#define JoystickSupport		NO


/* FIXME: MOST of the HasXXXXXX defines below can be discarded when we update
 * to the X.org X11 tree, because linux.cf sets defaults for them on the
 * Linux platform.  I need to check and ensure the new defaults match what
 * we expect.   -- mharris
 */

/* FIXME: This should be defaulted upstream correctly, or patched and sent
 * upstream, and then removed from our specfile.
 */
%ifarch s390 s390x ppc64
#define HasAgpGart              NO
%else
#define HasAgpGart              YES
%endif

/* FIXME: HasFontconfig is broken so we have to use UseFontconfig
 * Update: This appears to work now (4.3.0-11.2), so HasFontconfig is being used
 * experimentally in rawhide now.  HasExpat can probably be removed if this works out.
 */
%if ! %{with_fontconfig}
#define HasFontconfig		YES
%endif

/* Expat is only needed by fontconfig (4.3.0) */
#define HasExpat		YES
#define HasFreetype2		YES
#define HasPam			YES
#define HasPamMisc		YES
#define HasZlib			YES

%if %{with_bail_on_undef_syms}
/* FIXME: This should be more configureable in stock Imake configs.  The
 * default SharedLibraryLoadFlags in 4.3.0 is merely "-shared", however
 * I'm adding "-Wl,-z,defs" upon Jakub's recommendation as it should cause
 * ld to bail if there are undefined symbols at link time.
 *
 * Additional information:  This is useful for test builds, to find missing
 * deps over time and fix them, however there are some really screwed up
 * things in the tree, which have never listed deps right as far as I can
 * see.  Also, the X server doesn't like being built like this I'm told by
 * Gentoo developers who have tried this before too.  Hopefully we can work
 * towards a sane build with this enabled at some point.  Here is a reference
 * bug from Gentoo:  http://bugs.gentoo.org/show_bug.cgi?id=49038
 */
#define SharedLibraryLoadFlags	-shared -Wl,-z,defs
%endif

#define HasDevRandom            YES
#define HasLinuxInput		YES

#define HasGlide3		%{Glide3Require}
%if %{Glide3Require}
#define Glide3LibName		glide3
#define Glide3IncDir		%{_includedir}/glide3
%endif

%if %{with_fonts}
#define BuildFonts              YES
#define BuildSpeedoFonts        NO
#define BuildCyrillicFonts      YES
#define BuildBethMarduthoFonts	YES
/* #define BuildISO8859_1Fonts     YES */
#define BuildISO8859_2Fonts	YES
#define BuildISO8859_3Fonts	NO
#define BuildISO8859_4Fonts	NO
#define BuildISO8859_5Fonts	BuildCyrillicFonts
/* #define BuildISO8859_6Fonts	NO  */
#define BuildISO8859_7Fonts	YES 
/* #define BuildISO8859_8Fonts	NO  */
#define BuildISO8859_9Fonts	YES
#define BuildISO8859_10Fonts	NO
#define BuildISO8859_11Fonts	NO
#define BuildISO8859_12Fonts	NO
#define BuildISO8859_13Fonts	NO
#define BuildISO8859_14Fonts	YES
#define BuildISO8859_15Fonts	YES
#define BuildISO8859_16Fonts	NO
%else
#define BuildFonts              NO
/* ucs2any and bdftruncate */
#define BuildFontDevelUtils	YES
%endif

#define InstallXcmsTxt          NO
#define BuildXF86MiscExt        YES
#define BuildHtmlManPages       NO

/* FIXME: This is commented out, in order to test XFree86's Imake DRI defaults
 * for each architecture.  Once confirmed all DRI capable archs build, we can
 * remove this, for a cleaner environmentally friendly host.def
 * YES=1 in Imake.tmpl and NO=0 so we can just use with_DRI here
 */
#define BuildXF86DRI		%{with_DRI}
#define BuildXF86DRM            NO

/* Do not build config tools if we are not shipping them anyway */
%if ! %{with_xf86cfg}%{with_xf86config}
#define BuildXFree86ConfigTools NO
%endif

/* This disables building of libXaw 8, since we only ship Xaw 6 and 7 for
 * legacy application compatibility.
 */
#define BuildXaw		NO

%if ! %{with_xprint}
#define BuildXprint		NO
#define BuildXprintClients	NO
/* OpenMotif and Java currently use libXp, as well as some other stuff.  We
 * are currently shipping libXp for compatibility, but consider it deprecated,
 * and we plan to remove it entirely in a future OS release, after a
 * reasonable migration period to give 3rd parties time to migrate their apps
 * to libgnomeprint and libgnomeprintui.
 */
#define BuildXprintLib		YES
%endif

#define BuildXterm		%{with_xterm}

/* FIXME: We don't need this anymore? */
#define UseXserverWrapper       YES

#define UseUtempter             YES
#define UseInternalMalloc       NO
#define UseMatroxHal            NO

/* FIXME: Other distros set these to yes.  Should we do this soon too?  */
#define UseConfDirForXkb           NO
#define UseConfDirForAppDefaults   NO

#undef  DefaultUserPath
#define DefaultUserPath		/usr/local/bin:/bin:/usr/bin
#undef  DefaultSystemPath
#define DefaultSystemPath	/usr/local/sbin:/sbin:/usr/sbin:/bin:/usr/bin

/* We default to the Red Hat Bluecurve(TM) cursor theme, but if it isn't
 * installed, X will fallback to core cursors, so no forced dependancy is
 * required.
 */
#define DefaultCursorTheme	Bluecurve

/* FIXME: Check and see if we actually need this junk still, or if Imake
 * defaults are ok now. */
#define AdmDir              /var/log
#define LbxproxyDir         /etc/X11/lbxproxy
#define ProxyManagerDir     /etc/X11/proxymngr
#define ServerConfigDir     /etc/X11/xserver
#define XdmDir              /etc/X11/xdm
#define XConfigDir          /etc/X11
#define XinitDir            /etc/X11/xinit

/* Do not override video drivers for Alpha architecture any more, because
 * we do not have officially supported Red Hat OS products for Alpha.  Let's
 * just use the default driverset instead.
 * %ifarch alpha
 * #define XF86CardDrivers mga nv tga sis rendition \
 *			i740 tdfx cirrus tseng \
 *			fbdev ati vga v4l glint
 * %endif
 */

/* https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=112175
 * This should probably be ifnarch %{ix86} instead of ifarch ia64, but we'll
 * leave it this way for the time being.   mharris@redhat.com
 */
%ifarch ia64
#define ATIAvoidNonPCI YES
%endif

%ifarch ia64
#define XF86CardDrivers mga nv tdfx v4l fbdev glint ati vga 
%endif

#define DriverManDir    \$(MANSOURCEPATH)4
#define DriverManSuffix 4x /* use just one tab or cpp will die */
#define MiscManDir      \$(MANSOURCEPATH)7
#define MiscManSuffix   7x /* use just one tab or cpp will die */

EOF

##########  BUILD  ##################################################
%build
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf "$RPM_BUILD_ROOT"
# Speed up script processing
export LANG=C
# Make sure RPM_BUILD_DIR does not contain any CVS dirs prior to building
find "$RPM_BUILD_DIR" -name CVS -type d | xargs rm -rf

%if %{debug_build}
makeg World -C xc FAST=1
%else
make World -C xc FAST=1
%endif

##########  INSTALL  #################################################
%install
# Speed up script processing
export LANG=C

# Enable set -x if verbose_build is enabled
%{!?verbose_build:set -x}
make -C xc DESTDIR=$RPM_BUILD_ROOT install install.man
%if %{with_sdk}
make -C xc DESTDIR=$RPM_BUILD_ROOT install.sdk
%endif
# install the host-$arch.def config file
install -m 644 xc/config/cf/host-%{_arch}.def $RPM_BUILD_ROOT%{_x11datadir}/X11/config/

# FIXME: These mkdirs might be removable now
mkdir -p $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT%{_includedir}
# Install pam related files
{
    mkdir -p $RPM_BUILD_ROOT/etc/{pam.d,security/console.apps}
    install -c -m 644 %{SOURCE3} $RPM_BUILD_ROOT/etc/pam.d/xserver
    install -c -m 644 %{SOURCE4} $RPM_BUILD_ROOT/etc/pam.d/xdm
    touch $RPM_BUILD_ROOT/etc/security/console.apps/xserver
}
# Move OpenGL includes in %{_includedir}/GL instead of the default location,
# because the OpenGL ABI for Linux dictates that the OpenGL includes must be
# in /usr/include/GL.  The Imake LinkGLToUsrInclude would theoretically work,
# however that makes /usr/include/GL a symlink to the default X directory,
# which isn't particularly useful, and can cause rpm directory/symlink upgrade
# problems when switching from one OpenGL implementation to another.  The
# best longer term fix for this, is to add a new InstallGLToUsrInclude Imake
# option which does exactly what we're doing below, as there's no useful
# reason to have the includes in 2 locations really, especially on Linux
# systems.  Additionally InstallGLToUsrInclude once implemented, should be
# enabled by default.
# FIXME: Implement imake InstallGLToUsrInclude option
{
    mkdir -p $RPM_BUILD_ROOT/%{_includedir}/GL
    mv $RPM_BUILD_ROOT%{_x11includedir}/GL/* $RPM_BUILD_ROOT/%{_includedir}/GL/
    rmdir $RPM_BUILD_ROOT%{_x11includedir}/GL
}
# Explicitly create XDM authdir
mkdir -m 700 -p $RPM_BUILD_ROOT/var/lib/xdm/authdir

mkdir -p $RPM_BUILD_ROOT%{_libdir}/pkgconfig

# Install the Red Hat xfs config file and initscript
mkdir -p $RPM_BUILD_ROOT/etc/{X11/fs,rc.d/init.d}
install -c -m 644 %{SOURCE6} $RPM_BUILD_ROOT/etc/X11/fs/config
install -c -m 755 %{SOURCE5} $RPM_BUILD_ROOT/etc/rc.d/init.d/xfs
# Patch xfs.init to start earlier for gdm early login in FC4:
# Disabled because it breaks NFS /usr (#156413)
#%if %{build_fc4}
#pushd $RPM_BUILD_ROOT/etc/rc.d/init.d
#patch -p0 < %{PATCH20008}
#popd
#%endif

# FIXME: Can Imake do this?  Fix up symlinks
{
    ln -sf ../X11R6/include/X11 $RPM_BUILD_ROOT%{_includedir}/X11
    ln -sf ../X11R6/include/DPS $RPM_BUILD_ROOT%{_includedir}/DPS
}
# Backward compatibility symlink
ln -sf ../..%{_x11datadir}/X11/xkb $RPM_BUILD_ROOT/etc/X11

# Create ld.so.conf include file
mkdir -p $RPM_BUILD_ROOT/etc/ld.so.conf.d
echo %{_x11libdir} > $RPM_BUILD_ROOT/etc/ld.so.conf.d/xorg-x11-%{_arch}.conf

# Symlink shared libs
{
    pushd $RPM_BUILD_ROOT%{_x11libdir}
    for lib in *.so.*; do ln -sf $lib ${lib%.so*}.so ; done
    popd
    for lib in libGL.so libGL.so.1 libGLU.so libGLU.so.1 ; do
        ln -sf ../..%{_x11libdir}/$lib $RPM_BUILD_ROOT%{_libdir}/$lib
    done
}

# Create various ghost files, needed by RPM when packaging
{
    # Make ghost X server config files
    # FIXME: The XF86Config and XF86Config-4 files are for legacy compat with
    # XFree86, and may cease to function or be removed at any time.
    for configfile in xorg.conf XF86Config XF86Config-4 ; do
        touch $RPM_BUILD_ROOT/etc/X11/$configfile
    done
%if %{with_fonts}
    # Make ghost fonts.alias, fonts.dir, encodings.dir files
    FONTDIR=$RPM_BUILD_ROOT%{_x11fontdir}
    touch $FONTDIR/{OTF,TTF}/fonts.alias
    for subdir in 100dpi 75dpi CID local misc Type1 TTF cyrillic ; do
        rm -f $FONTDIR/$subdir/{encodings,fonts}.dir
        touch $FONTDIR/$subdir/{encodings,fonts}.dir
        chmod 0644 $FONTDIR/$subdir/{encodings,fonts}.dir
    done
%endif

    # Remove fonts which contain bad codepoints, as documented in bug #97591
    rm -f $RPM_BUILD_ROOT%{_x11fontdir}/OTF/SyrCOMCtesiphon.otf
    rm -f $RPM_BUILD_ROOT%{_x11fontdir}/OTF/SyrCOMKharput.otf
    rm -f $RPM_BUILD_ROOT%{_x11fontdir}/OTF/SyrCOMMalankara.otf
    rm -f $RPM_BUILD_ROOT%{_x11fontdir}/OTF/SyrCOMMidyat.otf
    rm -f $RPM_BUILD_ROOT%{_x11fontdir}/OTF/SyrCOMQenNeshrin.otf
    rm -f $RPM_BUILD_ROOT%{_x11fontdir}/OTF/SyrCOMTurAbdin.otf
    rm -f $RPM_BUILD_ROOT%{_x11fontdir}/OTF/SyrCOMUrhoyBold.otf
    rm -f $RPM_BUILD_ROOT%{_x11fontdir}/OTF/SyrCOMUrhoy.otf
}

# Make sure all manpage dirs exist
mkdir -m 755 -p $RPM_BUILD_ROOT%{_x11mandir}/man{1,2,3,4,5,6,7,8} || :
# Install split-out rpm changelog history
install -m 644 %{SOURCE25} xc/doc/hardcopy/
#install -m 644 %{SOURCE25} $RPM_BUILD_ROOT%{_x11datadir}/X11/doc/

# Fix permissions on locale/common/*.so libs
# FIXME: (CVS X doesn't have this dir, it is locale/lib/common now
#chmod 755 $RPM_BUILD_ROOT%{_x11localedir}/common/*.so.*

# Install mkxauth
{
    install -m 755 %{SOURCE23} $RPM_BUILD_ROOT%{_x11bindir}/
    install -m 644 %{SOURCE24} $RPM_BUILD_ROOT%{_x11mandir}/man1/
}
# Ugly hack to architecturally genericize xft-config and gccmakedep using
# my archexec script
{
    pushd $RPM_BUILD_ROOT/%{_x11bindir}
    # install archexec
%if %{with_archexec}
    install -m 755 %{SOURCE10} .
%endif

    for script in gccmakedep xft-config ; do
        mv $script $script-%{_arch}
        ln -s archexec $script
    done
    popd
}
# Copy CHANGELOG document into place for %%doc directive to find
cp xc/programs/Xserver/hw/xfree86/CHANGELOG .
# Create file list for SDK, because the list of files/dirs differs greatly
# depending on architecture, and RPM doesn't allow nested conditionals.
# FIXME: This should probably move up to where make install.sdk is called
%if %{with_sdk}
{
    SDKDIR=$RPM_BUILD_ROOT/%{_x11libdir}/Server
    # Remove stuff that is not really useful to have in the SDK as it is
    # duplicated in the sources, and not necessary for compiling external
    # driver modules
    {
        # Remove Xorg driver sourcecode
        rm -rf $SDKDIR/drivers
        # Remove duplicate copy of Xorg X server binary
        rm $SDKDIR/Xorg
        # Remove precompiled driver binaries
        rm -rf $SDKDIR/modules/{drivers,input}
        # There's probably more that can be removed here, but this is a good
        # start for now.
    }

    # Find the directories first
    find $SDKDIR -type d | sort | \
        sed -e "s#.*$RPM_BUILD_ROOT/%{_x11libdir}#%dir %%{_x11libdir}#g" > filelist.sdk
    # Append the files
    find $SDKDIR ! -type d | sort | \
        sed -e "s#.*$RPM_BUILD_ROOT/%{_x11libdir}#%%{_x11libdir}#g" >> filelist.sdk
    # Add the filelist.sdk itself to itself and install it
    echo %%{_x11libdir}/Server/filelist.sdk >> filelist.sdk
    cp filelist.sdk $RPM_BUILD_ROOT/%{_x11libdir}/Server/filelist.sdk
}
%endif
# FIXME: This needs to be fixed up to only ship on supported architectures
{
   touch filelist.%{name}
   # Include new I/O utils for architectures that they work on
   for file in inb inl inw ioport outb outl outw ; do
      if [ -x $RPM_BUILD_ROOT/%{_x11bindir}/$file ] ; then
         echo %%{_x11bindir}/$file >> filelist.%{name}
      fi
   done
}

# Move pkgconfig files to proper location in _libdir
# FIXME: Redo this with Imake and submit patch upstream
{
   mv $RPM_BUILD_ROOT%{_x11libdir}/pkgconfig/* $RPM_BUILD_ROOT%{_libdir}/pkgconfig/
   rmdir $RPM_BUILD_ROOT%{_x11libdir}/pkgconfig
}


######################################################################
# STRIP SECTION - must come just before DELETE UNWANTED FILES section
# strip the stuff that's safe to strip
%if ! %{debug_build}
{
#    set +x
    # Strip ELF binary executables of debug symbols and .comment section
    for file in $(find $RPM_BUILD_ROOT -type f -perm +0111 -exec file {} \; | \
                    grep -v ' shared object,' | \
                    sed -n -e 's/^\(.*\):[  ]*ELF.*, not stripped/\1/p')
    do
	# strip wont take both of these on one commandline for some reason
        strip --strip-debug $file || :
        strip -R .comment $file || :
    done
    # Strip shared libraries of .comment section, and all unneeded symbols
    # strip wont take both of these on one commandline for some reason
    strip --strip-unneeded	$RPM_BUILD_ROOT%{_x11libdir}/*.so.* || :
    strip -R .comment		$RPM_BUILD_ROOT%{_x11libdir}/*.so.* || :
    strip --strip-unneeded	$RPM_BUILD_ROOT%{_libdir}/*.so.* || :
    strip -R .comment		$RPM_BUILD_ROOT%{_libdir}/*.so.* || :
# Enable this only after testing and verifying it works properly
    strip --strip-unneeded $RPM_BUILD_ROOT%{_x11localedir}/%{_lib}/common/*.so.* || :
    strip -R .comment $RPM_BUILD_ROOT%{_x11localedir}/%{_lib}/common/*.so.* || :
}
%endif

# Cleanup documentation mess
{
    pushd xc/doc/hardcopy
    # We ship xterm in separate packaging, and don't ship rstart
    rm -rf {xterm,rstart}
    # Junk
    rm Imakefile Makefile
    # Compress Xv docs:
    gzip -9 Xv/xv-protocol-v2.PS
    # XKB docs are included twice for some reason
    {
        pushd XKB
        # Remove uncompressed .ps files
        rm *.ps
        # Remove PS.gz symlinks
        [ -L XKBlib.PS.gz ] && rm XKBlib.PS.gz
        [ -L XKBproto.PS.gz ] && rm XKBproto.PS.gz
        # Rename lowercase .ps.gz to .PS.gz for consistency with other docs
        mv XKBlib.ps.gz XKBlib.PS.gz
        mv XKBproto.ps.gz XKBproto.PS.gz
        popd
    }
    # Xprint docs install junk files
    {
        pushd XPRINT
        rm docbook.css dtprint_fspec.ps Imakefile Makefile
        popd
    }
    popd
}

######################################################################
# DELETE UNWANTED FILES SECTION - must come after all else
# error: Installed (but unpackaged) file(s) found:
{
%if ! %{with_redglass}
   rm -rf $RPM_BUILD_ROOT/%{_x11icondir}/redglass
%endif
%if ! %{with_whiteglass}
   rm -rf $RPM_BUILD_ROOT/%{_x11icondir}/whiteglass
%endif
%if ! %{with_handhelds}
   rm -rf $RPM_BUILD_ROOT/%{_x11icondir}/handhelds
%endif
%if ! %{with_fontconfig}
   rm -rf $RPM_BUILD_ROOT/etc/fonts $RPM_BUILD_ROOT/%{_x11includedir}/fontconfig
   rm -f $RPM_BUILD_ROOT%{_x11bindir}/{fc-cache,fc-list,fontconfig-config}
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man1/{fc-cache,fc-list}.1*
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man3/fontconfig.3*
   rm -f $RPM_BUILD_ROOT%{_x11libdir}/libfontconfig.*
%endif
%if ! %{with_rstart}
   rm -rf $RPM_BUILD_ROOT/etc/X11/rstart
   rm -rf $RPM_BUILD_ROOT%{_x11datadir}/X11/rstart 
   rm -f $RPM_BUILD_ROOT%{_x11bindir}/rstart*
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man1/rstart*.1*
%endif
%if ! %{with_xedit}
   rm -rf $RPM_BUILD_ROOT%{_x11datadir}/X11/xedit
   rm -f $RPM_BUILD_ROOT%{_x11bindir}/xedit
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man1/xedit.1*
%endif
%if ! %{with_xman}
   rm -f $RPM_BUILD_ROOT%{_x11bindir}/xman
   rm -f $RPM_BUILD_ROOT%{_x11datadir}/X11/xman*
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man1/xman.1*
%endif
%if ! %{with_xf86cfg}
   rm -f $RPM_BUILD_ROOT%{_x11bindir}/xf86cfg
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man1/xf86cfg.1*
%endif
%if ! %{with_xf86config}
   rm -f $RPM_BUILD_ROOT%{_x11bindir}/xf86config
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man1/xf86config.1*
%endif
%if ! %{with_xmh}
   rm -f $RPM_BUILD_ROOT%{_x11bindir}/xmh
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man1/xmh.1*
%endif
# FIXME: Fix this by patching Imake configs and submit upstream (hack fix bug #49990)
%if ! %{with_libxrx}
   rm -f $RPM_BUILD_ROOT%{_x11libdir}/libxrx.*
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man1/libxrx.1*
%endif
%if ! %{with_sis_dri}
   rm -f $RPM_BUILD_ROOT/%{_x11libdir}/modules/dri/sis_dri.so
%endif
%if ! %{with_Xserver}
   rm -f $RPM_BUILD_ROOT/etc/X11/xorg.conf*
   rm -f $RPM_BUILD_ROOT/etc/X11/XF86Config*
   rm -r $RPM_BUILD_ROOT/etc/X11/xserver
   rm $RPM_BUILD_ROOT/%{_x11datadir}/X11/xserver
   # Added to remove X11/etc stuff on RHL 9 ppc/s390/s390x builds because we
   # don't ship products on those platforms anyway.
   rm -rf $RPM_BUILD_ROOT/%{_x11datadir}/X11/etc
   rm $RPM_BUILD_ROOT%{_x11bindir}/startx
   rm $RPM_BUILD_ROOT%{_x11bindir}/xinit
   rm $RPM_BUILD_ROOT%{_x11mandir}/man1/startx.1*
   rm $RPM_BUILD_ROOT%{_x11mandir}/man1/Xserver.1*
   rm $RPM_BUILD_ROOT%{_x11mandir}/man1/xinit.1*
%endif

# Remove i810 XvMC client library driver on architectures the video hardware
# doesn't exist on, only ship it on those it is.
%ifnarch %{ix86} ia64 x86_64
   rm -f $RPM_BUILD_ROOT%{_x11libdir}/libI810XvMC.*
%endif

%ifarch s390 s390x ppc ppc64
   rm -f $RPM_BUILD_ROOT%{_x11bindir}/mmapr
   rm -f $RPM_BUILD_ROOT%{_x11bindir}/mmapw
   rm -f $RPM_BUILD_ROOT%{_x11bindir}/pcitweak
   rm -f $RPM_BUILD_ROOT%{_x11bindir}/scanpci
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man1/pcitweak.1*
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man1/scanpci.1*
%endif

{
# rm/unlink example config files that we do not ship
   rm -f $RPM_BUILD_ROOT%{_x11datadir}/X11/XF86Config.{98,eg,indy}
   # The following are uncommented for the time being as I'm lazy.
   rm -f $RPM_BUILD_ROOT/etc/X11/xdm/GiveConsole
   rm -f $RPM_BUILD_ROOT/etc/X11/xdm/TakeConsole
   rm -f $RPM_BUILD_ROOT/etc/X11/xdm/Xaccess
   rm -f $RPM_BUILD_ROOT/etc/X11/xdm/Xsession
   rm -f $RPM_BUILD_ROOT/etc/X11/xdm/Xsetup_0
   rm -f $RPM_BUILD_ROOT/etc/X11/xdm/xdm-config
   rm -f $RPM_BUILD_ROOT/etc/X11/xinit/xinitrc
   rm -f $RPM_BUILD_ROOT%{_x11bindir}/ccmakedep
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man1/ccmakedep.1*
   # FIXME: X.org CVS includes the XDarwin manpage in Linux, duh
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man1/XDarwin.1*
   # Remove DRM sources from installed tree (new to xorg-x11)
   rm -rf $RPM_BUILD_ROOT%{_x11dir}/src
}

%ifarch ppc64 s390 s390x
   # XOrg X11 started including these on s390 for some odd reason
   rm -f $RPM_BUILD_ROOT%{_x11datadir}/X11/doc/PostScript/RX.ps
   rm -f $RPM_BUILD_ROOT%{_x11datadir}/X11/doc/PostScript/XKBlib.ps
   rm -f $RPM_BUILD_ROOT%{_x11datadir}/X11/doc/PostScript/XKBproto.ps
   rm -f $RPM_BUILD_ROOT%{_x11datadir}/X11/doc/PostScript/dtprint_fspec.ps
   rm -f $RPM_BUILD_ROOT%{_x11datadir}/X11/doc/Xprint_FAQ.txt
   rm -f $RPM_BUILD_ROOT%{_x11datadir}/X11/doc/html/Xprint_FAQ.html
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man4/aiptek.4x*
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man4/glide.4x*
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man4/newport.4x*
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man4/sunbw2.4x*
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man4/suncg14.4x*
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man4/suncg3.4x*
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man4/suncg6.4x*
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man4/sunffb.4x*
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man4/sunleo.4x*
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man4/suntcx.4x*
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man4/ur98.4x*
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man4/v4l.4x*
%endif
%if ! %{with_xprint}
   rm -f $RPM_BUILD_ROOT%{_x11includedir}/X11/XprintAppUtil/xpapputil.h
   rm -f $RPM_BUILD_ROOT%{_x11includedir}/X11/XprintUtil/xprintutil.h
   rm -f $RPM_BUILD_ROOT%{_x11libdir}/libXprintAppUtil.a
   rm -f $RPM_BUILD_ROOT%{_x11libdir}/libXprintUtil.a
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man7/Xprint.7x*
%endif
 {
   # Remove some legacy Xaw/Xt apps
   rm -f $RPM_BUILD_ROOT%{_x11bindir}/xbiff
   rm -f $RPM_BUILD_ROOT%{_x11bindir}/xditview
   rm -f $RPM_BUILD_ROOT%{_x11bindir}/xeyes
#   rm -f $RPM_BUILD_ROOT%{_x11bindir}/xmessage
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man1/xbiff.*
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man1/xditview.*
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man1/xeyes.*
#   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man1/xmessage.*
 }
 {
   # We ship bitstream vera in separate packaging.  This should probably be
   # turned off with an Imake define in the future, perhaps something like
   # "#define BuildFontsBitsreamVera NO" in host.def, will have to investigate.
   # FIXME
   rm -f $RPM_BUILD_ROOT%{_x11fontdir}/TTF/Vera*.ttf
   # Remove various Syriac fonts which contain bad codepoints (bug #97951)
   rm -f $RPM_BUILD_ROOT%{_x11fontdir}/OTF/SyrCOMCtesiphon.otf
   rm -f $RPM_BUILD_ROOT%{_x11fontdir}/OTF/SyrCOMKharput.otf
   rm -f $RPM_BUILD_ROOT%{_x11fontdir}/OTF/SyrCOMMalankara.otf
   rm -f $RPM_BUILD_ROOT%{_x11fontdir}/OTF/SyrCOMMidyat.otf
   rm -f $RPM_BUILD_ROOT%{_x11fontdir}/OTF/SyrCOMQenNeshrin.otf
   rm -f $RPM_BUILD_ROOT%{_x11fontdir}/OTF/SyrCOMTurAbdin.otf
   rm -f $RPM_BUILD_ROOT%{_x11fontdir}/OTF/SyrCOMUrhoyBold.otf
   rm -f $RPM_BUILD_ROOT%{_x11fontdir}/OTF/SyrCOMUrhoy.otf
 }

%if ! %{with_wacom_driver}
   rm -f $RPM_BUILD_ROOT%{_x11libdir}/modules/input/wacom_drv.o
   rm -f $RPM_BUILD_ROOT%{_x11mandir}/man4/wacom.4x.gz
%endif
}
###  DO NOT PUT ANYTHING PAST THIS POINT #############################

%check
# Post build integrity checks section

# Find dead symlinks and fail the build if there are any
%if %{with_dead_symlink_test}
echo "Checking for broken symlinks ... "
{
    pushd $RPM_BUILD_ROOT
    BROKEN_LINK=0
    for link in $(find . -type l) ; do
        if test ! -e $link ; then
            echo Broken symlink $link found
            BROKEN_LINK=1
        fi
    done
    if [ $BROKEN_LINK = 1 ] ;then
        echo 'Broken symlink(s) detected in build, aborting ...'
        exit 1
    fi
    popd
}
%endif

# Scan the RPM_BUILD_ROOT for applications and shared libs that are
# not properly linked to all of their dependancies.
%if %{with_undef_sym_test}
echo "Checking for undefined symbols in shared libs ... "
{
    EXIT_STATUS=0
    # Use ldd's -u option only if supported on this system
    LDD_OPTS="-r$(ldd -u 2>&1 | grep 'unrecognized option' &> /dev/null|| echo ' -u')"
    echo LDD_OPTS=$LDD_OPTS

    pushd $RPM_BUILD_ROOT%{_x11libdir}
    for file in $(find . -type f -maxdepth 1 -name "lib*.so.*") ; do
        echo "Checking $file for undefined references ... "
        if ldd $LDD_OPTS "$file" 2>&1 | grep undefined ; then
            echo -e "\n*** WARNING: $file contains undefined references, listed above ***"}
            EXIT_STATUS=1
        fi
    done
    popd

    [ $EXIT_STATUS -eq 1 ] && echo -e "\nERROR: Undefined symbols detected above, failing build."
    exit $EXIT_STATUS
}
%endif


######################################################################
#########  SCRIPT SECTION  ###########################################
######################################################################
%if %{with_rstart}
%define symlinkdirs	lbxproxy proxymngr rstart
%else
%define symlinkdirs	lbxproxy proxymngr
%endif

%pre
{ 
  pushd /etc/X11

  # Massage pre-existing config files to work properly with X.org X11
  # - Remove xie and pex5 modules from the config files, as they are long
  #   since obsolete, and not provided since XFree86 4.2.0
  # - Remove Option "XkbRules" "xfree86" to help work around upgrade problems
  #   such as https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=120858
  {
    for configfile in xorg.conf XF86Config XF86Config-4 ; do
      # FIXME: rewrite this all to use perl, if the XkbRules stuff below works out ok.
      if [ -r $configfile -a -w $configfile ]; then
	# Remove module load lines from the config file for obsolete modules
        perl -p -i -e 's/^.*Load.*"(pex5|xie|xtt).*\n$"//gi' $configfile
        # Change the keyboard configuration from the deprecated "keyboard"
	# driver, to the newer "kbd" driver.
        perl -p -i -e 's/Driver(.*)"keyboard"/Driver\1"kbd"/gi' $configfile
	# Remove any Options "XkbRules" lines that may be present
        perl -p -i -e 's/^.*Option.*"XkbRules".*"(xfree86|xorg)".*\n$//gi' $configfile
      fi
    done
  }

  # Migrate any pre-existing XFree86 4.x config file to xorg.conf if it
  # doesn't already exist, and rename any remaining XFree86 4.x congig files
  # to have .obsoleted file extensions, to help avoid end user confusion for
  # people unaware of the config file name change between server
  # implementations, and avoid bug reports.  If this turns out to confuse
  # users, I can modify it to add comments to the top of the obsoleted files
  # to point users to xorg.conf   <mharris@redhat.com>
  {
    for configfile in XF86Config-4 XF86Config ; do
      if [ -r $configfile ]; then
          if [ -r xorg.conf ]; then
              mv -f $configfile $configfile.obsoleted
          else
              mv -f $configfile xorg.conf
          fi
      fi
    done
  }
  popd

  # Do this for upgrades or installs
  XKB_DIR=%{_x11datadir}/X11/xkb/compiled
  if [ ! -L $XKB_DIR -a -d $XKB_DIR ]; then
    mkdir -p /var/lib/xkb
    mv -f $XKB_DIR /var/lib/xkb/
    ln -sf ../../../../../var/lib/xkb $XKB_DIR
  fi
} &> /dev/null || :

%post
{
%if %{with_Xserver}
  for dir in %{symlinkdirs} ; do
%else
  for dir in %{symlinkdirs} xserver ; do
%endif
    [ ! -L %{_x11datadir}/X11/$dir -a ! -d %{_x11datadir}/X11/$dir ] && \
      ln -snf ../../../../etc/X11/$dir %{_x11datadir}/X11/$dir || :
  done
} &> /dev/null || :

%pre xdm
{
  # The dir /etc/X11/xdm/authdir moved to /var/lib/xdm/authdir and was replaced
  # by a symlink.  Upgrades from Red Hat Linux 6.x and earlier to any new
  # release with XFree86-4.0.x fail without the following. (fixes bug #32574)
  if [ ! -L /etc/X11/xdm/authdir -a -d /etc/X11/xdm/authdir ]; then
    mkdir -p /var/lib/xdm && \
    mv -f /etc/X11/xdm/authdir /var/lib/xdm/  && \
       ln -sf ../../../var/lib/xdm/authdir /etc/X11/xdm/authdir || :
  fi
} &> /dev/null || :
         
%post libs
/sbin/ldconfig

%postun libs
/sbin/ldconfig

%post deprecated-libs
/sbin/ldconfig

%postun deprecated-libs
/sbin/ldconfig

%post Mesa-libGL
/sbin/ldconfig

%postun Mesa-libGL
/sbin/ldconfig

%post Mesa-libGLU
/sbin/ldconfig

%postun Mesa-libGLU
/sbin/ldconfig

##### xfs scripts ####################################################
# Work around a bug in the XFree86-xfs postun script, which results in the
# special xfs user account being inadvertently removed, causing xfs to run as
# the root user, and also resulting in xfs not being activated by chkconfig,
# This trigger executes right after the XFree86-xfs postun script, and ensures
# that the xfs user exists, and that the xfs initscript is properly chkconfig
# activated (#118145,118818)
%triggerpostun xfs -- XFree86-xfs
{
  # Conditionalized to work on RHL 7.1 and 7.2 which do not have /sbin/nologin
  LOGINSHELL=$([ -e /sbin/nologin ] && echo /sbin/nologin || echo /bin/false)
  /usr/sbin/useradd -c "X Font Server" -r -s $LOGINSHELL -u 43 -d /etc/X11/fs xfs || :
  /sbin/chkconfig --add xfs
  /sbin/service xfs condrestart || :
} &> /dev/null || :

%pre xfs
{
  # Conditionalized to work on RHL 7.1 and 7.2 which do not have /sbin/nologin
  LOGINSHELL=$([ -e /sbin/nologin ] && echo /sbin/nologin || echo /bin/false)
  /usr/sbin/useradd -c "X Font Server" -r -s $LOGINSHELL -u 43 -d /etc/X11/fs xfs || :
} &> /dev/null || : # Silence output, and ignore errors (Bug #91822)

%post xfs
{
  /sbin/chkconfig --add xfs
# FIXME: What an unmaintainable mess.  ;o) There almost has to be a cleaner
# way of doing this.  If not, it needs to be figured out and documented to
# avoid confusion.
  use_unix=
  for config in /etc/X11/xorg.conf /etc/X11/XF86Config /etc/X11/XF86Config-4 ; do
    if [ -f $config ] && grep -q "unix/:" $config &> /dev/null; then
      use_unix=1
    fi
    if [ -f $config ] && grep -q "unix/:-1" $config &> /dev/null; then
      rm -f $config.new $config.rpmsave
      sed "s#unix/:-1#unix/:7100#g" $config > $config.new
      cp -f $config $config.rpmsave
      cat $config.new > $config
      rm -f $config.new
    fi
    if [ -f $config ] && grep -q "unix/:" $config &> /dev/null && \
      grep -q "%{_x11fontdir}/TrueType" $config &> /dev/null ; then \
      sed "s|FontPath[ ]*\"%{_x11fontdir}/TrueType\"|#FontPath \"%{_x11fontdir}/TrueType\"|g" $config > $config.new
      cat $config.new > $config
      rm -f $config.new
    fi
  done
  # If the font server config is using UNIX sockets, disable TCP listen by default
  if [ -n "$use_unix" ] && ! grep -q "no-listen" /etc/X11/fs/config &> /dev/null;then
    echo -e "# don't listen on tcp by default\nno-listen = tcp\n" >> /etc/X11/fs/config
  fi
}

%preun xfs
{
  if [ "$1" = "0" ]; then
    /sbin/service xfs stop &> /dev/null || :
# FIXME: The chkconfig call below works properly if uninstalling the package,
#        but it will cause xfs to be de-chkconfig'd if upgrading from one X11
#        implementation to another, as witnessed in the transition from
#        XFree86 to Xorg X11.  If this call is removed however, then xfs will
#        remain visible in ntsysv and similar utilities even after xfs is
#        uninstalled from the system in non-upgrade scenarios.  Not sure how
#        to fix this yet.
    /sbin/chkconfig --del xfs || :
# userdel/groupdel removed because they cause the user/group to get destroyed
# when upgrading from one X11 implementation to another, ie: XFree86 -> Xorg
#    /usr/sbin/userdel xfs 2>/dev/null || :
#    /usr/sbin/groupdel xfs 2>/dev/null || :
  fi
}

%postun xfs
{
  if [ "$1" -ge "1" ]; then
    /sbin/service xfs condrestart &> /dev/null || :
  fi
} 

%if %{with_fonts}
%post base-fonts
{
# FIXME: Make it only run mkfontdir in dirs that have fonts in them.
# Build fonts.dir files for all font dirs in this package.
# (exclude the local and CID dirs as they do not have fonts currently)
  for fontdir in 100dpi 75dpi misc Type1 ;do
    %__mkfontdir %{_x11fontdir}/$fontdir || :
  done
  /usr/sbin/chkfontpath -qa %{_x11fontdir}/75dpi:unscaled || :
  /usr/sbin/chkfontpath -qa %{_x11fontdir}/100dpi:unscaled || :
  /usr/sbin/chkfontpath -qa %{_x11fontdir}/misc:unscaled || :
  /usr/sbin/chkfontpath -qa %{_x11fontdir}/Type1 || :
  # Remove the Speedo directory from xfs config as X.Org no longer provides
  # Speedo font support.
  /usr/sbin/chkfontpath -qr %{_x11fontdir}/Speedo || :
# Only run fc-cache in the Type1 dir, gzipped pcf's take forever
  %__fccache %{_x11fontdir}/Type1 || :
} &> /dev/null || :

%postun base-fonts
{
  # Rebuild fonts.dir when uninstalling package. (exclude the local, CID dirs)
  if [ "$1" = "0" ]; then
    for fontdir in 100dpi 75dpi misc Type1 ;do
      %__mkfontdir %{_x11fontdir}/$fontdir || :
    done
# Only run fc-cache in the Type1 dir, gzipped pcf's take forever
    %__fccache %{_x11fontdir}/Type1 || :
  fi
} &> /dev/null || :

%post truetype-fonts
{
  FONTDIR=%{_x11fontdir}/TTF
  ttmkfdir -d $FONTDIR -o $FONTDIR/fonts.scale
  %__mkfontdir $FONTDIR
  %__fccache $FONTDIR
  /usr/sbin/chkfontpath -q -a $FONTDIR
} &> /dev/null || :

%postun truetype-fonts
{
  FONTDIR=%{_x11fontdir}/TTF
  if [ "$1" = "0" ]; then
    ttmkfdir -d $FONTDIR -o $FONTDIR/fonts.scale
    %__mkfontdir $FONTDIR
    %__fccache $FONTDIR
  fi
} &> /dev/null || :

%post syriac-fonts
{
  FONTDIR=%{_x11fontdir}/OTF
  %__mkfontscale $FONTDIR 
  %__mkfontdir $FONTDIR
  %__fccache $FONTDIR
  /usr/sbin/chkfontpath -q -a $FONTDIR
} &> /dev/null || :

%postun syriac-fonts
{
  FONTDIR=%{_x11fontdir}/OTF
  if [ "$1" = "0" ]; then
    %__mkfontscale $FONTDIR 
    %__mkfontdir $FONTDIR
    %__fccache $FONTDIR
  fi
} &> /dev/null || :

%post 75dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/75dpi
#    %__fccache %{_x11fontdir}/75dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/75dpi:unscaled
} &> /dev/null || :

%post 100dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/100dpi
#    %__fccache %{_x11fontdir}/100dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/100dpi:unscaled
} &> /dev/null || :

%post ISO8859-2-75dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/75dpi
#    %__fccache %{_x11fontdir}/75dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/75dpi:unscaled
} &> /dev/null || :

%post ISO8859-2-100dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/100dpi
#    %__fccache %{_x11fontdir}/100dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/100dpi:unscaled
} &> /dev/null || :

%post ISO8859-9-75dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/75dpi
#    %__fccache %{_x11fontdir}/75dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/75dpi:unscaled
} &> /dev/null || :

%post ISO8859-9-100dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/100dpi
#    %__fccache %{_x11fontdir}/100dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/100dpi:unscaled
} &> /dev/null || :

%post ISO8859-14-75dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/75dpi
#    %__fccache %{_x11fontdir}/75dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/75dpi:unscaled
} &> /dev/null || :
    

%post ISO8859-14-100dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/100dpi
#    %__fccache %{_x11fontdir}/100dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/100dpi:unscaled
} &> /dev/null || :

%post ISO8859-15-75dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/75dpi
#    %__fccache %{_x11fontdir}/75dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/75dpi:unscaled
} &> /dev/null || :
    

%post ISO8859-15-100dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/100dpi
#    %__fccache %{_x11fontdir}/100dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/100dpi:unscaled
} &> /dev/null || :

%post cyrillic-fonts
{
    %__mkfontdir %{_x11fontdir}/cyrillic
#    %__fccache %{_x11fontdir}/cyrillic
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/cyrillic:unscaled
} &> /dev/null || :

%postun 75dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/75dpi
#    %__fccache %{_x11fontdir}/75dpi
  fi
}

%postun 100dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/100dpi
#    %__fccache %{_x11fontdir}/100dpi
  fi
}

%postun ISO8859-2-75dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/75dpi
#    %__fccache %{_x11fontdir}/75dpi
  fi
}

%postun ISO8859-2-100dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/100dpi
#    %__fccache %{_x11fontdir}/100dpi
  fi
}

%postun ISO8859-9-75dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/75dpi
#    %__fccache %{_x11fontdir}/75dpi
  fi
}

%postun ISO8859-9-100dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/100dpi
#    %__fccache %{_x11fontdir}/100dpi
  fi
}

%postun ISO8859-15-75dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/75dpi
#    %__fccache %{_x11fontdir}/75dpi
  fi
}

%postun ISO8859-15-100dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/100dpi
#    %__fccache %{_x11fontdir}/100dpi
  fi
}

%postun cyrillic-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/cyrillic
#    %__fccache %{_x11fontdir}/cyrillic
  fi
}
%endif

########## FILES SECTION #############################################
# FIXME: Move this to a separate README.specfile document
#
# IMPORTANT NOTE:  All fonts.dir, fonts.scale files are created during package
# installation time, and as such need to be flagged as ghost files, also their
# content is variable while installed as new fonts can be installed in the same
# directories potentially at any time, so they need to be flagged with %verify
# also.  They should not be flagged with %config however as they are not
# considered to be user editable, and should not be preserved.  Any case of a
# user wanting to edit these files by hand for ANY REASON, indicates a bug
# in the mkfontdir/ttmkfdir tools which should be fixed instead.
#
# encodings.dir files also should be flagged with %ghost and %verify, since
# the same applies to them, the only difference is that it may not actually
# exist unless the user creates it for some reason.  These files are deprecated
# and will be removed in a future upstream release entirely.
#
# fonts.alias should be flagged with %verify as it is modifyable.  For directories
# in which we supply a fonts.alias file, it should be flagged %config(noreplace)
# and for dirs which we do not supply one it should be flagged as both %ghost
# and %config(noreplace) so that the files are actually owned by the package,
# just not supplied by default, and they are preserved across upgrades.

######################################################################
# XFree86 package

%files -f filelist.%{name}
%defattr(-,root,root)
%doc CHANGELOG
%dir /etc/X11/lbxproxy
%config /etc/X11/lbxproxy/AtomControl
%dir /etc/X11/proxymngr
%config /etc/X11/proxymngr/pmconfig

# rstart stuffola
%if %{with_rstart}
%dir /etc/X11/rstart
%dir /etc/X11/rstart/commands
/etc/X11/rstart/commands/@List
/etc/X11/rstart/commands/ListContexts
/etc/X11/rstart/commands/ListGenericCommands
/etc/X11/rstart/commands/x
/etc/X11/rstart/commands/x11
%dir /etc/X11/rstart/commands/x11r6
%dir /etc/X11/rstart/contexts
/etc/X11/rstart/contexts/@List
/etc/X11/rstart/contexts/default
/etc/X11/rstart/contexts/x
/etc/X11/rstart/contexts/x11
%dir /etc/X11/rstart/contexts/x11r6
%config /etc/X11/rstart/config
/etc/X11/rstart/rstartd.real
%endif

%if %{with_Xserver}
%dir /etc/X11/xinit
# %config /etc/X11/xinit/xinitrc We have a separate xinitrc package
%dir /etc/X11/xserver
%config /etc/X11/xserver/*
%ghost %config(missingok,noreplace) %verify(not md5 size mtime) /etc/X11/xorg.conf
# FIXME: The XF86Config* files are deprecated and not supported.  Included here
# only to ease the transition to xorg.conf for an OS release or so.
%ghost %config(missingok,noreplace) %verify(not md5 size mtime) /etc/X11/XF86Config
%ghost %config(missingok,noreplace) %verify(not md5 size mtime) /etc/X11/XF86Config-4
%endif

%dir /etc/X11/xsm
%config /etc/X11/xsm/system.xsm
%ghost %{_x11datadir}/X11/lbxproxy
%ghost %{_x11datadir}/X11/proxymngr
%if %{with_rstart}
%ghost %{_x11datadir}/X11/rstart
%endif
%if %{with_Xserver}
%ghost %{_x11datadir}/X11/xserver
%endif
%dir %{_x11datadir}/X11/xkb
%config %{_x11datadir}/X11/app-defaults/*
%dir /var/lib/xkb
%config %attr(0644,root,root) /etc/pam.d/xserver
%config(missingok) /etc/security/console.apps/xserver
/var/lib/xkb/README
# SuperProbe is obsolete %{_x11bindir}/SuperProbe
%if %{with_Xserver}
%{_x11bindir}/X
%attr(4711,root,root) %{_x11bindir}/Xorg
%endif
%{_x11bindir}/Xmark
%ifnarch s390 s390x ppc ppc64
%{_x11bindir}/pcitweak
%{_x11bindir}/scanpci
%{_x11bindir}/mmapr
%{_x11bindir}/mmapw
%endif
%{_x11bindir}/appres
%{_x11bindir}/atobm
%{_x11bindir}/bitmap
%{_x11bindir}/bmtoa
%{_x11bindir}/cleanlinks
%{_x11bindir}/dga
%{_x11bindir}/dpsexec
%{_x11bindir}/dpsinfo
%{_x11bindir}/editres
%{_x11bindir}/iceauth
%if %{with_Xserver}
%{_x11bindir}/getconfig
%{_x11bindir}/getconfig.pl
%{_x11datadir}/X11/getconfig/cfg.sample
%{_x11datadir}/X11/getconfig/xorg.cfg
%{_x11bindir}/gtf
%endif
%{_x11bindir}/lbxproxy
%{_x11bindir}/lndir
%{_x11bindir}/luit
%{_x11bindir}/makepsres
%{_x11bindir}/makestrs
%{_x11bindir}/mergelib
%{_x11bindir}/mkcfm
%{_x11bindir}/mkdirhier
%{_x11bindir}/proxymngr
%if %{with_xterm}
%{_x11bindir}/resize
%endif
# Xresource extension client app
%{_x11bindir}/revpath
%if %{with_rstart}
%{_x11bindir}/rstart
%{_x11bindir}/rstartd
%endif
%{_x11bindir}/sessreg
%{_x11bindir}/setxkbmap
%{_x11bindir}/showrgb
%{_x11bindir}/smproxy
%if %{with_Xserver}
%{_x11bindir}/startx
%endif
%{_x11bindir}/texteroids
%if %{with_xterm}
%{_x11bindir}/uxterm
%endif
%{_x11bindir}/xcmsdb
%{_x11bindir}/xconsole
%{_x11bindir}/xcursor-config
%{_x11bindir}/xcursorgen
%{_x11bindir}/xcutsel
%{_x11bindir}/xdpyinfo
%{_x11bindir}/xdriinfo
%if %{with_xf86config}
# This has been removed from build 4.2.99.2-0.20021110.8 and later.  The
# supported X configuration tool in Red Hat Linux is system-config-display
# now, and we expect people to use it, and report bugs if there are any,
# and make requests for any missing features.  <mharris@redhat.com>
%{_x11bindir}/xf86config
%endif
%{_x11bindir}/xfindproxy
%{_x11bindir}/xfwp
%{_x11bindir}/xgamma
%{_x11bindir}/xhost
%if %{with_Xserver}
%{_x11bindir}/xinit
%endif
%{_x11bindir}/xkbbell
%{_x11bindir}/xkbcomp
%{_x11bindir}/xkbevd
%{_x11bindir}/xkbprint
%{_x11bindir}/xkbvleds
%{_x11bindir}/xkbwatch
%{_x11bindir}/xlsatoms
%{_x11bindir}/xlsclients
%{_x11bindir}/xlsfonts
%if %{with_xmh}
# xmh is obsolete
%{_x11bindir}/xmh
%endif
%{_x11bindir}/xmodmap
%{_x11bindir}/xon
%{_x11bindir}/xprop
%{_x11bindir}/xrandr
%{_x11bindir}/xrdb
%{_x11bindir}/xrefresh
%{_x11bindir}/xset
%{_x11bindir}/xsetmode
%{_x11bindir}/xsetpointer
%{_x11bindir}/xsetroot
%{_x11bindir}/xsm
%{_x11bindir}/xstdcmap
%if %{with_xterm}
%{_x11bindir}/xterm
%endif
%{_x11bindir}/xtrapchar
%{_x11bindir}/xtrapin
%{_x11bindir}/xtrapinfo
%{_x11bindir}/xtrapout
%{_x11bindir}/xtrapproto
%{_x11bindir}/xtrapreset
%{_x11bindir}/xtrapstats
%{_x11bindir}/xvidtune
%{_x11bindir}/xwd
%{_x11bindir}/xwud

%if %{with_Xserver}
# Provided by the Xconfigurator package in RHL 7.x, and in the hwdata
# currently in rawhide.
#%{_x11datadir}/X11/Cards
%{_x11datadir}/X11/Options
#%{_x11datadir}/X11/XF86Config
%dir %{_x11datadir}/X11/doc
%{_x11datadir}/X11/doc/*
# X server modules
%dir %{_x11libdir}/modules
%{_x11libdir}/modules/*.*
%dir %{_x11libdir}/modules/extensions
%{_x11libdir}/modules/extensions/*
%dir %{_x11libdir}/modules/fonts
%{_x11libdir}/modules/fonts/*
%dir %{_x11libdir}/modules/input
%{_x11libdir}/modules/input/*
%dir %{_x11libdir}/modules/linux
%{_x11libdir}/modules/linux/*
%dir %{_x11libdir}/modules/drivers
%{_x11libdir}/modules/drivers/*
%endif
%if %{with_DRI}
%dir %{_x11libdir}/modules/dri
%{_x11libdir}/modules/dri/*_dri.so
%endif
%dir %{_x11datadir}/X11/app-defaults
# FIXME: this doesn't build right on RHL9 - s390/s390x/ppc64 but... who CARES
%if %{with_Xserver}
%dir %{_x11datadir}/X11/etc
%{_x11datadir}/X11/etc/*
%{_x11datadir}/X11/xinit
%endif
%{_x11datadir}/X11/xkb/*
/etc/X11/xkb
%dir %{_x11datadir}/X11/x11perfcomp
%{_x11datadir}/X11/x11perfcomp/*
%{_x11datadir}/X11/xsm
%if %{with_Xserver}
%{_x11mandir}/man1/Xorg.1*
%{_x11mandir}/man1/Xserver.1*
%endif
%{_x11mandir}/man1/Xmark.1*
%{_x11mandir}/man1/appres.1*
%{_x11mandir}/man1/atobm.1*
%{_x11mandir}/man1/bitmap.1*
%{_x11mandir}/man1/bmtoa.1*
%{_x11mandir}/man1/cleanlinks.1*
%{_x11mandir}/man1/dga.1*
%{_x11mandir}/man1/dpsexec.1*
%{_x11mandir}/man1/dpsinfo.1*
%{_x11mandir}/man1/dumpkeymap.1*
%{_x11mandir}/man1/editres.1*
%{_x11mandir}/man1/iceauth.1*
%if %{with_Xserver}
%{_x11mandir}/man1/getconfig.1*
%{_x11mandir}/man1/gtf.1*
%endif
%{_x11mandir}/man1/lbxproxy.1*
%if %{with_libxrx}
%{_x11mandir}/man1/libxrx.1*
%endif
%{_x11mandir}/man1/lndir.1*
%{_x11mandir}/man1/luit.1*
%{_x11mandir}/man1/makedepend.1*
%{_x11mandir}/man1/makepsres.1*
%{_x11mandir}/man1/makestrs.1*
%{_x11mandir}/man1/mergelib.1*
%{_x11mandir}/man1/mkcfm.1*
%{_x11mandir}/man1/mkdirhier.1*
%{_x11mandir}/man1/oclock.1*
%ifnarch s390 s390x ppc ppc64
%{_x11mandir}/man1/pcitweak.1*
%{_x11mandir}/man1/scanpci.1*
%endif
%{_x11mandir}/man1/proxymngr.1*
%if %{with_xterm}
%{_x11mandir}/man1/resize.1*
%endif
%{_x11mandir}/man1/revpath.1*
%if %{with_rstart}
%{_x11datadir}/X11/rstart
%{_x11bindir}/rstart
%{_x11mandir}/man1/rstart.1*
%{_x11mandir}/man1/rstart.1*
%{_x11mandir}/man1/rstartd.1*
%endif
%{_x11mandir}/man1/sessreg.1*
%{_x11mandir}/man1/setxkbmap.1*
%{_x11mandir}/man1/showrgb.1*
%{_x11mandir}/man1/smproxy.1*
%if %{with_Xserver}
%{_x11mandir}/man1/startx.1*
%endif
%{_x11mandir}/man1/texteroids.1*
%{_x11mandir}/man1/xcmsdb.1*
%{_x11mandir}/man1/xconsole.1*
%{_x11mandir}/man1/xcursorgen.1*
%{_x11mandir}/man1/xcutsel.1*
%{_x11mandir}/man1/xdpyinfo.1*
%{_x11mandir}/man1/xdriinfo.1*
%if %{with_xf86config}
%{_x11mandir}/man1/xf86config.1*
%endif
%{_x11mandir}/man1/xfindproxy.1*
%{_x11mandir}/man1/xfwp.1*
%{_x11mandir}/man1/xgamma.1*
%{_x11mandir}/man1/xhost.1*
%if %{with_Xserver}
%{_x11mandir}/man1/xinit.1*
%endif
%{_x11mandir}/man1/xkbcomp.1*
%{_x11mandir}/man1/xkbevd.1*
%{_x11mandir}/man1/xkbprint.1*
%{_x11mandir}/man1/xkill.1*
%{_x11mandir}/man1/xlogo.1*
%{_x11mandir}/man1/xlsatoms.1*
%{_x11mandir}/man1/xlsclients.1*
%{_x11mandir}/man1/xlsfonts.1*
%if %{with_xmh}
# xmh is obsolete 
%{_x11mandir}/man1/xmh.1*
%endif
%{_x11mandir}/man1/xmodmap.1*
%{_x11mandir}/man1/xon.1*
%{_x11mandir}/man1/xprop.1*
%{_x11mandir}/man1/xrandr.1*
%{_x11mandir}/man1/xrdb.1*
%{_x11mandir}/man1/xrefresh.1*
%{_x11mandir}/man1/xset.1*
%{_x11mandir}/man1/xsetmode.1*
%{_x11mandir}/man1/xsetpointer.1*
%{_x11mandir}/man1/xsetroot.1*
%{_x11mandir}/man1/xsm.1*
%{_x11mandir}/man1/xstdcmap.1*
%if %{with_xterm}
%{_x11mandir}/man1/xterm.1*
%endif
%{_x11mandir}/man1/xtrap.1*
%{_x11mandir}/man1/xtrapchar.1*
%{_x11mandir}/man1/xtrapin.1*
%{_x11mandir}/man1/xtrapinfo.1*
%{_x11mandir}/man1/xtrapout.1*
%{_x11mandir}/man1/xtrapproto.1*
%{_x11mandir}/man1/xtrapreset.1*
%{_x11mandir}/man1/xtrapstats.1*
%{_x11mandir}/man1/xvidtune.1*
%{_x11mandir}/man1/xwd.1*
%{_x11mandir}/man1/xwud.1*
%if %{with_Xserver}
%{_x11mandir}/man4/*
%{_x11mandir}/man5/*
%endif
%{_x11mandir}/man7/*
%if ! %{with_icons_in_datadir}
%dir %{_x11icondir}
%endif
%dir %{_x11icondir}/default
%config(noreplace) %verify(not md5 size mtime) %{_x11icondir}/default/index.theme
%if %{with_handhelds}
%dir %{_x11icondir}/handhelds
%dir %{_x11icondir}/handhelds/cursors
%{_x11icondir}/handhelds/cursors/*
%endif
%if %{with_redglass}
%dir %{_x11icondir}/redglass
%dir %{_x11icondir}/redglass/cursors
%{_x11icondir}/redglass/cursors/*
%endif
%if %{with_whiteglass}
%dir %{_x11icondir}/whiteglass
%dir %{_x11icondir}/whiteglass/cursors
%{_x11icondir}/whiteglass/cursors/*
%endif

%files devel
%defattr(-,root,root)
# Changed GL include dir, on Mar 17, 2002 for 4.2.0-6.48 release
%dir %{_includedir}/GL
%{_includedir}/GL/*
%{_includedir}/X11
%{_includedir}/DPS
%{_libdir}/libGL.so
%{_libdir}/libGLU.so
%dir %{_x11includedir}
%dir %{_x11includedir}/DPS
%dir %{_x11includedir}/X11
%dir %{_x11includedir}/X11/ICE
# PEX is obsolete %dir %{_x11includedir}/X11/PEX5
%dir %{_x11includedir}/X11/PM
%dir %{_x11includedir}/X11/SM
%dir %{_x11includedir}/X11/Xaw
%dir %{_x11includedir}/X11/Xcursor
%dir %{_x11includedir}/X11/Xft
%dir %{_x11includedir}/X11/Xmu
%dir %{_x11includedir}/X11/bitmaps
%{_x11includedir}/X11/bitmaps/*
%dir %{_x11includedir}/X11/extensions
%{_x11includedir}/X11/extensions/*.h
%exclude %{_x11includedir}/X11/extensions/Print.h
%exclude %{_x11includedir}/X11/extensions/Printstr.h
%if %{with_fontconfig}
%dir %{_x11includedir}/fontconfig
%{_x11includedir}/fontconfig/*
%endif
%dir %{_x11includedir}/X11/fonts
%{_x11includedir}/X11/fonts/*.h
# FIXME: these are no longer present in 6.8.0, not sure why yet, so just
# commenting out rather than removing.  -- mharris
#%dir %{_x11includedir}/X11/fonts/codeconv
#%{_x11includedir}/X11/fonts/codeconv/*.h
%dir %{_x11datadir}/X11/config
%if %{with_archexec}
%{_x11bindir}/archexec
%endif
%{_x11bindir}/cxpm
%if %{with_fontconfig}
%{_x11bindir}/fontconfig-config
%endif
%{_x11bindir}/gccmakedep
%{_x11bindir}/gccmakedep-%{_arch}
%{_x11bindir}/imake
%{_x11bindir}/makedepend
%{_x11bindir}/makeg
%{_x11bindir}/pswrap
%{_x11bindir}/rman
%{_x11bindir}/sxpm
%{_x11bindir}/xft-config
%{_x11bindir}/xft-config-%{_arch}
%{_x11bindir}/xmkmf
%if %{with_Xserver}
%{_x11includedir}/*.h
%endif
%{_x11includedir}/DPS/*.h
%{_x11includedir}/X11/*.h
%{_x11includedir}/X11/ICE/*.h
# PEX is obsolete %{_x11includedir}/X11/PEX5/*.h
%{_x11includedir}/X11/PM/*.h
%{_x11includedir}/X11/SM/*.h
%{_x11includedir}/X11/Xaw/*
%{_x11includedir}/X11/Xcursor/*
###%if ! %{with_new_fontconfig_Xft}
%{_x11includedir}/X11/Xft/*
###%endif
%{_x11includedir}/X11/Xmu/*.h
%{_x11libdir}/libFS.a
%{_x11libdir}/libGL.a
%{_x11libdir}/libGLU.a
%{_x11libdir}/libGLw.a
%ifarch %{ix86} ia64 x86_64
%{_x11libdir}/libI810XvMC.a
%endif
%{_x11libdir}/libICE.a
%{_x11libdir}/libOSMesa.a
%{_x11libdir}/libSM.a
%{_x11libdir}/libX11.a
%{_x11libdir}/libXRes.a
%{_x11libdir}/libXTrap.a
%{_x11libdir}/libXau.a
#%{_x11libdir}/libXaw.a
%{_x11libdir}/libXcomposite.a
%{_x11libdir}/libXcursor.a
%{_x11libdir}/libXdamage.a
%{_x11libdir}/libXdmcp.a
%{_x11libdir}/libXext.a
%{_x11libdir}/libXevie.a
%{_x11libdir}/libXfixes.a
%{_x11libdir}/libXfont.a
# FIXME: this is no longer present in 6.8.0, not sure why yet, so just
# commenting out rather than removing.  -- mharris
#%{_x11libdir}/libXfontcache.a
%{_x11libdir}/libXft.a
%{_x11libdir}/libXi.a
%{_x11libdir}/libXinerama.a
%{_x11libdir}/libXmu.a
%{_x11libdir}/libXmuu.a
%{_x11libdir}/libXpm.a
%{_x11libdir}/libXrandr.a
%{_x11libdir}/libXrender.a
%{_x11libdir}/libXss.a
%{_x11libdir}/libXt.a
%{_x11libdir}/libXtst.a
%{_x11libdir}/libXv.a
%{_x11libdir}/libXvMC.a
%{_x11libdir}/libXxf86dga.a
%{_x11libdir}/libXxf86misc.a
%{_x11libdir}/libXxf86rush.a
%{_x11libdir}/libXxf86vm.a
%{_x11libdir}/libdmx.a
%{_x11libdir}/libdps.a
%{_x11libdir}/libdpstk.a
%{_x11libdir}/libfntstubs.a
%{_x11libdir}/libfontenc.a
%{_x11libdir}/liboldX.a
%{_x11libdir}/libpsres.a
%if %{with_Xserver}
%{_x11libdir}/libxf86config.a
%endif
%{_x11libdir}/libxkbfile.a
%{_x11libdir}/libxkbui.a
# Shared library symlinks
%{_x11libdir}/libGL.so
%{_x11libdir}/libGLU.so
%ifarch %{ix86} ia64 x86_64
%{_x11libdir}/libI810XvMC.so
%endif
%{_x11libdir}/libICE.so
%{_x11libdir}/libOSMesa.so
%{_x11libdir}/libSM.so
%{_x11libdir}/libX11.so
%{_x11libdir}/libXRes.so
%{_x11libdir}/libXTrap.so
%{_x11libdir}/libXaw.so
%{_x11libdir}/libXcomposite.so
%{_x11libdir}/libXcursor.so
%{_x11libdir}/libXdamage.so
%{_x11libdir}/libXext.so
%{_x11libdir}/libXevie.so
%{_x11libdir}/libXfixes.so
%{_x11libdir}/libXfont.so
# FIXME: these are no longer present in 6.8.0, not sure why yet, so just
# commenting out rather than removing.  -- mharris
#%{_x11libdir}/libXfontcache.so
%{_x11libdir}/libXft.so
%{_x11libdir}/libXi.so
%{_x11libdir}/libXinerama.so
%{_x11libdir}/libXmu.so
%{_x11libdir}/libXmuu.so
%{_x11libdir}/libXpm.so
%{_x11libdir}/libXrandr.so
%{_x11libdir}/libXrender.so
%{_x11libdir}/libXss.so
%{_x11libdir}/libXt.so
%{_x11libdir}/libXtst.so
%{_x11libdir}/libXv.so
%{_x11libdir}/libXvMC.so
%{_x11libdir}/libXxf86dga.so
%{_x11libdir}/libXxf86misc.so
%{_x11libdir}/libXxf86rush.so
%{_x11libdir}/libXxf86vm.so
%{_x11libdir}/libdps.so
%{_x11libdir}/libdpstk.so
%{_x11libdir}/libfontenc.so
%{_x11libdir}/libpsres.so
%{_x11libdir}/libxkbfile.so
%{_x11libdir}/libxkbui.so
%if %{with_libxrx}
%{_x11libdir}/libxrx.so
%endif
%if %{with_fontconfig}
%{_x11libdir}/libfontconfig.a
%{_x11libdir}/libfontconfig.so
%{_libdir}/pkgconfig/fontconfig.pc
%endif
# %{_x11libdir}/pkgconfig dir is unnecessary, just use the /usr/lib/pkgconfig dir
#%dir %{_x11libdir}/pkgconfig
%{_libdir}/pkgconfig/xcomposite.pc
%{_libdir}/pkgconfig/xcursor.pc
%{_libdir}/pkgconfig/xdamage.pc
%{_libdir}/pkgconfig/xevie.pc
%{_libdir}/pkgconfig/xfixes.pc
%{_libdir}/pkgconfig/xft.pc
%{_libdir}/pkgconfig/xrender.pc
# render.pc disabled because they do not get created properly
#%{_libdir}/pkgconfig/render.pc
%{_x11datadir}/X11/config/*
%{_x11mandir}/man1/cxpm.1*
%{_x11mandir}/man1/gccmakedep.1*
%{_x11mandir}/man1/imake.1*
%{_x11mandir}/man1/makeg.1*
%{_x11mandir}/man1/pswrap.1*
%{_x11mandir}/man1/rman.1*
%{_x11mandir}/man1/sxpm.1*
%{_x11mandir}/man1/xmkmf.1*
%{_x11mandir}/man3/*
%if %{with_fontconfig}
%{_x11mandir}/man3/fontconfig.3*
%endif


%files font-utils
%defattr(-,root,root)
%{_x11bindir}/bdftopcf
%{_x11mandir}/man1/bdftopcf.1*
%{_x11bindir}/bdftruncate
%{_x11mandir}/man1/bdftruncate.1*
#%{_x11bindir}/fonttosfnt
#%{_x11mandir}/man1/fonttosfnt.1*
%if %{with_fontconfig}
%{_x11bindir}/fc-cache
%{_x11bindir}/fc-list
%{_x11mandir}/man1/fc-cache.1*
%{_x11mandir}/man1/fc-list.1*
%endif
%{_x11bindir}/mkfontdir
%{_x11mandir}/man1/mkfontdir.1*
%{_x11bindir}/mkfontscale
%{_x11mandir}/man1/mkfontscale.1*
# The 'util' subdir is used by ucs2any, mkfontdir et al.
%dir %{_x11fontdir}/util
%{_x11fontdir}/util/*
# FIXME: ucs2any should be moved to %{name}-font-utils
%{_x11bindir}/ucs2any
# FIXME: ucs2any should be moved to font-utils subpackage
%{_x11mandir}/man1/ucs2any.1*


%files tools
%defattr(-,root,root)
%{_x11bindir}/beforelight
%{_x11bindir}/glxinfo
%{_x11bindir}/glxgears
%{_x11bindir}/ico
%{_x11bindir}/listres
%{_x11bindir}/mkhtmlindex
%{_x11bindir}/oclock
%{_x11bindir}/showfont
%{_x11bindir}/viewres
%{_x11bindir}/x11perf
%{_x11bindir}/x11perfcomp
%if %{with_xcalc}
%{_x11bindir}/xcalc
%endif
%{_x11bindir}/xclipboard
%{_x11bindir}/xclock
%if %{with_xedit}
%{_x11bindir}/xedit
%endif
%{_x11bindir}/xev
%{_x11bindir}/xfd
%{_x11bindir}/xfontsel
%{_x11bindir}/xgc
# XIE is obsolete %{_x11bindir}/xieperf
# xload has no need to be SUID root
%attr(755,root,root) %{_x11bindir}/xload
%{_x11bindir}/xmag
%if %{with_xman}
%{_x11bindir}/xman
%endif
%{_x11bindir}/xmessage
%{_x11bindir}/xvinfo
%{_x11bindir}/xwininfo
%{_x11bindir}/xlogo
%{_x11bindir}/xkill
%if %{with_xedit}
%dir %{_x11datadir}/X11/xedit
%dir %{_x11datadir}/X11/xedit/lisp
%{_x11datadir}/X11/xedit/lisp/*.lsp
%dir %{_x11datadir}/X11/xedit/lisp/progmodes
%{_x11datadir}/X11/xedit/lisp/progmodes/*.lsp
%endif
%if %{with_xman}
%{_x11datadir}/X11/xman.help
%endif
%{_x11mandir}/man1/beforelight.1*
%{_x11mandir}/man1/glxinfo.1*
%{_x11mandir}/man1/glxgears.1*
%{_x11mandir}/man1/ico.1*
%{_x11mandir}/man1/listres.1*
%{_x11mandir}/man1/mkhtmlindex.1*
%{_x11mandir}/man1/showfont.1*
%{_x11mandir}/man1/viewres.1*
%{_x11mandir}/man1/x11perf.1*
%{_x11mandir}/man1/x11perfcomp.1*
%if %{with_xcalc}
%{_x11mandir}/man1/xcalc.1*
%endif
%{_x11mandir}/man1/xclipboard.1*
%{_x11mandir}/man1/xclock.1*
%if %{with_xedit}
%{_x11mandir}/man1/xedit.1*
%endif
%{_x11mandir}/man1/xev.1*
%{_x11mandir}/man1/xfd.1*
%{_x11mandir}/man1/xfontsel.1*
%{_x11mandir}/man1/xgc.1*
# XIE is obsolete %{_x11mandir}/man1/xieperf.1*
%{_x11mandir}/man1/xload.1*
%{_x11mandir}/man1/xmag.1*
%if %{with_xman}
%{_x11mandir}/man1/xman.1*
%endif
%{_x11mandir}/man1/xmessage.1*
%{_x11mandir}/man1/xvinfo.1*
%{_x11mandir}/man1/xwininfo.1*


%files twm
%defattr(-,root,root)
%dir %{_sysconfdir}/X11/twm
%config %{_sysconfdir}/X11/twm/system.twmrc
%{_x11bindir}/twm
%{_x11datadir}/X11/twm
%{_x11mandir}/man1/twm.1*


%files xauth
%defattr(-,root,root)
%{_x11bindir}/xauth
%{_x11bindir}/mkxauth
%{_x11mandir}/man1/xauth.1*
%{_x11mandir}/man1/mkxauth.1*


%files xdm
%defattr(-,root,root)
%dir %{_sysconfdir}/X11/xdm
%{_sysconfdir}/X11/xdm/authdir
%dir %{_sysconfdir}/X11/xdm/pixmaps
%{_sysconfdir}/X11/xdm/pixmaps/*
# We ship these in the xinitrc package
#%config /etc/X11/xdm/GiveConsole
#%config /etc/X11/xdm/TakeConsole
#%config /etc/X11/xdm/Xaccess
%config /etc/X11/xdm/Xservers
# We ship these in the xinitrc package
#/etc/X11/xdm/Xsession
#/etc/X11/xdm/Xsetup_0
%config /etc/X11/xdm/Xresources
%config /etc/X11/xdm/Xwilling
# FIXME: chooser is an ELF executable, should not be in /etc really
/etc/X11/xdm/chooser
%config  %attr(0644,root,root) /etc/pam.d/xdm
%{_x11bindir}/xdm
%{_x11datadir}/X11/xdm
%{_x11mandir}/man1/xdm.1*
%dir /var/lib/xdm
%dir %attr(0700,root,root) /var/lib/xdm/authdir


%files xfs
%defattr(-,root,root)
%dir /etc/X11/fs
# Changed back to 'noreplace' to fix bug #53103
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/X11/fs/config
%config %{_sysconfdir}/rc.d/init.d/xfs
%{_x11bindir}/xfsinfo
%{_x11bindir}/fslsfonts
%{_x11bindir}/fstobdf
%{_x11bindir}/xfs
%{_x11datadir}/X11/fs
%{_x11mandir}/man1/xfs.1*
%{_x11mandir}/man1/xfsinfo.1*
%{_x11mandir}/man1/fslsfonts.1*
%{_x11mandir}/man1/fstobdf.1*

### %{name}-libs-data ################################################
# libs-data includes files which used to be in "libs" but which were moved
# here so that both x86, and x86_64 libs packages may be installed simultaneously.
%if %{with_libs_data}
%files libs-data
%defattr(-,root,root)
%dir %{_x11datadir}
%dir %{_x11datadir}/X11
%dir %{_x11localedir}
%{_x11localedir}/*
%{_x11datadir}/X11/rgb.txt
# Xcms.txt should be banished from the face of the earth with extreme
# hostility
#%{_x11datadir}/X11/Xcms.txt
%{_x11datadir}/X11/XErrorDB
%{_x11datadir}/X11/XKeysymDB
# Exclude i18n DSOs as they're arch specific
%exclude %dir %{_x11localedir}/%{_lib}
%exclude %dir %{_x11localedir}/%{_lib}/common
%exclude %{_x11localedir}/%{_lib}/common/*
%dir %{_x11mandir}
%dir %{_x11mandir}/man1
%dir %{_x11mandir}/man2
%dir %{_x11mandir}/man3
%dir %{_x11mandir}/man4
%dir %{_x11mandir}/man5
%dir %{_x11mandir}/man6
%dir %{_x11mandir}/man7
%dir %{_x11mandir}/man8
%endif

%files libs
%defattr(-,root,root)
# On x86 and other architectures _x11libdir and _x11datadir are the same dir,
# so listing them both generates a "file included twice" error.  Since these
# dirs are different on x86_64, we ifarch it here.
# All manpage dirs owned by libs package to guarantee they are owned by some
# installed package because everything pretty much depends on libs being there
%if ! %{with_libs_data}
%dir %{_x11datadir}
%dir %{_x11datadir}/X11
#%dir %{_x11localedir}
#%dir %{_x11localedir}/*/
#%{_x11localedir}/*/*
#%{_x11localedir}/compose.dir
#%{_x11localedir}/locale.alias
#%{_x11localedir}/locale.dir
%{_x11datadir}/X11/rgb.txt
# Xcms.txt should be banished from the face of the earth with extreme
# hostility
#%{_x11datadir}/X11/Xcms.txt
%{_x11datadir}/X11/XErrorDB
%{_x11datadir}/X11/XKeysymDB
%dir %{_x11mandir}
%dir %{_x11mandir}/man1
%dir %{_x11mandir}/man2
%dir %{_x11mandir}/man3
%dir %{_x11mandir}/man4
%dir %{_x11mandir}/man5
%dir %{_x11mandir}/man6
%dir %{_x11mandir}/man7
%dir %{_x11mandir}/man8
%endif # ! %{with_libs_data}

%dir %{_x11localedir}
%dir %{_x11localedir}/C
%dir %{_x11localedir}/armscii-8
%dir %{_x11localedir}/el_GR.UTF-8
%dir %{_x11localedir}/en_US.UTF-8
%dir %{_x11localedir}/georgian-*
%dir %{_x11localedir}/ibm-cp1133
%dir %{_x11localedir}/is*
%dir %{_x11localedir}/ja*
%dir %{_x11localedir}/ko*
%dir %{_x11localedir}/microsoft-cp125?
%dir %{_x11localedir}/mulelao-1
%dir %{_x11localedir}/nokhchi-1
%dir %{_x11localedir}/tatar-cyr
%dir %{_x11localedir}/th_TH*
%dir %{_x11localedir}/tscii-0
%dir %{_x11localedir}/vi_VN.*
%dir %{_x11localedir}/zh*
%dir %{_x11localedir}/%{_lib}
%dir %{_x11localedir}/%{_lib}/common
%{_x11localedir}/compose.dir
%{_x11localedir}/locale.alias
%{_x11localedir}/locale.dir
%{_x11localedir}/C/*
%{_x11localedir}/armscii-8/*
%{_x11localedir}/el_GR.UTF-8/*
%{_x11localedir}/en_US.UTF-8/*
%{_x11localedir}/georgian-*/*
%{_x11localedir}/ibm-cp1133/*
%{_x11localedir}/is*/*
%{_x11localedir}/ja*/*
%{_x11localedir}/ko*/*
%{_x11localedir}/microsoft-cp125?/*
%{_x11localedir}/mulelao-1/*
%{_x11localedir}/nokhchi-1/*
%{_x11localedir}/pt_BR.UTF-8/*
%{_x11localedir}/tatar-cyr/*
%{_x11localedir}/th_TH*/*
%{_x11localedir}/tscii-0/*
%{_x11localedir}/vi_VN.*/*
%{_x11localedir}/zh*/*
#%{_x11localedir}/%{_lib}/*
%{_x11localedir}/%{_lib}/common/*
%ifarch x86_64
%dir %{_x11libdir}
%endif
# Shared libraries:  %{_x11libdir}/lib*.so.* might be better in the long run
# except for arch specific stuff, but it shouldn't be built in the first place.
/etc/ld.so.conf.d/xorg-x11-%{_arch}.conf
%{_x11libdir}/libFS.so.6
%{_x11libdir}/libFS.so.6.0
%{_x11libdir}/libGLw.so.1
%{_x11libdir}/libGLw.so.1.0
%ifarch %{ix86} ia64 x86_64
%{_x11libdir}/libI810XvMC.so.1
%{_x11libdir}/libI810XvMC.so.1.0
%endif
%{_x11libdir}/libICE.so.6
%{_x11libdir}/libICE.so.6.3
%{_x11libdir}/libOSMesa.so.4
%{_x11libdir}/libOSMesa.so.4.0
%{_x11libdir}/libSM.so.6
%{_x11libdir}/libSM.so.6.0
%{_x11libdir}/libX11.so.6
%{_x11libdir}/libX11.so.6.2
%{_x11libdir}/libXRes.so.1
%{_x11libdir}/libXRes.so.1.0
%{_x11libdir}/libXTrap.so.6
%{_x11libdir}/libXTrap.so.6.4
%{_x11libdir}/libXaw.so.6
%{_x11libdir}/libXaw.so.6.1
%{_x11libdir}/libXaw.so.7
%{_x11libdir}/libXaw.so.7.0
%{_x11libdir}/libXcomposite.so.1
%{_x11libdir}/libXcomposite.so.1.0
%{_x11libdir}/libXcursor.so.1
%{_x11libdir}/libXcursor.so.1.0.2
%{_x11libdir}/libXdamage.so.1
%{_x11libdir}/libXdamage.so.1.0
%{_x11libdir}/libXext.so.6
%{_x11libdir}/libXext.so.6.4
%{_x11libdir}/libXevie.so.1
%{_x11libdir}/libXevie.so.1.0
%{_x11libdir}/libXfixes.so.3
%{_x11libdir}/libXfixes.so.3.0
%{_x11libdir}/libXfont.so.1
%{_x11libdir}/libXfont.so.1.5
# FIXME: these are no longer present in 6.8.0, not sure why yet, so just
# commenting out rather than removing.  -- mharris
#%{_x11libdir}/libXfontcache.so.1
#%{_x11libdir}/libXfontcache.so.1.2
%{_x11libdir}/libXft.so.1
%{_x11libdir}/libXft.so.1.1
%{_x11libdir}/libXft.so.2
%{_x11libdir}/libXft.so.2.1.2
%{_x11libdir}/libXi.so.6
%{_x11libdir}/libXi.so.6.0
%{_x11libdir}/libXinerama.so.1
%{_x11libdir}/libXinerama.so.1.0
%{_x11libdir}/libXmu.so.6
%{_x11libdir}/libXmu.so.6.2
%{_x11libdir}/libXmuu.so.1
%{_x11libdir}/libXmuu.so.1.0
%{_x11libdir}/libXpm.so.4
%{_x11libdir}/libXpm.so.4.11
%{_x11libdir}/libXrandr.so.2
%{_x11libdir}/libXrandr.so.2.0
%{_x11libdir}/libXrender.so.1
%{_x11libdir}/libXrender.so.1.2.2
%{_x11libdir}/libXss.so.1
%{_x11libdir}/libXss.so.1.0
%{_x11libdir}/libXt.so.6
%{_x11libdir}/libXt.so.6.0
%{_x11libdir}/libXtst.so.6
%{_x11libdir}/libXtst.so.6.1
%{_x11libdir}/libXv.so.1
%{_x11libdir}/libXv.so.1.0
%{_x11libdir}/libXvMC.so.1
%{_x11libdir}/libXvMC.so.1.0
%{_x11libdir}/libXxf86dga.so.1
%{_x11libdir}/libXxf86dga.so.1.0
%{_x11libdir}/libXxf86misc.so.1
%{_x11libdir}/libXxf86misc.so.1.1
%{_x11libdir}/libXxf86rush.so.1
%{_x11libdir}/libXxf86rush.so.1.0
%{_x11libdir}/libXxf86vm.so.1
%{_x11libdir}/libXxf86vm.so.1.0
%{_x11libdir}/libdps.so.1
%{_x11libdir}/libdps.so.1.0
%{_x11libdir}/libdpstk.so.1
%{_x11libdir}/libdpstk.so.1.0
%{_x11libdir}/libfontenc.so.1
%{_x11libdir}/libfontenc.so.1.0
%{_x11libdir}/libpsres.so.1
%{_x11libdir}/libpsres.so.1.0
%{_x11libdir}/libxkbfile.so.1
%{_x11libdir}/libxkbfile.so.1.0
%{_x11libdir}/libxkbui.so.1
%{_x11libdir}/libxkbui.so.1.0
%if %{with_fontconfig}
%{_x11libdir}/libfontconfig.so.*
%endif
%if %{with_libxrx}
# FIXME: need to do test build to get .so version
%{_x11libdir}/libxrx.so.
%endif

%files deprecated-libs
%defattr(-,root,root)
# Even when with_xprint is 0, we still need the libs for legacy compat
%{_x11libdir}/libXp.so.6
%{_x11libdir}/libXp.so.6.2

%files deprecated-libs-devel
%defattr(-,root,root)
%{_x11includedir}/X11/extensions/Print.h
%{_x11includedir}/X11/extensions/Printstr.h
%{_x11libdir}/libXp.a
%{_x11libdir}/libXp.so

%files Mesa-libGL
%defattr(-,root,root)
%{_x11libdir}/libGL.so.1
%{_x11libdir}/libGL.so.%{libGL_version}
%{_libdir}/libGL.so.1
#%{_libdir}/libGL.so.1.2

%files Mesa-libGLU
%defattr(-,root,root)
%{_x11libdir}/libGLU.so.1
%{_x11libdir}/libGLU.so.%{libGLU_version}
%{_libdir}/libGLU.so.1

######################################################################
# Fonts
%if %{with_fonts}
%files base-fonts
%defattr(-,root,root)
%dir %{_x11fontdir}
# base 100dpi fonts
%dir %{_x11fontdir}/100dpi
%ghost %verify(not md5 size mtime) %{_x11fontdir}/100dpi/encodings.dir
%config(noreplace) %verify(not md5 size mtime) %{_x11fontdir}/100dpi/fonts.alias
%ghost %verify(not md5 size mtime) %{_x11fontdir}/100dpi/fonts.dir
%ghost %verify(not md5 size mtime) %{_x11fontdir}/100dpi/fonts.scale
# base 75dpi fonts
%dir %{_x11fontdir}/75dpi
%ghost %verify(not md5 size mtime) %{_x11fontdir}/75dpi/encodings.dir
%config(noreplace) %verify(not md5 size mtime) %{_x11fontdir}/75dpi/fonts.alias
%ghost %verify(not md5 size mtime) %{_x11fontdir}/75dpi/fonts.dir
%ghost %verify(not md5 size mtime) %{_x11fontdir}/75dpi/fonts.scale
# base CID fonts
%dir %{_x11fontdir}/CID
%ghost %verify(not md5 size mtime) %{_x11fontdir}/CID/encodings.dir
%ghost %verify(not md5 size mtime) %{_x11fontdir}/CID/fonts.dir
%ghost %verify(not md5 size mtime) %{_x11fontdir}/CID/fonts.scale
# Encoding files
%dir %{_x11fontdir}/encodings
%{_x11fontdir}/encodings/*
#%dir %{_x11fontdir}/encodings/large
#%{_x11fontdir}/encodings/large/*
# local, and misc do not currently contain fonts, but we want to own the dir
%dir %{_x11fontdir}/local
%ghost %verify(not md5 size mtime) %{_x11fontdir}/local/encodings.dir
%ghost %verify(not md5 size mtime) %{_x11fontdir}/local/fonts.dir
# base misc files
%dir %{_x11fontdir}/misc
%{_x11fontdir}/misc/*.pcf.gz
%ghost %verify(not md5 size mtime) %{_x11fontdir}/misc/encodings.dir
%config(noreplace) %verify(not md5 size mtime) %{_x11fontdir}/misc/fonts.alias
%ghost %verify(not md5 size mtime) %{_x11fontdir}/misc/fonts.dir
%ghost %verify(not md5 size mtime) %{_x11fontdir}/misc/fonts.scale
# base Type1 fonts
%dir %{_x11fontdir}/Type1
%{_x11fontdir}/Type1/*.afm
%{_x11fontdir}/Type1/*.pfa
%{_x11fontdir}/Type1/*.pfb
%ghost %verify(not md5 size mtime) %{_x11fontdir}/Type1/encodings.dir
%ghost %verify(not md5 size mtime) %{_x11fontdir}/Type1/fonts.dir
%verify(not md5 size mtime) %{_x11fontdir}/Type1/fonts.scale
%ghost %verify(not md5 size mtime) %{_x11fontdir}/Type1/fonts.cache*
# Make base-fonts own the other font directories and auxilliary files
%dir %{_x11fontdir}/OTF
%ghost %verify(not md5 size mtime) %{_x11fontdir}/OTF/encodings.dir
%ghost %verify(not md5 size mtime) %config(noreplace) %{_x11fontdir}/OTF/fonts.alias
%ghost %verify(not md5 size mtime) %{_x11fontdir}/OTF/fonts.dir
%ghost %verify(not md5 size mtime) %{_x11fontdir}/OTF/fonts.scale
%ghost %verify(not md5 size mtime) %{_x11fontdir}/OTF/fonts.cache*
%dir %{_x11fontdir}/TTF
%ghost %verify(not md5 size mtime) %{_x11fontdir}/TTF/encodings.dir
%ghost %verify(not md5 size mtime) %config(noreplace) %{_x11fontdir}/TTF/fonts.alias
%ghost %verify(not md5 size mtime) %{_x11fontdir}/TTF/fonts.dir
%ghost %verify(not md5 size mtime) %{_x11fontdir}/TTF/fonts.scale
%ghost %verify(not md5 size mtime) %{_x11fontdir}/TTF/fonts.cache*

# Don't glob all TTF fonts with *.ttf as we wont detect newly added fonts in
# new releases, and may not want them all (ie: Vera we ship separately)
%files truetype-fonts
%defattr(-,root,root)
%dir %{_x11fontdir}/TTF
%{_x11fontdir}/TTF/luxi*.ttf

%files syriac-fonts
%defattr(-,root,root)
%dir %{_x11fontdir}/OTF
%{_x11fontdir}/OTF/Syr*.otf

%files 75dpi-fonts
%defattr(-,root,root)
%dir %{_x11fontdir}/75dpi
%exclude %{_x11fontdir}/75dpi/*-ISO8859-2.pcf.gz
%exclude %{_x11fontdir}/75dpi/*-ISO8859-9.pcf.gz
%exclude %{_x11fontdir}/75dpi/*-ISO8859-14.pcf.gz
%exclude %{_x11fontdir}/75dpi/*-ISO8859-15.pcf.gz
%{_x11fontdir}/75dpi/*.pcf.gz

%files 100dpi-fonts
%defattr(-,root,root)
%dir %{_x11fontdir}/100dpi
%exclude %{_x11fontdir}/100dpi/*-ISO8859-2.pcf.gz
%exclude %{_x11fontdir}/100dpi/*-ISO8859-9.pcf.gz
%exclude %{_x11fontdir}/100dpi/*-ISO8859-14.pcf.gz
%exclude %{_x11fontdir}/100dpi/*-ISO8859-15.pcf.gz
%{_x11fontdir}/100dpi/*.pcf.gz

%files ISO8859-2-75dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/75dpi/*-ISO8859-2.pcf.gz

%files ISO8859-2-100dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/100dpi/*-ISO8859-2.pcf.gz

%files ISO8859-9-75dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/75dpi/*-ISO8859-9.pcf.gz

%files ISO8859-9-100dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/100dpi/*-ISO8859-9.pcf.gz

%files ISO8859-14-75dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/75dpi/*-ISO8859-14.pcf.gz

%files ISO8859-14-100dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/100dpi/*-ISO8859-14.pcf.gz

%files ISO8859-15-75dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/75dpi/*-ISO8859-15.pcf.gz

%files ISO8859-15-100dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/100dpi/*-ISO8859-15.pcf.gz

%files cyrillic-fonts
%defattr(-,root,root)
%dir %{_x11fontdir}/cyrillic
%{_x11fontdir}/cyrillic/*.gz
%ghost %verify(not md5 size mtime) %{_x11fontdir}/cyrillic/encodings.dir
%config(noreplace) %verify(not md5 size mtime) %{_x11fontdir}/cyrillic/fonts.alias
%ghost %verify(not md5 size mtime) %{_x11fontdir}/cyrillic/fonts.dir
%ghost %verify(not md5 size mtime) %{_x11fontdir}/cyrillic/fonts.scale

%endif
# End of font subpackages
#######################################################################


%if %{with_docs}
%files doc
%defattr(-,root,root)
%doc xc/doc/hardcopy/*
%endif

%files Xdmx
%defattr(-,root,root)
%{_x11bindir}/Xdmx
%{_x11mandir}/man1/Xdmx.1*
%{_x11mandir}/man1/dmxtodmx.1*
%{_x11mandir}/man1/vdltodmx.1*
%{_x11mandir}/man1/xdmxconfig.1*

%files Xnest
%defattr(-,root,root)
%{_x11bindir}/Xnest
%{_x11mandir}/man1/Xnest.1*

%if %{with_xprint}
%files Xprint
%defattr(-,root,root)
/etc/X11/Xsession.d/92xprint-xpserverlist.sh
/etc/X11/xinit/xinitrc.d/92xprint-xpserverlist.sh
/etc/init.d/xprint
/etc/profile.d/xprint.csh
/etc/profile.d/xprint.sh
/etc/rc.d/init.d/xprint
/etc/rc.d/rc[0-6].d/K??xprint
/etc/rc.d/rc[0-6].d/S??xprint
%{_x11bindir}/Xprt
%endif

%files Xvfb
%defattr(-,root,root)
%{_x11bindir}/Xvfb
%{_x11mandir}/man1/Xvfb.1*

%if %{with_xf86cfg}
%files xf86cfg
%defattr(-,root,root)
%{_x11bindir}/xf86cfg
%{_x11mandir}/man1/xf86cfg.1*
# FIXME: This stuff should not be in any include directory, that is stupid
%dir %{_x11includedir}/X11/pixmaps
%{_x11includedir}/X11/pixmaps/*
%endif

%if %{with_sdk}
%files sdk -f filelist.sdk
%defattr(-,root,root)
%endif

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT 

%changelog
* Fri May 13 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-31
- Added xorg-x11-6.8.2-ati-ragexl-ia64-avoidcpiofix.patch to workaround issue
  on ia64 with CPIO disabled in ati Mach64 driver (#155609,155610).  For
  future reference, this is also included in RHEL4_U1 build 6.8.2-1.EL.13.5.

* Sat Apr 30 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-30
- Disabled xfs.init-fc4-startearly.patch as it breaks systems that /usr is
  on NFS. (FC4Blocker #156413)

* Mon Apr 25 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-29
- Added xfs.init-fc4-startearly.patch to patch xfs.init to start earlier in
  the boot process for gdm early login on FC4 builds.  This is done to the
  RPM_BUILD_ROOT installed file to ensure the changes do not get checked into
  CVS for the master initscript accidentally.

* Fri Apr 22 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-28
- Added xorg-x11-6.8.2-xft-releasefile-crash.patch for fc4 builds (#155634)
- Reordered patch section to clean up numbering inconsistencies
- Update freetype BuildRequires to version 2.1.8, which is what ships in
  6.8.2 stock.

* Fri Apr 22 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-27
- Change xfs initscript dependancies from "Requires(preun,postun):" to using
  two separate lines because rpm has a bug (#118773) that causes dependancies
  of this syntax to be ignored.

* Thu Apr 21 2005 Soren Sandmann Pedersen <sandmann@redhat.com>
- Make old custom-modelines RHEL4 only. Add .laptop-modes.patch with
  support for various weird laptop resolutions.

* Wed Apr 20 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-26
- Re-enable xorg-x11-6.8.2-ati-radeon-disable-broken-renderaccel-by-default.patch
  patch on FC3/FC4, until we have a new renderaccel patch to test.
- Delete Xprint manpage.

* Mon Apr 18 2005 Kristian Høgsberg <krh@redhat.com> 6.8.2-25
- Add xorg-x11-6.8.1-ati-radeon-dynamic-clocks-fix-2.patch to revert
  radeon dynamic clock setup to what we had in 6.8.1.  The 6.8.2 code
  still causes lockups on some systems (#152648).

* Sat Apr 16 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-24
- Remove the Speedo font files, as Xorg no longer supports Speedo fonts in
  6.8.0 onward but includes the fonts accidentally. (#142744,154191)
- Changed base subpackage post script to remove the Speedo font path from xfs
  configuration to avoid warnings in /var/log/messages from xfs about bad
  font path elements.

* Fri Apr 15 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-23
- Disable xorg-x11-6.8.2-ati-radeon-disable-broken-renderaccel-by-default.patch
  patch on FC3/FC4, so we can test the real bugfix.

* Tue Apr 12 2005 Kristian Høgsberg <krh@redhat.com> 6.8.2-22
- Remove xorg-x11-6.8.3-intrinsics-gcc4-fdo2893-2305.patch and
  remember to cvs add xorg-x11-6.8.3-deassert-ddc-lines.patch
- Add patches nominated for 6.8.3:
   - xorg-x11-6.8.3-alpha-srel32-fix-fdo1765-2174.patch
   - xorg-x11-6.8.3-canonicalize-builderaddr-1-fdo2884-2293.patch
   - xorg-x11-6.8.3-intrinsics-gcc4-fdo2893-2305.patch
   - xorg-x11-6.8.3-iso8859-compose-files-fdo2592-2156.patch
   - xorg-x11-6.8.3-lbxproxy-fdo2678-2051.patch
   - xorg-x11-6.8.3-nv-hw-fdo2533-1896.patch
   - xorg-x11-6.8.3-nv-patch-fdo2380-1752.patch
   - xorg-x11-6.8.3-radeon-cursor-sync-fdo2844-2230.patch
   - xorg-x11-6.8.3-radeon-render-byteswap-fdo2164-1863.patch
   - xorg-x11-6.8.3-radeon-set-fb-location-fdo2698-2079.patch
   - xorg-x11-6.8.3-saver-c-fdo2194-1613.patch
   - xorg-x11-6.8.3-uname-fdo2123-1587.patch
   - xorg-x11-6.8.3-void-fdo2467-1828.patch
   - xorg-x11-6.8.3-xnest-fdo2599-1964.patch
   - xorg-x11-6.8.3-xorgcfg-typo-fdo2896-2311.patch
   - xorg-x11-6.8.3-xset-fdo2258-2166.patch
  Add patch to deassert i2s lines after ddc probe
  (xorg-x11-6.8.3-deassert-ddc-lines.patch).

* Tue Apr  5 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-21
- Added xorg-x11-6.8.2-xorg.conf.man-dont-refer-to-nonexisting-example.patch
  to fix bug (#69335)
- Removed dead XFree86-4.2.99.901-parallelmake.patch as it has not worked for
  several X releases and is unmaintained.

* Tue Apr  5 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-20
- Updated pre script to only strip away XkbRules lines indicating "xfree86"
  or "xorg" rules be used.  (#142429)
- xfs.init reordered find "-maxdepth" option to be first in the list of
  options because some people report errors, although I can not reproduce
  locally, implying it is a change in GNU findutils.  (#154056)

* Mon Apr  4 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-19
- xfs.init updated with fixes for chkfontpath invocation, as the previous
  code did not filter the output of chkfontpath very good.  The new sed
  filtering is more reliable now, until chkfontpath is enhanced to provide
  the info in a way that does not require filtering.
- xfs.init updated to handle .ot[cf] fonts before .tt[cf] fonts, which is a
  small optimization for the case of dirs containing .ot[cf] and .tt[cf]
  fonts, as it bypasses the prior invocation of ttmkfdir which would get
  discarded anyway.  Now only one of the two will be invoked, however the
  resulting fonts.dir will be identical to before.
- xfs.init updated to *always* run fc-cache without arguments, in order to
  ensure all fontconfig configured font directories have updated cache
  files. (#133451)
- xfs.init should no longer try to create files on read-only filesystems,
  coincidentally due to the above changes, except when the font metadata
  is genuinely outdated, which is an error condition no matter how the
  filesystem is mounted (#74398)

* Sun Apr  3 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-18
- Added new file "CHANGELOG-rpm" as SOURCE25, which contains all rpm spec
  file changelog entries from XFree86 4.3.0 and older era of historical
  significance, in order to reduce the per-subpackage rpm payload costs
  of large changelogs at install time, and to generally reduce spec file
  clutter.

* Sun Apr  3 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-17
- Remove precompiled video and input drivers and duplicate copy of Xorg
  server binary from xorg-x11-sdk subpackage as they are unnecessary and
  non-useful duplication consuming CDROM space.

* Sat Apr  2 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-16
- Added xorg-x11-6.8.2-use-linux-native-pciscan-by-default.patch to fix PCI
  config space contention issue by changing the X server to default to using
  Linux native PCI interfaces instead of directly banging on PCI space
  itself (#152608).
- Clean up xorg-x11-doc subpackage by removing junk that gets installed that
  should not have been installed by the upstream Makefiles.

* Sat Apr  2 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-15
- Added "find $RPM_BUILD_ROOT -name CVS -type d | xargs rm -rf" to rm -rf
  section of %%install, to force CVS directories to be removed so they do not
  end up getting installed in the final packaging.

* Tue Mar 29 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-14
- Added "Provides: libGL = 1" virtual provide to the xorg-x11-Mesa-libGL
  subpackage, and "Provides: libGLU = 1" virtual provide to the
  xorg-x11-Mesa-libGLU subpackage, so that packages providing the headers
  can require the virtual provide, rather than a specific implementation.
  Currently restricted to build_fc4 for beta testing.
- Added "Requires: libGL >= 1, libGLU >= 1" to xorg-x11-devel package, as the
  libGL and libGLU headers are currently present in xorg-x11-devel.  Also
  restricted to build_fc4 for testing.  Once confirmed safe, with no
  regressions, all of these changes should be enabled simultaneously for all
  builds.

* Wed Mar 23 2005 Kristian Høgsberg <krh@redhat.com> 6.8.2-13
- Add XFree86-4.1.0-xpm-security-fix-CAN-2005-0605.patch (#150040).

* Wed Mar 16 2005 Soeren Sandmann <sandmann@redhat.com> 6.8.2-12
- Add xorg-x11-6.8.2-cursor-flicker.patch (#144022)
- Fix xorg-x11-6.8.2-XScreenSaverQueryInfo-crash-fix.patch so it will apply

* Tue Mar 15 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-11
- Added xorg-x11-6.8.2-config-StaticNeedsPicForShared.patch for (#108026)
- Removed StaticNeedsPicForShared from host.def section
- Added xorg-x11-6.8.2-XScreenSaverQueryInfo-crash-fix.patch to fix (#147890)

* Mon Mar 14 2005 Mike A. Harris <mharris@redhat.com>
- Search and destroy any CVS directories found in RPM_BUILD_DIR during rpm
  spec file build section prior to building.  This fixes a problem where the
  6.8.2 release was tarballed officially from a CVS checkout rather than a
  CVS export, causing the CVS metadata to be present, and some of it ends up
  getting installed in the final OS.

* Fri Mar 11 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-1.FC3.10test
- Rebuild 6.8.2-10 as 6.8.2-1.FC3.10test for Fedora Core 3 testing release

* Fri Mar 11 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-10
- Re-enable xorg-x11-6.8.2-xnest-shape-fix.patch which has been updated now
  for 6.8.2 by Mark McLoughlin (#148763,138482)

* Thu Mar 10 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-9
- Disable xorg-x11-6.8.2-xnest-shape-fix.patch added in 6.8.2-8, as it does
  not compile.

* Thu Mar 10 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-1.FC3.8test
- Rebuild 6.8.2-8 as 6.8.2-1.FC3.8test for Fedora Core 3 testing release

* Tue Mar  8 2005 Soeren Sandmann <sandmann@redhat.com> 6.8.2-8
- Add Patch9329: xorg-x11-6.8.2-xnest-shape-fix.patch (Patch by Mark
  McLoughlin). (#148763)

* Fri Mar  4 2005 Soeren Sandmann <sandmann@redhat.com> 6.8.2-7
- Added xorg-x11-6.8.2-fix-font-crash.patch to fix crash on fonts with NULL
  bits (#145546)

* Wed Mar  2 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-1.FC3.6test
- Rebuild 6.8.2-6 as 6.8.2-1.FC3.6test for Fedora Core 3 testing release

* Wed Mar  2 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-6
- Added xorg-x11-6.8.2-ati-radeon-gcc4-fix.patch to fix bug in radeon driver
  when building with gcc 4. (#150086)

* Tue Mar  1 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-5
- Conditionalize the gcc4 patch for FC4 only for now.
- Disable FORTIFY_SOURCE on RHEL4/FC3 builds as it fails for some odd reason,
  yet it builds ok on FC4.
- Added xorg-x11-6.8.2-ati-radeon-disable-broken-renderaccel-by-default.patch
  to disable render acceleration by default in the "radeon" driver, as it is
  currently broken (#136065,136941,149907,143401,143234)

* Tue Mar  1 2005 Soeren Sandmann <sandmann@redhat.com> 6.8.2-4
- Fix somehow empty patch file

* Tue Mar  1 2005 Soeren Sandmann <sandmann@redhat.com> 6.8.2-3
- Add patch for gcc 4 build problem (#150042)

* Tue Mar  1 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-2
- Rebuild xorg-x11 with gcc 4 into FC4

* Thu Feb 10 2005 Mike A. Harris <mharris@redhat.com> 6.8.2-1
- Update main tarball to X.Org X11 6.8.2

* Tue Feb  8 2005 Mike A. Harris <mharris@redhat.com> 6.8.1.904-2
- [SECURITY] Added with_fortify_source option macro to spec file, to allow
  xorg-x11 to take partial advantage of the new gcc FORTIFY_SOURCE feature
  available in newer gcc releases.  This option is automatically enabled in
  FC4 builds by rpm by default via RPM_OPT_FLAGS, however while gcc in FC3
  and RHEL4 has this support also, it must be manually enabled in the spec
  file for it to get used.  "-D_FORTIFY_SOURCE=2" gets passed to gcc when
  this option is enabled.

* Fri Feb  4 2005 Mike A. Harris <mharris@redhat.com> 6.8.1.904-1
- Update main tarball to X.Org X11 6.8.1.904 (6.8.2 release candidate 4)
  via X.Org official tarball: xorg-x11-6.8.1.904.tar.gz
- Removed xorg-x11-6.8.1.903-nls-pt_BR.UTF-8-fix.patch, as it is integrated
  into 6.8.1.904 already.

* Fri Feb  4 2005 Mike A. Harris <mharris@redhat.com> 6.8.1.903-4
- Added new with_alternate_projectroot macro, which will eventually allow the
  parallel installation of multiple versions of xorg-x11 in rpm format without
  conflicting with each other (theoretically).  The feature is intended only
  for Red Hat X.Org developer usage, and will not be an officially supported
  installation method.  It is an incomplete experimental work in progress,
  and should not be used by mortals.  THIS WILL FRY YOUR SYSTEM, DO NOT USE
  IT.  :o)

* Wed Feb  2 2005 Soeren Sandmann <sandmann@redhat.com> 6.8.1.903-3
- Added patch to fix Composite gravity issue, recently added to xorg
  HEAD. (fdo#2230).

* Thu Jan 27 2005 Mike A. Harris <mharris@redhat.com> 6.8.1.903-2
- Added xorg-x11-6.8.1.903-nls-pt_BR.UTF-8-fix.patch from kem to fix broken
  pt_BR.UTF-8 support recently added to xorg cvs (fdo#2400)

* Thu Jan 27 2005 Mike A. Harris <mharris@redhat.com> 6.8.1.903-1
- Update main tarball to X.Org X11 6.8.1.903 (6.8.2 release candidate 3)
  via X.Org official tarball: xorg-x11-6.8.1.903.tar.gz
- Updated xorg-x11.6.8.1.903-AMD64-override-default-driverlist.patch as the
  "i810" is now included upstream by default, but not "vmware" for AMD64
- Removed the following patches, as they are integrated into CVS now:
    xorg-x11-6.8.1.902-xf86pcibus-PCIX-bar-64bit-fix.patch
- Added {_x11localedir}/pt_BR.UTF-8/* to file list to pick up new i18n files

* Thu Jan 27 2005 Mike A. Harris <mharris@redhat.com> 6.8.1.902-7
- Renamed build_maintainer macro to build_mharris as it is actually a personal
  macro and there are actually several developers maintaining the rpm for
  quite some time now.  In case anyone is curious, I use it to tweak the spec
  file on occasion to build on a customized OS install that does not quite
  match any of our supported OS configurations.  ;o)
- Added a %%check section to the spec file, to put post build/install sanity
  checks in place.
- Added new post-build sanity check "with_undef_sym_test", did a local test
  build to confirm it works correctly, fixed a few things, then disabled it
  by default because Xorg needs a lot of love in order for this to be default.

* Wed Jan 26 2005 Mike A. Harris <mharris@redhat.com> 6.8.1.902-6
- Added xorg-x11-6.8.1.902-lnxLib-tmpl-sharedlibreq-fixes.patch to fix
  many missing library dependancies in lnxLib.tmpl, detected by examining
  the build log of a "with_bail_on_undef_syms" build.
- Disabled with_bail_on_undef_syms, after determining that there is a bit of
  work that needs to be done upstream first in order for us to expect X to
  fully build with these linker options.

* Mon Jan 24 2005 Mike A. Harris <mharris@redhat.com> 6.8.1.902-5
- Removed dead unused i810 update patch.
- Enabled with_bail_on_undef_syms, to do a test build.

* Fri Jan 21 2005 Mike A. Harris <mharris@redhat.com> 6.8.1.902-4
- Renamed the xorg-x11-6.8.0-AMD64-enable-i810-driver.patch patch to
  xorg-x11-6.8.0-AMD64-override-default-driverlist.patch and added the "vmware"
  driver to the default list of drivers to be build on AMD64. (#145588)

* Thu Jan 20 2005 Mike A. Harris <mharris@redhat.com> 6.8.1.902-3
- Added xorg-x11-6.8.1.902-xf86pcibus-PCIX-bar-64bit-fix.patch to attempt to
  fix bugs (#140601, 143910)

* Mon Jan 17 2005 Mike A. Harris <mharris@redhat.com> 6.8.1.902-2
- Added xorg-x11-6.8.1.902-ia64-hp-zx2-support-bug-119364.patch to add support
  for new Hewlett Packard IA64 ZX2 chipset. (#119364)

* Thu Jan 13 2005 Mike A. Harris <mharris@redhat.com> 6.8.1.902-1
- Update main tarball to X.Org X11 6.8.1.902 (6.8.2 release candidate 2)
  via X.Org official tarball: xorg-x11-6.8.1.902.tar.gz

* Sat Dec 18 2004 Mike A. Harris <mharris@redhat.com> 6.8.1.901-1
- Update main tarball to X.Org X11 6.8.1.901 (6.8.2 release candidate 1)
  via CVS export of CVS tag XORG-6_8_1_901
- Removed the following patches, as they are integrated into CVS now:
    xorg-x11-6.8.1-ati-radeon-segv-130888.patch
    xorg-x11-6.8.1-ati-radeon-panel-timing-param-init-130888.patch
    xorg-x11-6.8.0-ia64-460gx-pci-typo.patch
    xorg-x11-6.8.1-ati-radeon-mobility-display-detection-fix2.patch
    xorg-x11-6.8.1-ati-radeon-dynamic-clocks-fix.patch
    xorg-x11-6.8.1-libX11-stack-overflow.patch
    xorg-x11-6.8.1-vidmode-change-verbosity.patch
    xorg-x11-6.8.1-disable-dri-option.patch
    xorg-x11-6.8.1-xmodmap-overflows.patch
    xorg-x11-6.8.1-xpm-security-fixes-CAN-2004-0914.patch
    xorg-x11-6.8.1-xpm-security-fixes-CAN-2004-0914-sec8-ammendment.patch
    xorg-x11-6.8.1-r128-logout-deadlock.patch
    xorg-x11-6.8.1-add-missing-lucidatypewriter-font.patch
- Disabled xorg-x11-6.8.1-i810-update.patch, but left it present, as only some
  hunks fail to apply.  This leads me to believe perhaps 6.8.2 has only part of
  the i810 CVS head code.  We need to explore this a bit before dropping the
  patch altogether.

* Sat Dec 18 2004 Mike A. Harris <mharris@redhat.com> 6.8.1-25
- Tag CVS head of latest changes, to update to 6.8.2rc1 (6.8.1.901) for the
  next commit

* Mon Dec 13 2004 Kristian Høgsberg <krh@redhat.com>
- Rename xorg-x11.conf to xorg-x11-%{_arch}.conf so it works on
  multilib systems.

* Mon Dec 13 2004 Kristian Høgsberg <krh@redhat.com> 6.8.1-24
- Bump version.

* Sun Dec 12 2004 Kristian Høgsberg <krh@redhat.com>
- Drop xorg-libICE-remove-bogus-delay.patch as this was resolved in
  6.8.0 (https://bugs.freedesktop.org/show_bug.cgi?id=306)
- Drop XFree86-4.3.0-Xserver-xf86PciInfo-updates.patch, most of these
  #define's are present in the latest Xorg release.
- XFree86-4.3.0-redhat-xlib-linux-fix-avoiding-substance-abuse-job.patch
  is no longer needed since the unwanted code is only enabled when __sparcv9
  is defined.
- Remove XFree86-4.2.0-xtermresources.patch from cvs.
- Use /etc/ld.so.conf.d/xorg-x11.conf instead of editing
  /etc/ld.so.conf in %post (#124077).
- Remove XFree86-4.3.0-Xserver-dix-xkb-key-repeating-bug-CVS-backport.patch
  since the problem is now fixed upstream.
- Remove XFree86-4.3.0-xcursorgen-check-malloc-return.patch since it
  would only make xcursorgen fail differently in case of OOM.

* Thu Dec  9 2004 Soeren Sandmann <sandmann@redhat.com> 6.8.1-22.EL
- Better patch to Disable DRI on Radeon, workaround for bug #138348 .

* Thu Dec  9 2004 Soeren Sandmann <sandmann@redhat.com>
- Add disabled-by-default "dri" option to radeon driver.

* Mon Dec  6 2004 Mike A. Harris <mharris@redhat.com>
- Added "Obsoletes XFree86-ISO8859-2-Type1-fonts, fonts-ISO8859-2-Type1" to
  base-fonts subpackage, so that these ancient buggy font rpms get forcibly
  removed on OS upgrades from older OS releases that contained them.  We
  removed these fonts because they are very buggy among other reasons, however
  they do not get removed on upgrade without flagging them Obsoleted, which
  causes some problems when people use the buggy fonts in applications (#129523)

* Fri Dec  3 2004 Kristian Høgsberg <krh@redhat.com>
- Remove XFree86-4.3.0-Xserver-dix-xkb-key-repeating-bug-CVS-backport.patch
  since the problem is now fixed upstream.
- Remove XFree86-4.3.0-xcursorgen-check-malloc-return.patch since it
  would only make xcursorgen fail differently in case of OOM.

* Wed Dec  1 2004 Kristian Høgsberg <krh@redhat.com> 6.8.1-22
- Update xorg-x11-6.8.1-battle-libc-wrapper.patch to not break when
  some module also includes stdio.h.

* Tue Nov 30 2004 Mike A. Harris <mharris@redhat.com> 6.8.1-21.EL
- Build 6.8.1-21 using build_fc3 target as 6.8.1-12.FC3.21 for FC3

* Tue Nov 30 2004 Mike A. Harris <mharris@redhat.com> 6.8.1-21
- Added xorg-x11-6.8.1-ati-radeon-dynamic-clocks-fix.patch which now replaces
  xorg-x11-6.8.1-ati-radeon-7000-smp-lockup.patch as a fix for a lockup
  problem that occurs on some models of Radeon on SMP systems, related to the
  dynamic clocks code.  Fixes bugs: (#138108, 138348, 133526, 138539, 138779,
  fdo#1912)
- Merge to FC-3 branch and tag as 6.8.1-12.FC3.21, and to RHEL-4 branch and
  tag as 6.8.1-21.EL

* Mon Nov 29 2004 Mike A. Harris <mharris@redhat.com> 6.8.1-20
- Disabled with_fonts again
- Added xorg-x11-6.8.1-xpm-security-fixes-CAN-2004-0914-sec8-ammendment.patch
  to fix bugs introduced into libXpm in the previous security patch for
  CAN-2004-0914 which cause gimp to fail to save Xpm files (#140815, 141047,
  fdo#1924)

* Mon Nov 29 2004 Kristian Høgsberg <krh@redhat.com>
- Update xorg-x11-6.8.1-ati-radeon-7000-smp-lockup.patch to the new
  patch from Alex Deucher <agd5f@yahoo.com>, provided in
  https://bugs.freedesktop.org/show_bug.cgi?id=1912.

* Tue Nov 23 2004 Mike A. Harris <mharris@redhat.com> 6.8.1-19.with_fonts.0
- Enabled with_fonts for a single build, to update fonts-xorg package

* Tue Nov 23 2004 Mike A. Harris <mharris@redhat.com> 6.8.1-19
- Updated a few patches to apply with -p0 for consistency
- Reordered some patches by patch number
- Change libI810XvMC inclusion to be ifarch ix86/ia64/x86_64 only, since we
  know Intel video exists on those arches.  This is better than excluding it
  on arches we know it is not available on, because the list is shorter this
  way, and exact.  Less maintenance this way.

* Tue Nov 23 2004 Mike A. Harris <mharris@redhat.com> 6.8.1-18
- Remove libI810XvMC from PPC, as there is no Intel video hardware available
  for PPC architecture and this is an Intel video specific client side lib.
- Added xorg-x11-6.8.1-r128-logout-deadlock.patch to fix lockup on logout
  bug on Rage128 with DRI (#138822)
- Added xorg-x11-6.8.1-add-missing-lucidatypewriter-font.patch from upstream
  to fix bug with fonts that got inadvertently excluded from the X11 6.8.1
  release.  Our fonts-xorg package is being updated to include these additional
  fonts now as well (#139108, 139121, fdo#1560)
- Enable xorg-x11-6.8.1-i810-update.patch for all OS version builds now.

* Tue Nov 23 2004 Kristian Høgsberg <krh@redhat.com> 6.8.1-17
- Add libI810XvMC back on PPC filelists.
- Move xorg-x11-6.8.1-battle-libc-wrapper.patch into fc4_build section.

* Tue Nov 23 2004 Kristian Høgsberg <krh@redhat.com> 6.8.1-16
- Add xorg-x11-6.8.1-battle-libc-wrapper.patch to work around build
  error that pops up when system headers #define printf.

* Mon Nov 22 2004 Kristian Høgsberg <krh@redhat.com> 6.8.1-15
- Added xorg-x11-6.8.1-ati-radeon-7000-smp-lockup.patch to fix the
  hard lockup happening on SMP boxes with Radeon 7000 cards (#138108).

* Thu Nov 18 2004 Mike A. Harris <mharris@redhat.com> 6.8.1-14
- Added xorg-x11-6.8.1-nls-indic-locales.patch to add support for some indic
  locales.  BLOCKER (#133880)
- Minor fix in application of vidmode verbosity patch
- Added build_fc4 and build_rhel4 spec file build targets
- Enabled DRI for PPC only on FC2/FC3/FC4 builds for Fedora/PPC users.
- Conditionalized i810-update patch to only apply for build_fc4 as it is
  currently experimental.

* Thu Nov 18 2004 Kristian Høgsberg <krh@redhat.com>
- Add xorg-x11-6.8.1-i810-update.patch which contain fixes for i810
  chipsets backported from CVS HEAD as of November 16th (#132267).

* Mon Nov 15 2004 Kristian Høgsberg <krh@redhat.com> 6.8.1-13
- Added xorg-x11-6.8.1-xpm-security-fixes-CAN-2004-0914.patch to fix a
  number of Xpm issues found by Thomas Biege <thomas@suse.de>
  (#136169)

* Fri Nov 12 2004 Kristian Høgsberg <krh@redhat.com>
- Remove xorg-x11-6.8.1-ati-radeon-mobility-display-detection-fix.patch
  since it has been replaced with the -fix2 patch, remove
  XFree86-4.3.0-redhat-version-change-detection.patch since it doesn't
  work for Xorg.
- Remove XFree86-4.3.0-remove-copyright-symbol-to-fix-UTF-8.patch
  since it is now fixed upstream.

* Thu Nov 11 2004 Kristian Høgsberg <krh@redhat.com>
- Drop XFree86-4.3.0-Xserver-common-fix-broken-MIN-macro-definition.patch
  since it's harmless and it's fixed in Xorg HEAD now.
- Removed commented out xbiff, xeyes and xditview files from file
  lists, they are in CVS if we need them.
- Updated xorg-x11-tools description so it doesn't advertise stuff it
  doesn't contain (xbiff and xeyes).
- Drop XFree86-4.3.0-xbiff-file-heirarchy-standard.patch as we don't
  ship xbiff.
- Drop XFree86-4.2.0-xtermresources.patch as we don't ship in tree
  xterm anymore.
- Drop XFree86-4.3.0-redhat-lock-version.patch as Xorg don't print
  scary warnings for betas.

* Wed Nov 10 2004 Kristian Høgsberg <krh@redhat.com> 
- Edit xorg-x11-6.8.1-xmodmap-overflows.patch to fix buffer overflow
  crash (#138743).

* Wed Oct 20 2004 Kristian Høgsberg <krh@redhat.com> 6.8.1-12
- Add NULL check in xorg-x11-6.8.1-init-origins-fix.patch to prevent
  crashes on single head setups.

* Tue Oct 19 2004 Mike A. Harris <mharris@redhat.com> 6.8.1-11
- Added xorg-x11-6.8.1-ati-radeon-mobility-display-detection-fix2.patch to fix
  ATI Radeon Mobility display detection issue. (#132865, 133147, and upstream
  bugs: (fdo #1599, 1301, 1303, 1374, 1482, 1514, 1622, and 1631, and numerous
  others not on our lists))

* Tue Oct 19 2004 Mike A. Harris <mharris@redhat.com> 6.8.1-10
- Set with_fonts based off build_fc2 macro, so it is enabled for FC2 builds
  but remains disabled for FC3 and other builds.  Makes it easier to rebuild
  for FC2/FC1.
- Fix to make Vera font really get deleted this time for real. ;o)
* Mon Oct 18 2004  <krh@redhat.com> 6.8.1-9
- Add xorg-x11-6.8.1-init-origins-fix.patch, which fixes a crash for
  some invalid xorg.conf combinations (#134967).

* Mon Oct 18 2004 Mike A. Harris <mharris@redhat.com>
- Do not include the Bitstream Vera fonts when doing builds with with_fonts
  enabled, as we ship Vera in separate packaging already.
- When doing with_fonts builds to generate the fonts-xorg tarball, remove
  various Syriac fonts which contain bad codepoints:  SyrCOMCtesiphon.otf
  SyrCOMKharput.otf, SyrCOMMalankara.otf, SyrCOMMidyat.otf, SyrCOMQenNeshrin.otf
  SyrCOMTurAbdin.otf, SyrCOMUrhoyBold.otf, SyrCOMUrhoy.otf (bug #97951)

* Mon Oct 18 2004 Mike A. Harris <mharris@redhat.com> 6.8.1-8
- Added xorg-x11-6.8.1-ati-radeon-segv-130888.patch from Kevin Martin to fix
  linked list related SEGV for bug (#130888)
- Added xorg-x11-6.8.1-ati-radeon-panel-timing-param-init-130888.patch by
  Kevin Martin to fix panel timing issue in Radeon driver (#130888)

* Thu Oct 14 2004 Soren Sandmann <sandmann@redhat.com> 6.8.1-7
- Add xorg-x11-6.8.1-xmodmap-overflows.patch (#83720, #103161).

* Tue Oct 12 2004  <krh@redhat.com> 6.8.1-6
- Add xorg-x11-6.8.1-disable-dri-option.patch, which adds XF86Free-DRI
  to the list of extensions that can be disabled using the -extension
  command line switch (#135071).

* Wed Oct  6 2004 Mike A. Harris <mharris@redhat.com> 6.8.1-5
- Added xorg-x11-6.8.1-vidmode-change-verbosity.patch which changes the
  default verbosity level of Xvidmode extension debugging log messages in
  the X server from "1" to "> DEFAULT_XF86VIDMODE_VERBOSITY" which is set
  to 3.  This fixes a power consumption problem on laptops running on battery
  power, where when a screensaver kicks in and calls xf86GetVidMode(), the
  X server generates excessive log messages which cause the hard disk to spin
  up if it was in powersave mode, thus reducing the battery life.  Since the
  currently logged messages are pretty useless generally speaking, this fixes
  the problem by increasing the verbosity level required before the messages
  end up in the log file. (#128305)

* Tue Oct  5 2004 Mike A. Harris <mharris@redhat.com>
- Added post/postun scripts to the deprecated-libs subpackage, copied versions
  of those in the libs subpackage (#134424)

* Fri Sep 24 2004 Mike A. Harris <mharris@redhat.com> 6.8.1-4
- Implemented xorg-x11-6.8.1-libX11-stack-overflow.patch to fix stack
  overflow in libX11 which was discovered by new security features of
  gcc4 (#132885)

* Mon Sep 20 2004 Mike A. Harris <mharris@redhat.com> 6.8.1-3
- Bump to 6.8.1 and rebuild to quell beehive complaining
- Disable "parallel_build", as it is still broken

* Mon Sep 20 2004 Mike A. Harris <mharris@redhat.com> 6.8.1-2
- Update main tarball to the final X.Org X11 6.8.1 release via CVS export of
  CVS tag XORG-6_8_1 - this obsoletes previous 6.8.1 tarball which was a
  upstream release mixup.
- Added xorg-x11-6.8.0-libXdmcp-build-with-PIC.patch to make libXdmcp.a
  build with PIC flags to fix (#131130)
- Fixed changelog dates and made changelog version-release strings
  consistent
- Re-enable "parallel_build 1" to test if it works currently, so we can take
  advantage of SMP machines better

* Wed Sep 15 2004 Kristian Høgsberg <krh@redhat.com> 6.8.1-1
- Update to xorg 6.8.1
- Change Source: to use xorg-%{version}.%{zipext} since that is what
  the tarball from http://freedesktop.org/~xorg/X11R6.8.1/src/single/
  is called.

* Tue Sep 14 2004 Mike A. Harris <mharris@redhat.com> 6.8.0-5
- Enable "#define HasDevRandom YES" in host-$arch.def for bug (#126205)
- Remove "Requires: %{name}, %{name}-libs = %{version}-%{release}" from twm
  subpackage, as the libs twm is linked to should automatically be picked up
  by rpm "find-provides", and xterm moved to a separate package a long time
  ago, so both of these should no longer be needed. (#123423)
- Added xorg-x11-6.8.0-ia64-460gx-pci-typo.patch to fix typo in Intel 460gx
  PCI handling code on ia64. (#126586)
- Remove "XtermWithI18N" from host.def as we build xterm externally
- Added SElinux fix to xfs initscript (#130421,130969)

* Tue Sep 14 2004 Bill Nottingham <notting@redhat.com> 6.8.0-4
- buildrequire redhat-rpm-config, use brp-compress from that (fixes file conflicts)

* Mon Sep 13 2004 Kristian Høgsberg <krh@redhat.com> 6.8.0-3
- Fix typo in test for xorg.conf (#127711).

* Mon Sep 13 2004 Kristian Høgsberg <krh@redhat.com> 6.8.0-2
- Add with_wacom_driver option and set it to 0 (#132438, #132440).

* Thu Sep  9 2004 Mike A. Harris <mharris@redhat.com> 6.8.0-1
- Update main tarball to the final X.Org X11 6.8.0 release via CVS export of
  CVS tag XORG-6_8_0
- Add "BuildXaw NO" to host-$arch.def to disable building of libXaw 8 library
- Add "XtransFailSoft YES" to host-$arch.def to fix (#129622)
- Moved "archexec" script from main xorg-x11 subpackage to xorg-x11-devel
  subpackage since it is only used by things in the devel subpackage and we
  do not want to have the devel subpackage have a forced dependancy on the
  main package.  (#132121)
- Added "Conflicts: xorg-x11 < 6.8.0-1" to xorg-x11-devel for archexec
  subpackage move, so upgrades work correctly
- Removed libXaw.a from file list, as 6.8.0 no longer builds static libXaw 7
  even when libXaw 8 is disabled by "BuildXaw NO"
- Rework the _x11localedir file lists to fix rpm build problems

* Mon Sep  6 2004 Mike A. Harris <mharris@redhat.com>
- Remove various Syriac fonts which contain bad codepoints:  SyrCOMCtesiphon.otf
  SyrCOMKharput.otf, SyrCOMMalankara.otf, SyrCOMMidyat.otf, SyrCOMQenNeshrin.otf
  SyrCOMTurAbdin.otf, SyrCOMUrhoyBold.otf, SyrCOMUrhoy.otf (bug #97951)

* Fri Sep  3 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.903-6
- Remove hard coded dependancy on Glide3 from xorg-x11 package, as the tdfx
  DRI driver has used dlopen() with Glide3 since XFree86 4.2.1 or so, and no
  longer has a build time or runtime dependancy on Glide3 being present.  If
  Glide3 is present, DRI will work (theoretically), but if it is not present,
  the tdfx driver should still function correctly, so we can get rid of this
  dependancy now, as we are removing Glide3 from some of our OS products.

* Thu Sep  2 2004 Bill Nottingham <notting@redhat.com> 6.7.99.903-5
- bump release again

* Tue Aug 31 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.903-4
- Bump release field and rebuild unmodified to handle an off-by-one error
  in release field of font-utils subpackage dependancy

* Tue Aug 31 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.903-3
- Enable "#define HasDevRandom YES" in host-$arch.def for bug (#126205)
- Remove driver list overrides for all architectures except ia64, as ppc was
  missing the "nv" driver.  In the future, we will use patches to the Imake
  config directory to disable individual drivers on particular architectures.
- Disable building of fonts by setting with_fonts 0, as we now provide the
  fonts from a separate src.rpm which builds noarch packages, so that we no
  longer regenerate fonts every single X build, and people do not have to 
  redownload fonts every single xorg-x11 update when the fonts never change
  anyway.
- Added xorg-x11-6.8.0-Imake-add-BuildFontDevelUtils-macro.patch to allow
  building and inclusion of ucs2any and bdftruncate when doing "with_fonts 0"
  builds, as "BuildFonts NO" causes these utils to be excluded.
- Change main package dependancy from xorg-x11-base-fonts to base-fonts which
  is a virtual provide in both the xorg-x11-base-fonts and fonts-xorg-base
  packages now, to maximize install/upgrade compatibility.
- Moved "ucs2any" from the xorg-x11-tools subpackage to the font-utils
  subpackage where it belongs, and added a Conflicts line to the font-utils
  package to handle upgrades.
- Moved "fonts/util" subdir from xorg-x11-base-fonts, to font-utils package,
  as the utilities that use it reside there, and it never made sense in the
  base-fonts package anyway really.  Added Conflicts line to font-utils to
  handle upgrades.

* Tue Aug 31 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.903-2
- Remove "xtt" module line from config file on upgrades, as X.Org no longer
  supplies that module, since the "freetype" module now includes the
  functionality that was only available in the "xtt" module before.

* Sat Aug 29 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.903-1
- Update main tarball to CVS export of CVS tag XORG-6_7_99_903 snapshot,
  a.k.a. 6.8.0 RC3
- Added "xmessage" back upon request (#131076)
- Updated file list to change libXevie.so.1.0.0 to libXevie.so.1.0 due to
  upstream .so versioning change.

* Wed Aug 25 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.902-8
- Add defattr flag to Xdmx subpackage (#130870)

* Tue Aug 24 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.902-7
- Added new rpm macro 'with_libs_data' to Conditionalize the libs-data
  subpackage.  This allows us to disable the "libs-data" subpackage now, as
  rpm multilib should properly handle both architectures sanely, so the
  workaround of having the library data in a separate package is no longer
  needed.  By setting 'with_libs_data' to 0, it will cause the libs-data files
  to be included in the "libs" subpackage as it was in the past, and the
  "libs-data" package will get obsoleted.  This will simplify the rpm
  packaging a slight bit for the future.

* Sun Aug 22 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.902-6
- Remove a bunch of legacy Xaw/Xt applications which really should not be
  part of X11 sources (xbiff,xditview,xeyes,xmessage)

* Sat Aug 21 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.902-5
- Update archexec with additional cleanups, and make host.def match the
  version of host.def backported to XFree86 4.3.0 for RHEL3-U3, to maximize
  upgrade compatibility.

* Sat Aug 21 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.902-4
- Added "archexec" script as a generic solution to the xft-config/gccmakedep
  problem.
- Renamed xft-config and gccmakedep to <name>-<arch>, and added symlinks from
  archexec to <name>, so these two files do not conflict when installed on
  multilib systems.

* Fri Aug 20 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.902-3
- Install the host-<arch>.def file where host.def gets installed.

* Fri Aug 20 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.902-2
- Initial attempt to make host.def architecture neutral, and split the
  architecture specific things onto host-<arch>.def specific files, to allow
  multiple xorg-devel packages to be installed on multilib systems, such as
  x86_64, ppc64, and s390x.

* Wed Aug 18 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.902-1
- Update main tarball to CVS export of CVS tag XORG-6_7_99_902 snapshot,
  a.k.a. 6.8.0 RC2
- Removed patches that are now included in upstream sources:
  - xorg-x11-6.8.0-glx-install-dri-modules-in-correct-place.patch

* Mon Aug 16 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.901-2
- Set "BuildXprint NO" "BuildXprintClients NO" "BuildXprintLib YES" so we get
  *only* the Xprint libraries for backward compatibility with existing
  dynamically linked applications.
- Added new "xorg-x11-deprecated-libs", and moved the Xprint runtimes to it
  for backward compatibility for now, until we remove libXp entirely at some
  point in the future.
- Replaced remaining spec file package description references of "XFree86" to
  something X11 implementation neutral.
- Exclude the two new Xprint libraries libXprintAppUtil.a, libXprintUtil.a
  as we do not ship anything that links to them, so do not need them for
  back compat.

* Mon Aug 16 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.901-1
- Update main tarball to CVS export of CVS tag XORG-6_7_99_901 snapshot,
  a.k.a. 6.8.0 RC1
- Removed patches that are now included in upstream sources:
  - xorg-x11-6.7.0-mga-storm-sync-fix.patch
  - xorg-x11-6.8.0-ppc64-XorgServer-not-XF86Server-fix.patch
- Update xorg-x11-6.8.0-redhat-custom-startup.patch due to Imakefile change
- Disabled xorg-6.8.0-redhat-libGL-exec-shield-fixes.patch for now, as Xorg
  changes have broken it again and I do not want to port it forward 10 times.
  Once 6.8.0 is finalized, we will port it forward to Mesa CVS and get it
  into the Mesa CVS head *first*, then we will backport it to 6.8.0.  This
  way we do not have to maintain and port this patch once a week.
- Removed unwanted xprint file deletion from specfile as "BuildXprint NO"
  actually works now.
- Added Xevie libraries to file lists.

* Thu Aug 12 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.2-5
- Remove unneeded pre-build of ucs2any.c as it is now part of xorg stock
- Various minor cleanups to specfile
- Remove 'restest' Xresource extension sample client, as we now have 'xrestop'
  which is way better.
- Update xorg-x11-6.8.0-glx-install-dri-modules-in-correct-place.patch to use
  MODULEDIR instead of BUILDMODULEDIR (fdo #1057)

* Thu Aug 12 2004 Jeremy Katz <katzj@redhat.com> - 6.7.99.2-4
- Nuke libXp.a as it is unneeded (libXp got enabled for libXaw)

* Thu Aug 12 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.2-3
- Added xorg-6.8.0-glx-install-dri-modules-in-correct-place.patch to correct
  the location where dri modules get installed on lib64 arches (#129668)
- Enable libXp.so.* temporarily as libXaw is cancerously attached to it

* Thu Aug 12 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.2-2
- Added code to the rpm pre script to munge the config file to change the
  "keyboard" driver to "kbd" driver on upgrades, as XOrg no longer supports
  the old "keyboard" driver.
- Use perl -p -i -e in pre rpm script for all config file munging instead of
  grep and temporary files.

* Wed Aug 11 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.2-1
- Update main tarball to CVS export of CVS tag XORG-6_7_99_2 snapshot
- Removed patches that are now included in upstream sources:
  - xorg-x11-6.8.0-ppc64-support-updates.patch
  - xorg-x11-6.8.0-fix-xprint-install.patch
  - xorg-x11-6.8.0-build-fix-for-non-dri-builds.patch
- Remove /etc/init.d/xprint, as we do not ship/support Xprint
- Set "#define BuildXprint NO" in host.def
- Add xorg-x11-6.8.0-fix-BuildXprint.patch to fix "BuildXprint NO"
- Add xorg-x11-6.8.0-ppc64-XorgServer-not-XF86Server-fix.patch to fix ppc64
  build issue due to upstream renaming of XF86Server to XorgServer
- Added "XorgServer NO" to host.def for non-server builds

* Tue Aug 10 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.1-1
- Update main tarball to CVS export of CVS tag XORG-6_7_99_1 snapshot
- Removed patches that are now included in upstream sources:
  - xorg-x11-6.7.0-xkb-sysreq.patch
  - xorg-x11-6.7.0-mga-enable-video-rom-before-using.patch
  - xorg-x11-6.7.0-xset-man-update.patch
  - xorg-libX11-zh_CN.UTF8-crash-fix.patch
  - xorg-x11-6.8.0-i810-remove-stale-sdk-header.patch
- Update xorg-x11-6.8.0-redhat-custom-startup.patch due to Imakefile change
- Fix glitch in macro that disables DRI on ppc builds for fc3/rhel4
- Implemented xorg-x11-6.8.0-build-fix-for-non-dri-builds.patch patch to fix
  a compile time bug in the Radeon driver render acceleration on non-DRI
  builds, where the driver tests if CPStarted is set before calling
  RADEONInit3DEngineForRender(), however CPStarted is not available in
  non-DRI builds.  Also, RADEONInit3DEngineForRender() already correctly
  handles both the DRI and non-DRI cases both at compile and runtime, and
  checks if CPStarted is set internally.  (xorg #1033)

* Sat Aug  7 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.0-0.2004_08_05.1
- Delete various X server driver manpages on ppc64 s390, s390x which are
  showing up now for some odd reason, even when servers are not being built.
- Do not include libI810XvMC on ppc/ppc64/s390/s390x filelists

* Thu Aug  5 2004 Mike A. Harris <mharris@redhat.com> 6.7.99.0-0.2004_08_05.0
- Updated to X.Org X11 CVS development and branched specfile.  Chose arbitrary
  version number of "6.7.99.0" as XOrg confusingly calls development builds
  "6.7.0" still, and we need differentiation for sanity.  Kevin mentioned he
  would tag 6.7.99.1 in CVS once the final version 6.8.0 is approved by the
  XOrg BOD, so everything should work out ok version-wise.
- Removed patches already included in new upstream snapshot:
  - xorg-x11-6.7.0-ati-driver-message-cleanups.patch
  - xorg-x11-6.7.0-ati-radeon-pagesize.patch
  - xorg-x11-6.7.0-ati-radeon-7000m-dell-server.patch
  - xorg-x11-6.7.0-siliconmotion-fboffset-fix-from-cvs-head.patch
  - xorg-double-cast.patch
  - XFree86-4.3.0-build-libXinerama-before-libGL-for-via-driver.patch
  - xorg-use-linux-pci-only.patch
  - xorg-x11-6.7.0-allow-XF86ExtraCardDrivers-on-AMD64.patch
  - xorg-r200-uninitialized-variable-used.patch
- Disabled ati-radeon-forcelegacycrt and xorg-x11-6.7.0-xterm-make-optional
  patches, as they need porting forward and are very low priority
- Removed voodoo driver tarballs, as a newer version of the driver is now
  included in stock Xorg
- Update xorg-x11-6.8.0-Xserver-increase-max-pci-devices.patch for 6.8.0,
  as the upstream default changed from 64 to 128, but we want it to be 256.
- Update xorg-x11-6.8.0-AMD64-enable-i810-driver.patch for 6.8.0, as upstream
  currently still does not enable the i810 driver on AMD64 arch for some
  reason.
- Update xorg-x11-6.7.0-ppc64-support-updates.patch for 6.8.0
- Updated xorg-6.8.0-redhat-libGL-exec-shield-fixes.patch for 6.8.0
- Commented out the codeconv dir - no longer present
- Commented libXfontcache out of file lists, no longer present
- Added new libraries to file lists: libXcomposite, libXdamage, libXfixes,
- Added pkg-config files xcomposite.pc, xdamage.pc, xfixes.pc, xrender.pc
- Added all of the new Xprint junk to the xprint exclusion list
- Created new xorg-x11-Xdmx subpackage to contain all of the DMX related files
  required to run DMX.
- Removed with_via_driver option as it is no longer needed
- Removed "WORLDOPTS=" from make World invocation as upstream defaults to
  this now for some time.
- Added xorg-x11-6.8.0-i810-remove-stale-sdk-header.patch as workaround for
  header file inclusion problem (Kristian Hogsberg, fdo-bz #995)
- Added xorg-x11-6.8.0-fix-xprint-install.patch (Kristian Hogsberg)

* Thu Aug  5 2004 Mike A. Harris <mharris@redhat.com> 6.7.0-7.2
- Disabled XFree86-4.3.0-ia64-new-elfloader-relocations.patch as it fails the
  build on ia64.

* Thu Jul 15 2004 Mike A. Harris <mharris@redhat.com> 6.7.0-7.1
- Disabled XFree86-4.2.99.901-chips-default-to-noaccel-on-69000.patch and
  XFree86-4.2.99.901-chips-default-to-swcursor-on-65550.patch for the time
  being at least in order to see if anyone still reports the problem, in
  which case we can narrow down the bad primative, report upstream with
  workaround patch that disables accel.  (#82438)
- Removed XFree86-4.0.1-nohardware.patch as it is ancient, undocumented, and
  probably not needed anymore.
- Removed unnecessary or no longer needed patches, including:
  - XFree86-4.3.0-ati-r128-chip-names-touchup.patch
  - XFree86-4.3.0-nls-cjk-utf8.patch, XFree86-4.0-xdm-servonly.patch
  - XFree86-4.2.99.4-x86_64-glx-nopic.patch
  - XFree86-4.3.0-xterm-can-2003-0063.patch
  - XFree86-4.3.0-SDK-add-missing-includes-for-synaptics.patch
  
* Thu Jul  8 2004 Mike A. Harris <mharris@redhat.com> 6.7.0-7
- Updated and renamed following patches from XFree86-* to xorg-x11-* while
  cleaning up and documenting them for submission upstream:
  - xorg-x11-6.7.0-xset-man-update.patch
  - xorg-x11-6.7.0-xkb-sysreq.patch
  - xorg-x11-6.7.0-ati-driver-message-cleanups.patch
  - xorg-x11-6.7.0-ati-radeon-pagesize.patch
  - xorg-x11-6.7.0-ati-radeon-forcelegacycrt.patch
- Removed patches that are tested and confirmed to be no longer needed:
  - xorg-x11-6.7.0-cpp-s390x.patch
  - XFree86-4.2.99.3-locale-alias-gb18030.patch
  - XFree86-4.3.0-nls-compose-en_US.UTF8-lxo.patch
  - XFree86-4.3.0-ati-ia64-no-nonpci-ioport-access.patch
  - XFree86-4.3.0-ia64-slowbcopy.patch
  - XFree86-4.3.0-ia64-slowbcopy2.patch
- Disabled the sis DRI driver using with_sis_dri macro, as it is currently too
  experimental (#126821)
- Added xorg-x11-6.7.0-siliconmotion-fboffset-fix-from-cvs-head.patch taken
  from X.Org CVS head to try and fix bug (#127278)
  
* Thu Jul  8 2004 Mike A. Harris <mharris@redhat.com> 6.7.0-6.2
- Test build with xorg-x11-6.7.0-cpp-s390x.patch disabled

* Thu Jul  8 2004 Mike A. Harris <mharris@redhat.com> 6.7.0-6.1
- Updated and renamed following patches from XFree86-* to xorg-x11-* while
  cleaning up and documenting them for submission upstream:
  - xorg-x11-6.7.0-mga-enable-video-rom-before-using.patch
- Removed patches that are tested and confirmed to be no longer needed:
  - XFree86-4.3.0-r128-unresolved-symbols.patch
  - XFree86-4.3.0-ati-r128-Xv-ecp-divisor.patch
  - XFree86-4.3.0-gb18030-20020207.patch
  - XFree86-4.3.0-gb18030-xtt.patch, XFree86-4.3.0-gb18030-enc.patch
  - XFree86-4.3.0-nv-riva-dualhead-fixes.patch
  - XFree86-4.3.0-siliconmotion-Xv-stability-fix.patch
  - XFree86-4.2.99.901-007_fix_xfree86_man_version_string.patch
  - XFree86-4.2.99.901-008_doc_extensions_fix.patch
  - XFree86-4.3.0-Xserver-includes-ansify-prototypes.patch
  - XFree86-4.3.0-missing-SharedXfooReqs.patch
  - XFree86-4.3.0-libXrandr-missing-sharedreqs.patch
  - XFree86-4.3.0-libXpm-missing-sharedreqs.patch
  - XFree86-4.3.0-missing-lib-sharedreqs.patch
  - XFree86-4.3.0-Mesa-SSE-fixes-from-MesaCVS-v2.patch

* Sun Jul  4 2004 Mike A. Harris <mharris@redhat.com>
- Remove temporary config file left over after upgrade (#127187)
- Add libGL-devel and libGLU-devel virtual provides to xorg-x11-devel
  subpackage.  Both are provided for the major library version (1 in both
  cases), and for the major.minor (1.2 for libGL, 1.3 for libGLU).  This is
  being added to allow 3rd party packagers to add BuildRequires in an agnostic
  manner for apps that use libGL/libGLU, which allows any libGL/libGLU
  implementation devel package to be installed and meet the dependancy, as
  long as it also provides the same virtual provide mechanism.

* Wed Jun 30 2004 Mike A. Harris <mharris@redhat.com> 6.7.0-6
- Added xorg-x11-6.7.0-AMD64-enable-i810-driver.patch to patch the i810
  driver into the default driver list instead (#126687)

* Wed Jun 30 2004 Mike A. Harris <mharris@redhat.com> 6.7.0-5.1
- Enabled XF86ExtraCardDrivers on x86_64, and added i810 driver to it, to
  implement feature request from Intel (#126687)
- Added xorg-x11-6.7.0-Xserver-increase-max-pci-devices.patch to Increase
  the maximum number of PCI devices the X server scans, by changing the
  compiled in constant MAX_PCI_DEVICES from 64 to 256, as a lot of newer
  x86, ia64, ppc, ppc64, AMD64 hardware exists which may have more than 64
  devices. (#126164)  

* Fri Jun 25 2004 Mike A. Harris <mharris@redhat.com> 6.7.0-5
- Fixed bug in mga driver which caused hangs on some Matrox Mystique boards
  of revision 0->2, which were caused by a previous upstream bugfix for
  another issue.  xorg-x11-6.7.0-mga-storm-sync-fix.patch (#124028)
- Added xorg-x11-6.7.0-ati-radeon-7000m-dell-server.patch to add support for
  custom ATI hardware made for Dell. (#122190)

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com> 6.7.0-4
- rebuilt

* Tue May 18 2004 Mike A. Harris <mharris@redhat.com> 6.7.0-3
- Added rpm script munging of X server config file back to spec file, which
  got inadvertently left out of the 6.7.0-2 build.  This fixes #120858 and
  its bretheren.

* Fri May  8 2004 Mike A. Harris <mharris@redhat.com> 6.7.0-2
- Add -Wa,--noexecstack to AsCmd, in order to force all assembler files to
  use GNU stacks.  This was accomplished in an alternative way in our XFree86
  4.3.0 packaging via XFree86-4.3.0-redhat-exec-shield-GNU-stack.patch which
  patched every assembler file to add a .note.GNU-stack section, which is
  considered a superior solution, but our patch was non-portable to non-GNU
  systems.  This is a cleaner hack for now. (FC2BLOCKER #122708)
- Modified main rpm pre script to massage the X server config file(s) to
  remove XkbRules lines to help avoid (FC2BLOCKER #120858 and a zillion
  duplicates), and to ensure that the only active X server config file is
  xorg.conf (if any is present), and any other XFree86 4.x config files are
  renamed to .obsolete, which will help to minimize config file name confusion,
  and provide some sanity on upgrades, as all users will use xorg.conf by
  default regardless now. (FC2BLOCKER #122454)  (Fix based on patch from wtogami)

* Thu May  7 2004 Mike A. Harris <mharris@redhat.com> 6.7.0-1
- Added xorg-x11-6.7.0-libxf86config-monitor-freq-fix.patch to fix a problem
  caused by gratuitous upstream libxf86config changes which force the
  HorizSync and VertRefresh lines to always be written out to the config file
  in commented out form.  (FC2BLOCKER #120950, 122341, 122573, 122439, 122072,
  122461, 121946, 121717, others not yet duped)

* Thu Apr 15 2004 John Dennis <jdennis@redhat.com> 6.7.0-0.5
- add xorg-use-linux-pci-only.patch, fixes bugs #118130 & #120520

* Thu Apr  8 2004 Mike A. Harris <mharris@redhat.com> 6.7.0-0.4
- Further package description cleanups to remove more references to "XFree86"
  and replace them with more neutral wording, and also fix (#119670)

* Thu Apr  8 2004 Mike A. Harris <mharris@redhat.com> 6.7.0-0.3
- Fix pre script for loop error created by accidentally committing half worked
  code.

* Wed Apr  7 2004 Mike A. Harris <mharris@redhat.com> 6.7.0-0.2
- Updated spec file package descriptions to remove references to "XFree86" and
  update them to "X Window System" or "Xorg X11" as appropriate.
- Updated the following patches to work with xorg.cf instead of xfree86.cf:
  - xorg-x11-0.6.6-allow-XF86ExtraCardDrivers-on-AMD64.patch
  - xorg-x11-0.6.6-fix-BuildXFree86ConfigTools.patch
  - xorg-x11-6.7.0-xterm-make-optional.patch
  - xorg-x11-6.7.0-ppc64-support-updates.patch

* Wed Apr  7 2004 Mike A. Harris <mharris@redhat.com> 6.7.0-0.1
- Updated file lists to handle upstream renaming of X server binary from
  "XFree86" to "Xorg", server manpage, and getconfig config file.
- Added new ghost files for new server config file /etc/X11/xorg.conf
- Removed legacy compatibility symlinks for the old XF86Config file from
  /usr/X11R6/lib/X11 as X.org X11 uses /etc/X11/xorg.conf and there is no
  legacy to be compatible with.
- Other specfile cleanups to use /etc/X11/xorg.conf as the config file, and
  flag all places of XF86Config files with FIXME warnings of deprecation

* Tue Apr  6 2004 Mike A. Harris <mharris@redhat.com>
- Update main tarball to official X11 Release 6.7.0 from CVS export of the
  upstream release tag "xo-6_7_0" off of the "XORG-RELEASE-1" branch of CVS
- Removed xorg-redhat-ia64-plt-prot-exec-fix.patch as it is merged in 6.7.0

* Tue Apr  6 2004 Mike A. Harris <mharris@redhat.com> 0.6.6-0.2004_03_30.5
- Removed build_psyche build target, renamed build_rawhide to build_fc2, and
  added new build_maintainer custom build target
- Various spec file cleanups, renamed macros to foo_bar format, etc.

* Tue Apr  6 2004 Mike A. Harris <mharris@redhat.com> 0.6.6-0.2004_03_30.4
- Updated our ppc64 support patch and submitted upstream to fix (FDO #303) 
- Renamed xorg-ppc64-support-updates.patch to xorg-x11-ppc64-support-updates.patch
  to establish consistency with the names my xdiff utility produces.
- Added xorg-x11-0.6.6-allow-XF86ExtraCardDrivers-on-AMD64.patch to allow
  add on drivers to be specified using XF86ExtraCardDrivers in host.def on
  AMD64 architecture, in order to enable the "voodoo" driver.
- Enable the "voodoo" driver for AMD64 in addition to x86.
- Removed build_shrike, build_yarrow, and build_taroon build target macros and
  usage, as the package is not designed or intended to be used on those OS
  releases, and there are various potential problems that could arise.
- Updated freetype and freetype-devel dependancies to require version 2.1.7, as
  that is what version ships in the upstream sources, and there have been some
  font display related bugs reported by people who have recompiled the SRPM on
  older OS releases, and we do not support that anyway.
- Fixed bugs in spec file command substitution '[' tests discovered while
  updating the build target macros.
- Disabled BuildRequires: Glide3, Glide3-devel dependancies as Glide is opened
  via dlopen() for a while now, so it should not be needed at compile time any
  more.

* Mon Apr  5 2004 Mike A. Harris <mharris@redhat.com>
- Updated xorg-ppc64-support-updates.patch with fix for endian related issue
  (FC2 BLOCKER #119045)
- Removed obsolete_xfree86 conditional and usage, we hard code the Obsoletes
  lines now.
- Restored "Conflicts" lines that I had previously removed in the transition
  from XFree86 to Xorg X11, as they seem to still be needed on upgrades, or
  it is possible there will be upgrade failure issues, in particular when
  upgrading from Red Hat Linux 7.x or older releases to FC2.
- Added xorg-libX11-zh_CN.UTF8-crash-fix.patch to fix (FC2 BLOCKER #119032)

* Fri Apr  2 2004 Mike A. Harris <mharris@redhat.com> 0.6.6-0.2004_03_30.3
- Fixed a bug in xorg-redhat-libGL-exec-shield-fixes.patch (FC2 BLOCKER #119818)
- John further updated above patch, and tagged the .3 release.

* Thu Apr  1 2004 Mike A. Harris <mharris@redhat.com> 0.6.6-0.2004_03_30.2
- Added new open source Nvidia DRI 3D driver today, and enabled it on x86,
  ia64, and x86_64 only, as those are the only architectures that have been
  tested.  It builds cleanly with xorg, but is totally untested so far.

* Wed Mar 31 2004 Mike A. Harris <mharris@redhat.com> 0.6.6-0.2004_03_30.1
- Added xorg-ppc64-support-updates.patch back, as PPC64 fixes were reverted
  upstream <sigh>.

* Tue Mar 30 2004 Mike A. Harris <mharris@redhat.com> 0.6.6-0.2004_03_30.0
- Updated main xorg tarball to CVS snapshot 2004_03_30 from today.
- Removed XFree86-4.3.0-radeon-dpms-on-dvi-v2.patch as it should no longer be
  needed with current Radeon driver.
- Removed patches already merged into new upstream tarball, including:
  - xorg-redhat-elfloader-linux-non-exec-stack.patch
  - xorg-x11-addrinuse.patch
  - xorg-x11-Xft-freetype-bitmap-font-fix.patch
- Split out xorg-redhat-ia64-plt-prot-exec-fix.patch from libGL-exec-shield
  patch, as it was unrelated to libGL-exec-shield fixes. (#119324)
- Removed fonttosfnt* from the file lists as it has been removed upstream now
- Updated file list for libXft.so.2.1.2

* Tue Mar 30 2004 Mike A. Harris <mharris@redhat.com> 0.0.6.6-0.0.2004_03_11.11
- Added xorg-r200-uninitialized-variable-used.patch to CVS, as my last commit
  neglected to include the file.

* Tue Mar 30 2004 John Dennis <jdennis@redhat.com> 0.0.6.6-0.0.2004_03_11.10
- reenable libGL exec shield patch
- also fix bug 119324 ia64 exec permissions on PLT in elfloader

* Thu Mar 25 2004 Mike A. Harris <mharris@redhat.com>
- Fixed uninitialized variable access in Radeon R200 driver, in r200_pixel.c
  with xorg-r200-uninitialized-variable-used.patch FC2t2 TARGET (#116661)

* Wed Mar 24 2004 Mike A. Harris <mharris@redhat.com> 0.0.6.6-0.0.2004_03_11.9
- Really added the xorg-x11-Xft-freetype-bitmap-font-fix.patch patch this time
  as it was inadvertently left out of 0.0.6.6-0.0.2004_03_11.8 by mistake

* Tue Mar 23 2004 Mike A. Harris <mharris@redhat.com> 0.0.6.6-0.0.2004_03_11.8
- Added xorg-x11-Xft-freetype-bitmap-font-fix.patch from Xft 2.1.6 to Xorg
  included Xft to fix - FC2t2 BLOCKER (#118587,118822)
- Remove the rpm pre scripts from the library subpackages as they did not end
  up solving the XFree86 -> xorg-x11 ld.so.conf upgrade problem.
- Disable userdel/groupdel in xfs preun script, as it is harmless to leave the
  xfs user/group around as it is a registered account ID anyway, and there is
  a rather unsolveable problem on upgrades from one package providing xfs to
  a new one otherwise. - FC2t2 BLOCKER (#118145)
- Added "triggerpostun xfs -- XFree86-xfs" script, to work around a bug in the
  XFree86-xfs postun script, which results in the special xfs user account
  being inadvertently removed, causing xfs to run as the root user, and also
  resulting in xfs not being activated by chkconfig.  This trigger executes
  right after the XFree86-xfs postun script, and ensures that the xfs user
  exists, and that the xfs initscript is properly added by chkconfig, however
  this problem will recur again if we ever rename the xorg-x11 package to
  something else, or switch to a different X11 implementation altogether, since
  the xfs postun still will remove chkconfig on "rpm -e" or "rpm -U" to a
  different package name, but that problem is not easily solved other than by
  adding a new trigger every time the package name changes, unless someone
  has a better idea - FC2t2 BLOCKER (#118145,118818)
- Added "triggerpostun libs -- XFree86-libs" script to work around a bug in
  the XFree86-libs postun script, which results in _x11libdir being removed
  from ld.so.conf when upgrading from XFree86 to xorg-x11.  This trigger
  executes right after the XFree86-libs postun script and puts _x11libdir back
  in ld.so.conf - FC2t2 BLOCKER (#118448,118851,118993)
- Use "/sbin/service" instead of "service" in rpm scripts.
- Add "Requires(preun,postun): /sbin/service" to xfs package
  dependancies.

* Mon Mar 22 2004 Mike A. Harris <mharris@redhat.com> 0.0.6.6-0.0.2004_03_11.7
- Fixed -libs subpackage postun script by commenting out the broken empty
  if block (#118890,118949)
- Added xorg-x11-addrinuse.patch to fix bug in X.org Xtrans code which causes
  bind() failures to fail as if errno was set to -EADDRINUSE (#118950)
- Set "LinkGLToUsrLib NO" because the symlinks Imake creates are absolute,
  and we want relative symlinks.  A user reported this bug, so I have added
  code to %%install section to create relative symlinks in a similar but
  cleaner way to our XFree86 4.3.0 packaging. 

* Wed Mar 17 2004 Mike A. Harris <mharris@redhat.com> 0.0.6.6-0.0.2004_03_11.6
- Added new rpm pre scripts for the libs, Mesa-libGL, and Mesa-libGLU packages
  which add _x11libdir to ld.so.conf if it is missing, and then run ldconfig,
  in order to work around a race condition in the XFree86-libs-4.3.0-64 and
  older XFree86-libs packaging which could cause _x11libdir to be removed
  from ld.so.conf when other packages are still using it, including xorg-x11,
  causing upgrades to fail (#118448)
- Removed the offending code from xorg-x11-libs postun script so that this
  problem is not preserved in xorg-x11 packaging.  Also updated our XFree86
  packaging in cvs, so future XFree86 erratum for Fedora Core 1 and other OS
  releases will help to reduce the chances of someone getting hit by this
  upgrade problem.
- Added initial support to spec file for using the CVS Revision of the spec
  file in the package Release field.  Graciously stolen from the kernel spec
  file.  This is currently unused, but may be used in the future.

* Wed Mar 17 2004 Mike A. Harris <mharris@redhat.com> 0.0.6.6-0.0.2004_03_11.5
- Added versions to some of the XFree86 compabitility virtual provides, which
  include "Provides: XFree86-devel = 4.4.0", "Provides: XFree86-font-utils = 4.4.0",
  "Provides: XFree86-libs = 4.4.0"
- Added virtual provides of xdm, base-fonts, Xnest, xauth, libGL, libGLU, to
  each relevant subpackage.  They are all intentionally unversioned, so that
  things that require xdm/Xnest/etc. in a version/implementation agnostic
  manner, should use "Requires: xdm" instead of requiring a specific
  implementation or version of xdm.  If some package really does require a
  specific implementation or version of xdm, then it should still use the
  full non-virtual package name, as it is going to be both implementation and
  version specific anyway, so versioning these particular virtual provides
  does not make sense.

* Tue Mar 16 2004 Mike A. Harris <mharris@redhat.com> 0.0.6.6-0.0.2004_03_11.4
- Removed a bunch of the virtual Provides I added previously as they create
  problems with previous usage of Conflicts lines in some subpackages, and
  likely with other software, since they were not versioned Provides.  The
  other option would be versioning the provides, but I am not convinced that
  is the right approach.  Instead, I have removed them and will add things
  for compatibility only as problems arise.
- Added virtual "Provides: foo" to the Xvfb, xfs, twm, and font-utils subpackages,
  where "foo" is the subpackage name with the "XFree86-" part stripped off
  so that apps can use for example "Requires: xfs" to get an xfs font server,
  instead of requiring the XFree86 implementation specifically.  This allows
  us to have X11 implementation agnostic dependancies, which makes it easier
  to switch X11 implementations without breaking a pile of package
  dependancies.
- Added ld_so_conf_add_x11libdir macro, to clean up the rpm scripts a bit

* Mon Mar 15 2004 Mike A. Harris <mharris@redhat.com> 0.0.6.6-0.0.2004_03_11.3
- Added Obsoletes: tags to each subpackage in order to be able to properly
  replace XFree86 on upgrades cleanly
- Added virtual Provides: to most subpackages for compatibility with XFree86
  packaging on upgrades for packages that hard code specific XFree86
  dependancies.  Note that this may change in the future depending on the
  problems and needs that arise.
- Remove {_libdir}/libGL.so.1.2 symlink from Mesa-libGL subpackage as unneeded
- Disable libGL exec-shield patch for libGL as it has a slightly elusive glitch
- Remove all old XFree86 Conflicts lines from packaging, as they should not be
  needed now since the package names have changed and the old ones are now
  fully obsoleted

* Sat Mar 13 2004 Mike A. Harris <mharris@redhat.com> 0.0.6.6-0.0.2004_03_11.2
- Removed with_vmware conditional, and now unconditionally include vmware_drv
- Removed both the with_new_xft and with_new_xrender macros and their usage
- Removed version from virtual Xft Provides, as it is probably unnecessary
- Ported redhat-libGL-exec-shield-fixes.patch from 4.3.0 and added it as
  xorg-redhat-libGL-exec-shield-fixes.patch

* Sat Mar 13 2004 Mike A. Harris <mharris@redhat.com> 0.0.6.6-0.0.2004_03_11.1
- Various spec file cleanups, and s/XFree86/X Window System/ etc.
- Use %%{name} instead of hard coded XFree86 in dependancies for xdm
- Remove triggerpostun -- XFree86, as that was for 3.3.6 compatibility only
- Fix dri module file lists to prevent double inclusion problem
- Disable TLS support for libGL and the DRI drivers until it is ported forward

* Fri Mar 12 2004 Mike A. Harris <mharris@redhat.com> 0.0.6.6-0.0.2004_03_11.0
- Removed with_new_render hacks from specfile because new Render is included
  now, and upstream imake can deal with 3 level .so versions
- Updated libXft/libXrender .so.* versions in rpm file lists
- Updated spec file bits for moving GL includes into OpenGL ABI for Linux
  mandated location
- Removed spec file hack to make libGL be visible in OpenGL ABI for Linux
  mandated location, and enabled LinkGLToUsrLib YES in host.def to accomplish
  the same instead.
- Replaced .so version specific spec file hack to make libGLU be visible in
  OpenGL ABI for Linux mandated location, with a new hack that is more robust
- Updated file list for libXcursor.so.1.0.2

* Thu Mar 11 2004 Mike A. Harris <mharris@redhat.com>
- Updated to CVS snapshot 2004_03_11
- Added missing .so symlinks to -devel subpackage file list that did not get
  detected by the rpm missing_files_terminate_build test, but were present in
  the RPM_BUILD_ROOT
- Fixed bad dates for last few entries in spec file changelog
- Applied the xorg-mharris-radeon-agp-detect-via-pci-cap-list.patch and
  libICE-remove-bogus-delay.patch to upstream CVS and removed patches
- Downgraded freetype-devel dependancy to 2.1.4 again, so the package builds
  more easily on older OS releases for anyone brave enough to do so (ok, ok,
  so it is for me ok!)
- Added xorg-Imake-make-icondir-configurable.patch, ported forward from our
  XFree86 4.3.0 patch
- Explicitly list each individual shared library in the file lists instead of
  using globs, as this makes it easier to know when .so versions change,
  perhaps accidentally and catch problems sooner.  Globs were used before
  mainly to ensure files did not get excluded accidentally, however rpm now
  checks for files in the buildroot that do not end up in the final packaging
- Remove XFree86-4.3.0-redhat-xft-loadtarget.patch as the Xft in xorg CVS
  now includes this functionality already, however it is conditionalized at
  build time on the definition of FC_HINT_STYLE being defined, so we need to
  ensure this is getting defined at build time for compatibility.
- Updated redhat-embeddedbitmap patch

* Wed Mar 10 2004 Mike A. Harris <mharris@redhat.com> 0.0.6.6-0.0.2004_03_09.1
- Added xorg-ppc64-support-updates.patch, a forward port of ppc64 support from
  our XFree86 4.3.0 packaging
- Made with_savetemps work on x86/alpha/ppc/ppc64/amd64, and remove -pipe
  when using -save-temps
- Builds were failing with an mkfontscale SEGV or SIGILL on ppc/ppc64/s390
  which has been tracked down to an aliasing bug in freetype 2.1.7.  I have
  rebuilt freetype 2.1.7-3 with -fno-strict-aliasing which seems to work around
  the problem in testing.  We will see if it fixes it once freetype is built.
- Updated freetype dep in libs subpackage to 2.1.4
- Temporarily updated freetype-devel dep to 2.1.7-3 to force beehive to
  install it, so I get the -fno-strict-aliasing build
- ifnarch ppc64/s390/s390x libI810XvMC.*

* Wed Mar 10 2004 Mike A. Harris <mharris@redhat.com> 0.0.6.6-0.0.2004_03_09.0
- Initial xorg-x11 package, forked from the XFree86-4.3.0-63 package
- Package name chosen as xorg-x11 due to lack of official upstream package
  name at this point.  Name may change in the future, so people should not
  hard code any dependancies on it.  Version and Release fields future proofed
  for similar reasons, as we do not know what upstream version will be.
- Renamed StudlyCaps rpm macros XFree86CVSDate and CVSBuild to cvs_date and
  cvs_build to be more consistent in macro naming throughout specfile
- Disabled the with_new_savage_driver, and with_via_driver options by default,
  as the included drivers are newer, although the via driver may lose DRI
  support temporarily which I may need to add back later
- Disabled with_new_xft, with_new_xrender by default to use the stuff included
  in the tree, or use external Xft/Xrender packaging instead.
- Force with_xterm to 0 for all builds as we have shipped xterm separately
  for a few OS releases now
- Updated spec file License field to be more accurate "MIT/X11/others"
- Updated freetype deps to "BuildRequires: freetype-devel >= 2.1.4", as 2.1.4
  is what is currently included in the xorg sources and is the minimum needed
  to build properly
- Replaced all hard coded Requires: XFree86-* with usage of %%{name} macro
  instead, so package renames are easier to deal with
- Dropped all patches that were previously backported from XFree86 CVS, or
  were already checked into XFree86 CVS since 4.3.0.
- Temporarily disabled many patches that fail to apply, or fail to apply
  cleanly, for future investigation and cleanup, just to get rpms building
- Ported the elfloader-linux-non-exec-stack patch to current xorg-x11
- Removed the Glide3 conditionalized BuildRequires hack that was previously
  implemented to work around Red Hat buildsystem problems
- Disable removal of XIE/PEX docs as they are no longer provided in sources
- Force the removal of _x11dir/src in %%install, as the new tree installs the
  DRM source code there by default, and we do not want it because our DRM is
  in our kernel rpm.  No sense confusing users with multiple DRMs.
- Added getconfig bits to main server package
- Added fonttosfnt to font-utils subpackage
- Moved bdftopcf and bdftruncate to font-utils subpackage
- All libraries are now supplied by default in upstream builds in both static
  and dynamic (.a and .so) formats.  Libraries which are now supplied in
  shared form that were not in the past include:  libFS.so, libGLw.so,
  libI810XvMC.so, libXRes.so, libXfontcache.so, libXinerama.so, libXss.so,
  libXvMC.so, libXxf86dga, libXxf86misc.so, libXxf86rush.so, libXxf86vm.so,
  libfontenc.so, libxkbfile.so, libxkbui.so
- Added %%ghost flagged fonts.scale files to 100dpi, 75dpi, cyrillic, and misc
  font directories, so that if these files are present, they are owned by the
  appropriate subpackages

* Sun Mar  7 2004 Mike A. Harris <mharris@redhat.com>
- Conditionalized with_voodoo_driver to not build under build_taroon

* Fri Mar  5 2004 Mike A. Harris <mharris@redhat.com>
- Removed kdrive subpackage, and all with_kdrive conditionalization, as it is
  just extra spec file noise currently, and we have never shipped it.  Anyone
  building kdrive should instead be using kdrive from the xserver project on
  freedesktop.org
- Removed all 'athlon' subarchitecture references from spec file as the rpm
  {ix86} macro includes it automatically.
- Added XFree86-4.3.0-remove-copyright-symbol-to-fix-UTF-8.patch quick 2
  second fix to correct manpage display under UTF-8 (#101243)

* Thu Mar  4 2004 Mike A. Harris <mharris@redhat.com> 4.3.0-62.EL
- This changelog entry and all preceding historical XFree86 rpm specfile
  changelog entries have been split out into a separate file named
  "CHANGELOG-rpm" in the src.rpm, which is also included in the main
  package installed to "/usr/X11R6/lib/X11/doc/CHANGELOG-rpm".


